| Title                    | Invoke-Obfuscation Obfuscated IEX Invocation       |
|:-------------------------|:------------------|
| **Description**          | Detects all variations of obfuscated powershell IEX invocation code generated by Invoke-Obfuscation framework from the following code block — https://github.com/danielbohannon/Invoke-Obfuscation/blob/master/Out-ObfuscatedStringCommand.ps1#L873-L888 |
| **ATT&amp;CK Tactic**    |  <ul><li>[TA0005: Defense Evasion](https://attack.mitre.org/tactics/TA0005)</li></ul>  |
| **ATT&amp;CK Technique** | <ul><li>[T1027: Obfuscated Files or Information](https://attack.mitre.org/techniques/T1027)</li></ul>  |
| **Data Needed**          | <ul><li>[DN_0005_7045_windows_service_insatalled](../Data_Needed/DN_0005_7045_windows_service_insatalled.md)</li><li>[DN_0010_6_windows_sysmon_driver_loaded](../Data_Needed/DN_0010_6_windows_sysmon_driver_loaded.md)</li><li>[DN_0063_4697_service_was_installed_in_the_system](../Data_Needed/DN_0063_4697_service_was_installed_in_the_system.md)</li></ul>  |
| **Trigger**              | <ul><li>[T1027: Obfuscated Files or Information](../Triggers/T1027.md)</li></ul>  |
| **Severity Level**       | high |
| **False Positives**      | <ul><li>Unknown</li></ul>  |
| **Development Status**   | experimental |
| **References**           |  There are no documented References for this Detection Rule yet  |
| **Author**               | Daniel Bohannon (@Mandiant/@FireEye), oscd.community |


## Detection Rules

### Sigma rule

```
action: global
title: Invoke-Obfuscation Obfuscated IEX Invocation
id: 51aa9387-1c53-4153-91cc-d73c59ae1ca9
description: "Detects all variations of obfuscated powershell IEX invocation code generated by Invoke-Obfuscation framework from the following code block \u2014 https://github.com/danielbohannon/Invoke-Obfuscation/blob/master/Out-ObfuscatedStringCommand.ps1#L873-L888"
status: experimental
author: Daniel Bohannon (@Mandiant/@FireEye), oscd.community
date: 2019/11/08
tags:
    - attack.defense_evasion
    - attack.t1027
falsepositives:
    - Unknown
level: high
detection:
    selection:
        - ImagePath|re: '\$PSHome\[\s*\d{1,3}\s*\]\s*\+\s*\$PSHome\['
        - ImagePath|re: '\$ShellId\[\s*\d{1,3}\s*\]\s*\+\s*\$ShellId\['
        - ImagePath|re: '\$env:Public\[\s*\d{1,3}\s*\]\s*\+\s*\$env:Public\['
        - ImagePath|re: '\$env:ComSpec\[(\s*\d{1,3}\s*,){2}'
        - ImagePath|re: '\*mdr\*\W\s*\)\.Name'
        - ImagePath|re: '\$VerbosePreference\.ToString\('
        - ImagePath|re: '\String\]\s*\$VerbosePreference'
    condition: selection
---
logsource:
    product: windows
    service: system
detection:
    selection:
        EventID: 7045
---
logsource:
    product: windows
    service: sysmon
detection:
    selection:
        EventID: 6
---
 logsource:
     product: windows
     service: security
 detection:
     selection:
         EventID: 4697

```





### powershell
    
```
An unsupported feature is required for this Sigma rule (detection_rules/sigma/rules/windows/builtin/win_invoke_obfuscation_obfuscated_iex_services.yml): Backend does not support map values of type <class 'sigma.parser.modifiers.type.SigmaRegularExpressionModifier'>
Feel free to contribute for fun and fame, this is open source :) -> https://github.com/Neo23x0/sigma
```


### es-qs
    
```
(winlog.event_data.ImagePath:/\$PSHome\[\s*\d{1,3}\s*\]\s*\+\s*\$PSHome\[/ OR winlog.event_data.ImagePath:/\$ShellId\[\s*\d{1,3}\s*\]\s*\+\s*\$ShellId\[/ OR winlog.event_data.ImagePath:/\$env:Public\[\s*\d{1,3}\s*\]\s*\+\s*\$env:Public\[/ OR winlog.event_data.ImagePath:/\$env:ComSpec\[(\s*\d{1,3}\s*,){2}/ OR winlog.event_data.ImagePath:/\*mdr\*\W\s*\)\.Name/ OR winlog.event_data.ImagePath:/\$VerbosePreference\.ToString\(/ OR winlog.event_data.ImagePath:/\String\]\s*\$VerbosePreference/)
(winlog.channel:"Microsoft\-Windows\-Sysmon\/Operational" AND (winlog.event_data.ImagePath:/\$PSHome\[\s*\d{1,3}\s*\]\s*\+\s*\$PSHome\[/ OR winlog.event_data.ImagePath:/\$ShellId\[\s*\d{1,3}\s*\]\s*\+\s*\$ShellId\[/ OR winlog.event_data.ImagePath:/\$env:Public\[\s*\d{1,3}\s*\]\s*\+\s*\$env:Public\[/ OR winlog.event_data.ImagePath:/\$env:ComSpec\[(\s*\d{1,3}\s*,){2}/ OR winlog.event_data.ImagePath:/\*mdr\*\W\s*\)\.Name/ OR winlog.event_data.ImagePath:/\$VerbosePreference\.ToString\(/ OR winlog.event_data.ImagePath:/\String\]\s*\$VerbosePreference/))
(winlog.channel:"Security" AND (winlog.event_data.ImagePath:/\$PSHome\[\s*\d{1,3}\s*\]\s*\+\s*\$PSHome\[/ OR winlog.event_data.ImagePath:/\$ShellId\[\s*\d{1,3}\s*\]\s*\+\s*\$ShellId\[/ OR winlog.event_data.ImagePath:/\$env:Public\[\s*\d{1,3}\s*\]\s*\+\s*\$env:Public\[/ OR winlog.event_data.ImagePath:/\$env:ComSpec\[(\s*\d{1,3}\s*,){2}/ OR winlog.event_data.ImagePath:/\*mdr\*\W\s*\)\.Name/ OR winlog.event_data.ImagePath:/\$VerbosePreference\.ToString\(/ OR winlog.event_data.ImagePath:/\String\]\s*\$VerbosePreference/))
```


### xpack-watcher
    
```
curl -s -XPUT -H 'Content-Type: application/json' --data-binary @- localhost:9200/_watcher/watch/51aa9387-1c53-4153-91cc-d73c59ae1ca9 <<EOF
{
  "metadata": {
    "title": "Invoke-Obfuscation Obfuscated IEX Invocation",
    "description": "Detects all variations of obfuscated powershell IEX invocation code generated by Invoke-Obfuscation framework from the following code block \u2014 https://github.com/danielbohannon/Invoke-Obfuscation/blob/master/Out-ObfuscatedStringCommand.ps1#L873-L888",
    "tags": [
      "attack.defense_evasion",
      "attack.t1027"
    ],
    "query": "(winlog.event_data.ImagePath:/\\$PSHome\\[\\s*\\d{1,3}\\s*\\]\\s*\\+\\s*\\$PSHome\\[/ OR winlog.event_data.ImagePath:/\\$ShellId\\[\\s*\\d{1,3}\\s*\\]\\s*\\+\\s*\\$ShellId\\[/ OR winlog.event_data.ImagePath:/\\$env:Public\\[\\s*\\d{1,3}\\s*\\]\\s*\\+\\s*\\$env:Public\\[/ OR winlog.event_data.ImagePath:/\\$env:ComSpec\\[(\\s*\\d{1,3}\\s*,){2}/ OR winlog.event_data.ImagePath:/\\*mdr\\*\\W\\s*\\)\\.Name/ OR winlog.event_data.ImagePath:/\\$VerbosePreference\\.ToString\\(/ OR winlog.event_data.ImagePath:/\\String\\]\\s*\\$VerbosePreference/)"
  },
  "trigger": {
    "schedule": {
      "interval": "30m"
    }
  },
  "input": {
    "search": {
      "request": {
        "body": {
          "size": 0,
          "query": {
            "bool": {
              "must": [
                {
                  "query_string": {
                    "query": "(winlog.event_data.ImagePath:/\\$PSHome\\[\\s*\\d{1,3}\\s*\\]\\s*\\+\\s*\\$PSHome\\[/ OR winlog.event_data.ImagePath:/\\$ShellId\\[\\s*\\d{1,3}\\s*\\]\\s*\\+\\s*\\$ShellId\\[/ OR winlog.event_data.ImagePath:/\\$env:Public\\[\\s*\\d{1,3}\\s*\\]\\s*\\+\\s*\\$env:Public\\[/ OR winlog.event_data.ImagePath:/\\$env:ComSpec\\[(\\s*\\d{1,3}\\s*,){2}/ OR winlog.event_data.ImagePath:/\\*mdr\\*\\W\\s*\\)\\.Name/ OR winlog.event_data.ImagePath:/\\$VerbosePreference\\.ToString\\(/ OR winlog.event_data.ImagePath:/\\String\\]\\s*\\$VerbosePreference/)",
                    "analyze_wildcard": true
                  }
                }
              ],
              "filter": {
                "range": {
                  "timestamp": {
                    "gte": "now-30m/m"
                  }
                }
              }
            }
          }
        },
        "indices": [
          "winlogbeat-*"
        ]
      }
    }
  },
  "condition": {
    "compare": {
      "ctx.payload.hits.total": {
        "not_eq": 0
      }
    }
  },
  "actions": {
    "send_email": {
      "email": {
        "to": "root@localhost",
        "subject": "Sigma Rule 'Invoke-Obfuscation Obfuscated IEX Invocation'",
        "body": "Hits:\n{{#ctx.payload.hits.hits}}{{_source}}\n================================================================================\n{{/ctx.payload.hits.hits}}",
        "attachments": {
          "data.json": {
            "data": {
              "format": "json"
            }
          }
        }
      }
    }
  }
}
EOF
curl -s -XPUT -H 'Content-Type: application/json' --data-binary @- localhost:9200/_watcher/watch/51aa9387-1c53-4153-91cc-d73c59ae1ca9-2 <<EOF
{
  "metadata": {
    "title": "Invoke-Obfuscation Obfuscated IEX Invocation",
    "description": "Detects all variations of obfuscated powershell IEX invocation code generated by Invoke-Obfuscation framework from the following code block \u2014 https://github.com/danielbohannon/Invoke-Obfuscation/blob/master/Out-ObfuscatedStringCommand.ps1#L873-L888",
    "tags": [
      "attack.defense_evasion",
      "attack.t1027"
    ],
    "query": "(winlog.channel:\"Microsoft\\-Windows\\-Sysmon\\/Operational\" AND (winlog.event_data.ImagePath:/\\$PSHome\\[\\s*\\d{1,3}\\s*\\]\\s*\\+\\s*\\$PSHome\\[/ OR winlog.event_data.ImagePath:/\\$ShellId\\[\\s*\\d{1,3}\\s*\\]\\s*\\+\\s*\\$ShellId\\[/ OR winlog.event_data.ImagePath:/\\$env:Public\\[\\s*\\d{1,3}\\s*\\]\\s*\\+\\s*\\$env:Public\\[/ OR winlog.event_data.ImagePath:/\\$env:ComSpec\\[(\\s*\\d{1,3}\\s*,){2}/ OR winlog.event_data.ImagePath:/\\*mdr\\*\\W\\s*\\)\\.Name/ OR winlog.event_data.ImagePath:/\\$VerbosePreference\\.ToString\\(/ OR winlog.event_data.ImagePath:/\\String\\]\\s*\\$VerbosePreference/))"
  },
  "trigger": {
    "schedule": {
      "interval": "30m"
    }
  },
  "input": {
    "search": {
      "request": {
        "body": {
          "size": 0,
          "query": {
            "bool": {
              "must": [
                {
                  "query_string": {
                    "query": "(winlog.channel:\"Microsoft\\-Windows\\-Sysmon\\/Operational\" AND (winlog.event_data.ImagePath:/\\$PSHome\\[\\s*\\d{1,3}\\s*\\]\\s*\\+\\s*\\$PSHome\\[/ OR winlog.event_data.ImagePath:/\\$ShellId\\[\\s*\\d{1,3}\\s*\\]\\s*\\+\\s*\\$ShellId\\[/ OR winlog.event_data.ImagePath:/\\$env:Public\\[\\s*\\d{1,3}\\s*\\]\\s*\\+\\s*\\$env:Public\\[/ OR winlog.event_data.ImagePath:/\\$env:ComSpec\\[(\\s*\\d{1,3}\\s*,){2}/ OR winlog.event_data.ImagePath:/\\*mdr\\*\\W\\s*\\)\\.Name/ OR winlog.event_data.ImagePath:/\\$VerbosePreference\\.ToString\\(/ OR winlog.event_data.ImagePath:/\\String\\]\\s*\\$VerbosePreference/))",
                    "analyze_wildcard": true
                  }
                }
              ],
              "filter": {
                "range": {
                  "timestamp": {
                    "gte": "now-30m/m"
                  }
                }
              }
            }
          }
        },
        "indices": [
          "winlogbeat-*"
        ]
      }
    }
  },
  "condition": {
    "compare": {
      "ctx.payload.hits.total": {
        "not_eq": 0
      }
    }
  },
  "actions": {
    "send_email": {
      "email": {
        "to": "root@localhost",
        "subject": "Sigma Rule 'Invoke-Obfuscation Obfuscated IEX Invocation'",
        "body": "Hits:\n{{#ctx.payload.hits.hits}}{{_source}}\n================================================================================\n{{/ctx.payload.hits.hits}}",
        "attachments": {
          "data.json": {
            "data": {
              "format": "json"
            }
          }
        }
      }
    }
  }
}
EOF
curl -s -XPUT -H 'Content-Type: application/json' --data-binary @- localhost:9200/_watcher/watch/51aa9387-1c53-4153-91cc-d73c59ae1ca9-3 <<EOF
{
  "metadata": {
    "title": "Invoke-Obfuscation Obfuscated IEX Invocation",
    "description": "Detects all variations of obfuscated powershell IEX invocation code generated by Invoke-Obfuscation framework from the following code block \u2014 https://github.com/danielbohannon/Invoke-Obfuscation/blob/master/Out-ObfuscatedStringCommand.ps1#L873-L888",
    "tags": [
      "attack.defense_evasion",
      "attack.t1027"
    ],
    "query": "(winlog.channel:\"Security\" AND (winlog.event_data.ImagePath:/\\$PSHome\\[\\s*\\d{1,3}\\s*\\]\\s*\\+\\s*\\$PSHome\\[/ OR winlog.event_data.ImagePath:/\\$ShellId\\[\\s*\\d{1,3}\\s*\\]\\s*\\+\\s*\\$ShellId\\[/ OR winlog.event_data.ImagePath:/\\$env:Public\\[\\s*\\d{1,3}\\s*\\]\\s*\\+\\s*\\$env:Public\\[/ OR winlog.event_data.ImagePath:/\\$env:ComSpec\\[(\\s*\\d{1,3}\\s*,){2}/ OR winlog.event_data.ImagePath:/\\*mdr\\*\\W\\s*\\)\\.Name/ OR winlog.event_data.ImagePath:/\\$VerbosePreference\\.ToString\\(/ OR winlog.event_data.ImagePath:/\\String\\]\\s*\\$VerbosePreference/))"
  },
  "trigger": {
    "schedule": {
      "interval": "30m"
    }
  },
  "input": {
    "search": {
      "request": {
        "body": {
          "size": 0,
          "query": {
            "bool": {
              "must": [
                {
                  "query_string": {
                    "query": "(winlog.channel:\"Security\" AND (winlog.event_data.ImagePath:/\\$PSHome\\[\\s*\\d{1,3}\\s*\\]\\s*\\+\\s*\\$PSHome\\[/ OR winlog.event_data.ImagePath:/\\$ShellId\\[\\s*\\d{1,3}\\s*\\]\\s*\\+\\s*\\$ShellId\\[/ OR winlog.event_data.ImagePath:/\\$env:Public\\[\\s*\\d{1,3}\\s*\\]\\s*\\+\\s*\\$env:Public\\[/ OR winlog.event_data.ImagePath:/\\$env:ComSpec\\[(\\s*\\d{1,3}\\s*,){2}/ OR winlog.event_data.ImagePath:/\\*mdr\\*\\W\\s*\\)\\.Name/ OR winlog.event_data.ImagePath:/\\$VerbosePreference\\.ToString\\(/ OR winlog.event_data.ImagePath:/\\String\\]\\s*\\$VerbosePreference/))",
                    "analyze_wildcard": true
                  }
                }
              ],
              "filter": {
                "range": {
                  "timestamp": {
                    "gte": "now-30m/m"
                  }
                }
              }
            }
          }
        },
        "indices": [
          "winlogbeat-*"
        ]
      }
    }
  },
  "condition": {
    "compare": {
      "ctx.payload.hits.total": {
        "not_eq": 0
      }
    }
  },
  "actions": {
    "send_email": {
      "email": {
        "to": "root@localhost",
        "subject": "Sigma Rule 'Invoke-Obfuscation Obfuscated IEX Invocation'",
        "body": "Hits:\n{{#ctx.payload.hits.hits}}{{_source}}\n================================================================================\n{{/ctx.payload.hits.hits}}",
        "attachments": {
          "data.json": {
            "data": {
              "format": "json"
            }
          }
        }
      }
    }
  }
}
EOF

```


### graylog
    
```
(ImagePath:/\$PSHome\[\s*\d{1,3}\s*\]\s*\+\s*\$PSHome\[/ OR ImagePath:/\$ShellId\[\s*\d{1,3}\s*\]\s*\+\s*\$ShellId\[/ OR ImagePath:/\$env:Public\[\s*\d{1,3}\s*\]\s*\+\s*\$env:Public\[/ OR ImagePath:/\$env:ComSpec\[(\s*\d{1,3}\s*,){2}/ OR ImagePath:/\*mdr\*\W\s*\)\.Name/ OR ImagePath:/\$VerbosePreference\.ToString\(/ OR ImagePath:/\String\]\s*\$VerbosePreference/)
(ImagePath:/\$PSHome\[\s*\d{1,3}\s*\]\s*\+\s*\$PSHome\[/ OR ImagePath:/\$ShellId\[\s*\d{1,3}\s*\]\s*\+\s*\$ShellId\[/ OR ImagePath:/\$env:Public\[\s*\d{1,3}\s*\]\s*\+\s*\$env:Public\[/ OR ImagePath:/\$env:ComSpec\[(\s*\d{1,3}\s*,){2}/ OR ImagePath:/\*mdr\*\W\s*\)\.Name/ OR ImagePath:/\$VerbosePreference\.ToString\(/ OR ImagePath:/\String\]\s*\$VerbosePreference/)
(ImagePath:/\$PSHome\[\s*\d{1,3}\s*\]\s*\+\s*\$PSHome\[/ OR ImagePath:/\$ShellId\[\s*\d{1,3}\s*\]\s*\+\s*\$ShellId\[/ OR ImagePath:/\$env:Public\[\s*\d{1,3}\s*\]\s*\+\s*\$env:Public\[/ OR ImagePath:/\$env:ComSpec\[(\s*\d{1,3}\s*,){2}/ OR ImagePath:/\*mdr\*\W\s*\)\.Name/ OR ImagePath:/\$VerbosePreference\.ToString\(/ OR ImagePath:/\String\]\s*\$VerbosePreference/)
```


### splunk
    
```
An unsupported feature is required for this Sigma rule (detection_rules/sigma/rules/windows/builtin/win_invoke_obfuscation_obfuscated_iex_services.yml): Type modifier 're' is not supported by backend
Feel free to contribute for fun and fame, this is open source :) -> https://github.com/Neo23x0/sigma
```


### logpoint
    
```
An unsupported feature is required for this Sigma rule (detection_rules/sigma/rules/windows/builtin/win_invoke_obfuscation_obfuscated_iex_services.yml): Type modifier 're' is not supported by backend
Feel free to contribute for fun and fame, this is open source :) -> https://github.com/Neo23x0/sigma
```


### grep
    
```
An unsupported feature is required for this Sigma rule (detection_rules/sigma/rules/windows/builtin/win_invoke_obfuscation_obfuscated_iex_services.yml): Node type not implemented for this backend
Feel free to contribute for fun and fame, this is open source :) -> https://github.com/Neo23x0/sigma
```



