# T1040 - Network Sniffing
## [Description from ATT&CK](https://attack.mitre.org/wiki/Technique/T1040)
<blockquote>Network sniffing refers to using the network interface on a system to monitor or capture information sent over a wired or wireless connection. An adversary may place a network interface into promiscuous mode to passively access data in transit over the network, or use span ports to capture a larger amount of data.

Data captured via this technique may include user credentials, especially those sent over an insecure, unencrypted protocol. Techniques for name service resolution poisoning, such as [LLMNR/NBT-NS Poisoning and Relay](https://attack.mitre.org/techniques/T1171), can also be used to capture credentials to websites, proxies, and internal systems by redirecting traffic to an adversary.

Network sniffing may also reveal configuration details, such as running services, version numbers, and other network characteristics (ex: IP addressing, hostnames, VLAN IDs) necessary for follow-on Lateral Movement and/or Defense Evasion activities.</blockquote>

## Atomic Tests

- [Atomic Test #1 - Packet Capture Linux](#atomic-test-1---packet-capture-linux)

- [Atomic Test #2 - Packet Capture macOS](#atomic-test-2---packet-capture-macos)

- [Atomic Test #3 - Packet Capture Windows Command Prompt](#atomic-test-3---packet-capture-windows-command-prompt)

- [Atomic Test #4 - Packet Capture PowerShell](#atomic-test-4---packet-capture-powershell)


<br/>

## Atomic Test #1 - Packet Capture Linux
Perform a PCAP. Wireshark will be required for tshark. TCPdump may already be installed.

Upon successful execution, tshark or tcpdump will execute and capture 5 packets on interface ens33. 

**Supported Platforms:** Linux




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| interface | Specify interface to perform PCAP on. | String | ens33|


#### Attack Commands: Run with `bash`!  Elevation Required (e.g. root or admin) 


```bash
tcpdump -c 5 -nnni #{interface}
tshark -c 5 -i #{interface}
```






<br/>
<br/>

## Atomic Test #2 - Packet Capture macOS
Perform a PCAP on macOS. This will require Wireshark/tshark to be installed. TCPdump may already be installed.

Upon successful execution, tshark or tcpdump will execute and capture 5 packets on interface en0A.

**Supported Platforms:** macOS




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| interface | Specify interface to perform PCAP on. | String | en0A|


#### Attack Commands: Run with `bash`!  Elevation Required (e.g. root or admin) 


```bash
tcpdump -c 5 -nnni #{interface}
tshark -c 5 -i #{interface}
```






<br/>
<br/>

## Atomic Test #3 - Packet Capture Windows Command Prompt
Perform a packet capture using the windows command prompt. This will require a host that has Wireshark/Tshark
installed, along with WinPCAP. Windump will require the windump executable.

Upon successful execution, tshark will execute and capture 5 packets on interface Ethernet0.

**Supported Platforms:** Windows




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| interface | Specify interface to perform PCAP on. | String | Ethernet0|


#### Attack Commands: Run with `command_prompt`!  Elevation Required (e.g. root or admin) 


```cmd
"c:\Program Files\Wireshark\tshark.exe" -i #{interface} -c 5
c:\windump.exe
```






<br/>
<br/>

## Atomic Test #4 - Packet Capture PowerShell
Perform a packet capture using PowerShell with windump or tshark. This will require a host that has Wireshark/Tshark
installed, along with WinPCAP. Windump will require the windump executable.

Upon successful execution, tshark will spawn from powershell and capture 5 packets on interface Ethernet0.

**Supported Platforms:** Windows




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| interface | Specify interface to perform PCAP on. | String | Ethernet0|


#### Attack Commands: Run with `powershell`!  Elevation Required (e.g. root or admin) 


```powershell
& "c:\Program Files\Wireshark\tshark.exe" -i #{interface} -c 5
& c:\windump.exe
```






<br/>
