# T1047 - Windows Management Instrumentation
## [Description from ATT&CK](https://attack.mitre.org/wiki/Technique/T1047)
<blockquote>Windows Management Instrumentation (WMI) is a Windows administration feature that provides a uniform environment for local and remote access to Windows system components. It relies on the WMI service for local and remote access and the server message block (SMB) (Citation: Wikipedia SMB) and Remote Procedure Call Service (RPCS) (Citation: TechNet RPC) for remote access. RPCS operates over port 135. (Citation: MSDN WMI)

An adversary can use WMI to interact with local and remote systems and use it as a means to perform many tactic functions, such as gathering information for Discovery and remote Execution of files as part of Lateral Movement. (Citation: FireEye WMI 2015)</blockquote>

## Atomic Tests

- [Atomic Test #1 - WMI Reconnaissance Users](#atomic-test-1---wmi-reconnaissance-users)

- [Atomic Test #2 - WMI Reconnaissance Processes](#atomic-test-2---wmi-reconnaissance-processes)

- [Atomic Test #3 - WMI Reconnaissance Software](#atomic-test-3---wmi-reconnaissance-software)

- [Atomic Test #4 - WMI Reconnaissance List Remote Services](#atomic-test-4---wmi-reconnaissance-list-remote-services)

- [Atomic Test #5 - WMI Execute Local Process](#atomic-test-5---wmi-execute-local-process)

- [Atomic Test #6 - WMI Execute Remote Process](#atomic-test-6---wmi-execute-remote-process)


<br/>

## Atomic Test #1 - WMI Reconnaissance Users
An adversary might use WMI to list all local User Accounts. 
When the test completes , there should be local user accounts information displayed on the command line.

**Supported Platforms:** Windows





#### Attack Commands: Run with `command_prompt`! 


```cmd
wmic useraccount get /ALL /format:csv
```






<br/>
<br/>

## Atomic Test #2 - WMI Reconnaissance Processes
An adversary might use WMI to list Processes running on the compromised host.
When the test completes , there should be running processes listed on the command line.

**Supported Platforms:** Windows





#### Attack Commands: Run with `command_prompt`! 


```cmd
wmic process get caption,executablepath,commandline /format:csv
```






<br/>
<br/>

## Atomic Test #3 - WMI Reconnaissance Software
An adversary might use WMI to list installed Software hotfix and patches.
When the test completes, there should be a list of installed patches and when they were installed.

**Supported Platforms:** Windows





#### Attack Commands: Run with `command_prompt`! 


```cmd
wmic qfe get description,installedOn /format:csv
```






<br/>
<br/>

## Atomic Test #4 - WMI Reconnaissance List Remote Services
An adversary might use WMI to check if a certain Remote Service is running on a remote device. 
When the test completes, a service information will be displayed on the screen if it exists.
A common feedback message is that "No instance(s) Available" if the service queried is not running.
A common error message is "Node - (provided IP or default)  ERROR Description =The RPC server is unavailable" 
if the provided remote host is unreacheable

**Supported Platforms:** Windows




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| node | Ip Address | String | 127.0.0.1|
| service_search_string | Name Of Service | String | Spooler|


#### Attack Commands: Run with `command_prompt`! 


```cmd
wmic /node:"#{node}" service where (caption like "%#{service_search_string}%")
```






<br/>
<br/>

## Atomic Test #5 - WMI Execute Local Process
This test uses wmic.exe to execute a process on the local host.
When the test completes , a new process will be started locally .A notepad application will be started when input is left on default.

**Supported Platforms:** Windows




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| process_to_execute | Name or path of process to execute. | String | notepad.exe|


#### Attack Commands: Run with `command_prompt`! 


```cmd
wmic process call create #{process_to_execute}
```

#### Cleanup Commands:
```cmd
wmic process where name='#{process_to_execute}' delete >nul 2>&1
```





<br/>
<br/>

## Atomic Test #6 - WMI Execute Remote Process
This test uses wmic.exe to execute a process on a remote host. Specify a valid value for remote IP using the node parameter.
To clean up, provide the same node input as the one provided to run the test
A common error message is "Node - (provided IP or default)  ERROR Description =The RPC server is unavailable" if the default or provided IP is unreachable 

**Supported Platforms:** Windows




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| node | Ip Address | String | 127.0.0.1|
| process_to_execute | Name or path of process to execute. | String | notepad.exe|


#### Attack Commands: Run with `command_prompt`! 


```cmd
wmic /node:"#{node}" process call create #{process_to_execute}
```

#### Cleanup Commands:
```cmd
wmic /node:"#{node}" process where name='#{process_to_execute}' delete >nul 2>&1
```





<br/>
