# T1053 - Scheduled Task
## [Description from ATT&CK](https://attack.mitre.org/wiki/Technique/T1053)
<blockquote>Utilities such as [at](https://attack.mitre.org/software/S0110) and [schtasks](https://attack.mitre.org/software/S0111), along with the Windows Task Scheduler, can be used to schedule programs or scripts to be executed at a date and time. A task can also be scheduled on a remote system, provided the proper authentication is met to use RPC and file and printer sharing is turned on. Scheduling a task on a remote system typically required being a member of the Administrators group on the remote system. (Citation: TechNet Task Scheduler Security)

An adversary may use task scheduling to execute programs at system startup or on a scheduled basis for persistence, to conduct remote Execution as part of Lateral Movement, to gain SYSTEM privileges, or to run a process under the context of a specified account.</blockquote>

## Atomic Tests

- [Atomic Test #1 - At.exe Scheduled task](#atomic-test-1---atexe-scheduled-task)

- [Atomic Test #2 - Scheduled task Local](#atomic-test-2---scheduled-task-local)

- [Atomic Test #3 - Scheduled task Remote](#atomic-test-3---scheduled-task-remote)

- [Atomic Test #4 - Powershell Cmdlet Scheduled Task](#atomic-test-4---powershell-cmdlet-scheduled-task)


<br/>

## Atomic Test #1 - At.exe Scheduled task
Executes cmd.exe
Note: deprecated in Windows 8+

Upon successful execution, cmd.exe will spawn at.exe and create a scheduled task that will spawn cmd at a specific time.

**Supported Platforms:** Windows





#### Attack Commands: Run with `command_prompt`! 


```cmd
at 13:20 /interactive cmd
```






<br/>
<br/>

## Atomic Test #2 - Scheduled task Local
Upon successful execution, cmd.exe will create a scheduled task to spawn cmd.exe at 20:10. 

**Supported Platforms:** Windows




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| task_command | What you want to execute | String | C:&#92;windows&#92;system32&#92;cmd.exe|
| time | What time 24 Hour | String | 72600|


#### Attack Commands: Run with `command_prompt`!  Elevation Required (e.g. root or admin) 


```cmd
SCHTASKS /Create /SC ONCE /TN spawn /TR #{task_command} /ST #{time}
```

#### Cleanup Commands:
```cmd
SCHTASKS /Delete /TN spawn /F >nul 2>&1
```





<br/>
<br/>

## Atomic Test #3 - Scheduled task Remote
Create a task on a remote system.

Upon successful execution, cmd.exe will create a scheduled task to spawn cmd.exe at 20:10 on a remote endpoint. 

**Supported Platforms:** Windows




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| task_command | What you want to execute | String | C:&#92;windows&#92;system32&#92;cmd.exe|
| time | What time 24 Hour | String | 72600|
| target | Target | String | localhost|
| user_name | Username DOMAIN&#92;User | String | DOMAIN&#92;user|
| password | Password | String | At0micStrong|


#### Attack Commands: Run with `command_prompt`!  Elevation Required (e.g. root or admin) 


```cmd
SCHTASKS /Create /S #{target} /RU #{user_name} /RP #{password} /TN "Atomic task" /TR "#{task_command}" /SC daily /ST #{time}
```

#### Cleanup Commands:
```cmd
SCHTASKS /Delete /TN "Atomic task" /F >nul 2>&1
```





<br/>
<br/>

## Atomic Test #4 - Powershell Cmdlet Scheduled Task
Create an atomic scheduled task that leverages native powershell cmdlets.

Upon successful execution, powershell.exe will create a scheduled task to spawn cmd.exe at 20:10. 

**Supported Platforms:** Windows





#### Attack Commands: Run with `powershell`! 


```powershell
$Action = New-ScheduledTaskAction -Execute "calc.exe"
$Trigger = New-ScheduledTaskTrigger -AtLogon
$User = New-ScheduledTaskPrincipal -GroupId "BUILTIN\Administrators" -RunLevel Highest
$Set = New-ScheduledTaskSettingsSet
$object = New-ScheduledTask -Action $Action -Principal $User -Trigger $Trigger -Settings $Set
Register-ScheduledTask AtomicTask -InputObject $object
```

#### Cleanup Commands:
```powershell
Unregister-ScheduledTask -TaskName "AtomicTask" -confirm:$false >$null 2>&1
```





<br/>
