# T1082 - System Information Discovery
## [Description from ATT&CK](https://attack.mitre.org/wiki/Technique/T1082)
<blockquote>An adversary may attempt to get detailed information about the operating system and hardware, including version, patches, hotfixes, service packs, and architecture. Adversaries may use the information from [System Information Discovery](https://attack.mitre.org/techniques/T1082) during automated discovery to shape follow-on behaviors, including whether or not the adversary fully infects the target and/or attempts specific actions.

### Windows

Example commands and utilities that obtain this information include <code>ver</code>, [Systeminfo](https://attack.mitre.org/software/S0096), and <code>dir</code> within [cmd](https://attack.mitre.org/software/S0106) for identifying information based on present files and directories.

### Mac

On Mac, the <code>systemsetup</code> command gives a detailed breakdown of the system, but it requires administrative privileges. Additionally, the <code>system_profiler</code> gives a very detailed breakdown of configurations, firewall rules, mounted volumes, hardware, and many other things without needing elevated permissions.

### AWS

In Amazon Web Services (AWS), the Application Discovery Service may be used by an adversary to identify servers, virtual machines, software, and software dependencies running.(Citation: Amazon System Discovery)

### GCP

On Google Cloud Platform (GCP) <code>GET /v1beta1/{parent=organizations/*}/assets</code> or <code>POST /v1beta1/{parent=organizations/*}/assets:runDiscovery</code> may be used to list an organizations cloud assets, or perform asset discovery on a cloud environment.(Citation: Google Command Center Dashboard)

### Azure

In Azure, the API request <code>GET https://management.azure.com/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachines/{vmName}?api-version=2019-03-01</code> may be used to retrieve information about the model or instance view of a virtual machine.(Citation: Microsoft Virutal Machine API)</blockquote>

## Atomic Tests

- [Atomic Test #1 - System Information Discovery](#atomic-test-1---system-information-discovery)

- [Atomic Test #2 - System Information Discovery](#atomic-test-2---system-information-discovery)

- [Atomic Test #3 - List OS Information](#atomic-test-3---list-os-information)

- [Atomic Test #4 - Linux VM Check via Hardware](#atomic-test-4---linux-vm-check-via-hardware)

- [Atomic Test #5 - Linux VM Check via Kernel Modules](#atomic-test-5---linux-vm-check-via-kernel-modules)

- [Atomic Test #6 - Hostname Discovery (Windows)](#atomic-test-6---hostname-discovery-windows)

- [Atomic Test #7 - Hostname Discovery](#atomic-test-7---hostname-discovery)

- [Atomic Test #8 - Windows MachineGUID Discovery](#atomic-test-8---windows-machineguid-discovery)


<br/>

## Atomic Test #1 - System Information Discovery
Identify System Info

**Supported Platforms:** Windows





#### Attack Commands: Run with `command_prompt`! 


```cmd
systeminfo
reg query HKLM\SYSTEM\CurrentControlSet\Services\Disk\Enum
```






<br/>
<br/>

## Atomic Test #2 - System Information Discovery
Identify System Info

**Supported Platforms:** Linux, macOS





#### Attack Commands: Run with `sh`! 


```sh
systemsetup
system_profiler
ls -al /Applications
```






<br/>
<br/>

## Atomic Test #3 - List OS Information
Identify System Info

**Supported Platforms:** Linux, macOS





#### Attack Commands: Run with `sh`! 


```sh
uname -a >> /tmp/loot.txt
cat /etc/lsb-release >> /tmp/loot.txt
cat /etc/redhat-release >> /tmp/loot.txt
uptime >> /tmp/loot.txt
cat /etc/issue >> /tmp/loot.txt
```






<br/>
<br/>

## Atomic Test #4 - Linux VM Check via Hardware
Identify virtual machine hardware. This technique is used by the Pupy RAT and other malware.

**Supported Platforms:** Linux





#### Attack Commands: Run with `bash`! 


```bash
cat /sys/class/dmi/id/bios_version | grep -i amazon
cat /sys/class/dmi/id/product_name | grep -i "Droplet\|HVM\|VirtualBox\|VMware"
cat /sys/class/dmi/id/chassis_vendor | grep -i "Xen\|Bochs\|QEMU"
sudo dmidecode | grep -i "microsoft\|vmware\|virtualbox\|quemu\|domu"
cat /proc/scsi/scsi | grep -i "vmware\|vbox"
cat /proc/ide/hd0/model | grep -i "vmware\|vbox\|qemu\|virtual"
sudo lspci | grep -i "vmware\|virtualbox"
sudo lscpu | grep -i "Xen\|KVM\|Microsoft"
```






<br/>
<br/>

## Atomic Test #5 - Linux VM Check via Kernel Modules
Identify virtual machine guest kernel modules. This technique is used by the Pupy RAT and other malware.

**Supported Platforms:** Linux





#### Attack Commands: Run with `bash`! 


```bash
sudo lsmod | grep -i "vboxsf\|vboxguest"
sudo lsmod | grep -i "vmw_baloon\|vmxnet"
sudo lsmod | grep -i "xen-vbd\|xen-vnif"
sudo lsmod | grep -i "virtio_pci\|virtio_net"
sudo lsmod | grep -i "hv_vmbus\|hv_blkvsc\|hv_netvsc\|hv_utils\|hv_storvsc"
```






<br/>
<br/>

## Atomic Test #6 - Hostname Discovery (Windows)
Identify system hostname for Windows.

**Supported Platforms:** Windows





#### Attack Commands: Run with `command_prompt`! 


```cmd
hostname
```






<br/>
<br/>

## Atomic Test #7 - Hostname Discovery
Identify system hostname for Linux and macOS systems.

**Supported Platforms:** Linux, macOS





#### Attack Commands: Run with `bash`! 


```bash
hostname
```






<br/>
<br/>

## Atomic Test #8 - Windows MachineGUID Discovery
Identify the Windows MachineGUID value for a system.

**Supported Platforms:** Windows





#### Attack Commands: Run with `command_prompt`! 


```cmd
REG QUERY HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\Cryptography /v MachineGuid
```






<br/>
