# T1087 - Account Discovery
## [Description from ATT&CK](https://attack.mitre.org/wiki/Technique/T1087)
<blockquote>Adversaries may attempt to get a listing of local system or domain accounts. 

### Windows

Example commands that can acquire this information are <code>net user</code>, <code>net group <groupname></code>, and <code>net localgroup <groupname></code> using the [Net](https://attack.mitre.org/software/S0039) utility or through use of [dsquery](https://attack.mitre.org/software/S0105). If adversaries attempt to identify the primary user, currently logged in user, or set of users that commonly uses a system, [System Owner/User Discovery](https://attack.mitre.org/techniques/T1033) may apply.

### Mac

On Mac, groups can be enumerated through the <code>groups</code> and <code>id</code> commands. In mac specifically, <code>dscl . list /Groups</code> and <code>dscacheutil -q group</code> can also be used to enumerate groups and users.

### Linux

On Linux, local users can be enumerated through the use of the <code>/etc/passwd</code> file which is world readable. In mac, this same file is only used in single-user mode in addition to the <code>/etc/master.passwd</code> file.

Also, groups can be enumerated through the <code>groups</code> and <code>id</code> commands.

### Office 365 and Azure AD

With authenticated access there are several tools that can be used to find accounts. The <code>Get-MsolRoleMember</code> PowerShell cmdlet can be used to obtain account names given a role or permissions group.(Citation: Microsoft msolrolemember)(Citation: GitHub Raindance)

Azure CLI (AZ CLI) also provides an interface to obtain user accounts with authenticated access to a domain. The command <code>az ad user list</code> will list all users within a domain.(Citation: Microsoft AZ CLI)(Citation: Black Hills Red Teaming MS AD Azure, 2018) 

The <code>Get-GlobalAddressList</code> PowerShell cmdlet can be used to obtain email addresses and accounts from a domain using an authenticated session.(Citation: Microsoft getglobaladdresslist)(Citation: Black Hills Attacking Exchange MailSniper, 2016)</blockquote>

## Atomic Tests

- [Atomic Test #1 - Enumerate all accounts](#atomic-test-1---enumerate-all-accounts)

- [Atomic Test #2 - View sudoers access](#atomic-test-2---view-sudoers-access)

- [Atomic Test #3 - View accounts with UID 0](#atomic-test-3---view-accounts-with-uid-0)

- [Atomic Test #4 - List opened files by user](#atomic-test-4---list-opened-files-by-user)

- [Atomic Test #5 - Show if a user account has ever logged in remotely](#atomic-test-5---show-if-a-user-account-has-ever-logged-in-remotely)

- [Atomic Test #6 - Enumerate users and groups](#atomic-test-6---enumerate-users-and-groups)

- [Atomic Test #7 - Enumerate users and groups](#atomic-test-7---enumerate-users-and-groups)

- [Atomic Test #8 - Enumerate all accounts](#atomic-test-8---enumerate-all-accounts)

- [Atomic Test #9 - Enumerate all accounts via PowerShell](#atomic-test-9---enumerate-all-accounts-via-powershell)

- [Atomic Test #10 - Enumerate logged on users](#atomic-test-10---enumerate-logged-on-users)

- [Atomic Test #11 - Enumerate logged on users via PowerShell](#atomic-test-11---enumerate-logged-on-users-via-powershell)


<br/>

## Atomic Test #1 - Enumerate all accounts
Enumerate all accounts by copying /etc/passwd to another file

**Supported Platforms:** Linux, macOS




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| output_file | Path where captured results will be placed | Path | ~/loot.txt|


#### Attack Commands: Run with `sh`! 


```sh
cat /etc/passwd > #{output_file}
```






<br/>
<br/>

## Atomic Test #2 - View sudoers access
(requires root)

**Supported Platforms:** Linux, macOS




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| output_file | Path where captured results will be placed | Path | ~/loot.txt|


#### Attack Commands: Run with `sh`! 


```sh
cat /etc/sudoers > #{output_file}
```






<br/>
<br/>

## Atomic Test #3 - View accounts with UID 0
View accounts wtih UID 0

**Supported Platforms:** Linux, macOS




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| output_file | Path where captured results will be placed | Path | ~/loot.txt|


#### Attack Commands: Run with `sh`! 


```sh
grep 'x:0:' /etc/passwd > #{output_file}
```






<br/>
<br/>

## Atomic Test #4 - List opened files by user
List opened files by user

**Supported Platforms:** Linux, macOS





#### Attack Commands: Run with `sh`! 


```sh
username=$(echo $HOME | awk -F'/' '{print $3}') && lsof -u $username
```






<br/>
<br/>

## Atomic Test #5 - Show if a user account has ever logged in remotely
Show if a user account has ever logged in remotely

**Supported Platforms:** Linux




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| output_file | Path where captured results will be placed | Path | ~/loot.txt|


#### Attack Commands: Run with `sh`! 


```sh
lastlog > #{output_file}
```






<br/>
<br/>

## Atomic Test #6 - Enumerate users and groups
Utilize groups and id to enumerate users and groups

**Supported Platforms:** Linux, macOS





#### Attack Commands: Run with `sh`! 


```sh
groups
id
```






<br/>
<br/>

## Atomic Test #7 - Enumerate users and groups
Utilize local utilities to enumerate users and groups

**Supported Platforms:** macOS





#### Attack Commands: Run with `sh`! 


```sh
dscl . list /Groups
dscl . list /Users
dscl . list /Users | grep -v '_'
dscacheutil -q group
dscacheutil -q user
```






<br/>
<br/>

## Atomic Test #8 - Enumerate all accounts
Enumerate all accounts
Upon exection, multiple enumeration commands will be run and their output displayed in the PowerShell session

**Supported Platforms:** Windows





#### Attack Commands: Run with `command_prompt`! 


```cmd
net user
net user /domain
dir c:\Users\
cmdkey.exe /list
net localgroup "Users"
net localgroup
```






<br/>
<br/>

## Atomic Test #9 - Enumerate all accounts via PowerShell
Enumerate all accounts via PowerShell

**Supported Platforms:** Windows





#### Attack Commands: Run with `powershell`! 


```powershell
net user
net user /domain
get-localuser
get-localgroupmember -group Users
cmdkey.exe /list
ls C:/Users
get-childitem C:\Users\
dir C:\Users\
get-aduser -filter *
get-localgroup
net localgroup
```






<br/>
<br/>

## Atomic Test #10 - Enumerate logged on users
Enumerate logged on users

**Supported Platforms:** Windows





#### Attack Commands: Run with `command_prompt`! 


```cmd
query user
```






<br/>
<br/>

## Atomic Test #11 - Enumerate logged on users via PowerShell
Enumerate logged on users via PowerShell

**Supported Platforms:** Windows





#### Attack Commands: Run with `powershell`! 


```powershell
query user
```






<br/>
