# T1158 - Hidden Files and Directories
## [Description from ATT&CK](https://attack.mitre.org/wiki/Technique/T1158)
<blockquote>To prevent normal users from accidentally changing special files on a system, most operating systems have the concept of a ‘hidden’ file. These files don’t show up when a user browses the file system with a GUI or when using normal commands on the command line. Users must explicitly ask to show the hidden files either via a series of Graphical User Interface (GUI) prompts or with command line switches (<code>dir /a</code> for Windows and <code>ls –a</code> for Linux and macOS).

Adversaries can use this to their advantage to hide files and folders anywhere on the system for persistence and evading a typical user or system analysis that does not incorporate investigation of hidden files.

### Windows

Users can mark specific files as hidden by using the attrib.exe binary. Simply do <code>attrib +h filename</code> to mark a file or folder as hidden. Similarly, the “+s” marks a file as a system file and the “+r” flag marks the file as read only. Like most windows binaries, the attrib.exe binary provides the ability to apply these changes recursively “/S”.

### Linux/Mac

Users can mark specific files as hidden simply by putting a “.” as the first character in the file or folder name  (Citation: Sofacy Komplex Trojan) (Citation: Antiquated Mac Malware). Files and folder that start with a period, ‘.’, are by default hidden from being viewed in the Finder application and standard command-line utilities like “ls”. Users must specifically change settings to have these files viewable. For command line usages, there is typically a flag to see all files (including hidden ones). To view these files in the Finder Application, the following command must be executed: <code>defaults write com.apple.finder AppleShowAllFiles YES</code>, and then relaunch the Finder Application.

### Mac

Files on macOS can be marked with the UF_HIDDEN flag which prevents them from being seen in Finder.app, but still allows them to be seen in Terminal.app (Citation: WireLurker).
Many applications create these hidden files and folders to store information so that it doesn’t clutter up the user’s workspace. For example, SSH utilities create a .ssh folder that’s hidden and contains the user’s known hosts and keys.</blockquote>

## Atomic Tests

- [Atomic Test #1 - Create a hidden file in a hidden directory](#atomic-test-1---create-a-hidden-file-in-a-hidden-directory)

- [Atomic Test #2 - Mac Hidden file](#atomic-test-2---mac-hidden-file)

- [Atomic Test #3 - Create Windows System File with Attrib](#atomic-test-3---create-windows-system-file-with-attrib)

- [Atomic Test #4 - Create Windows Hidden File with Attrib](#atomic-test-4---create-windows-hidden-file-with-attrib)

- [Atomic Test #5 - Hidden files](#atomic-test-5---hidden-files)

- [Atomic Test #6 - Hide a Directory](#atomic-test-6---hide-a-directory)

- [Atomic Test #7 - Show all hidden files](#atomic-test-7---show-all-hidden-files)

- [Atomic Test #8 - Create ADS command prompt](#atomic-test-8---create-ads-command-prompt)

- [Atomic Test #9 - Create ADS PowerShell](#atomic-test-9---create-ads-powershell)


<br/>

## Atomic Test #1 - Create a hidden file in a hidden directory
Creates a hidden file inside a hidden directory

**Supported Platforms:** Linux, macOS





#### Attack Commands: Run with `sh`! 


```sh
mkdir /var/tmp/.hidden-directory
echo "T1158" > /var/tmp/.hidden-directory/.hidden-file
```

#### Cleanup Commands:
```sh
rm -rf /var/tmp/.hidden-directory/
```





<br/>
<br/>

## Atomic Test #2 - Mac Hidden file
Hide a file on MacOS

**Supported Platforms:** macOS





#### Attack Commands: Run with `sh`! 


```sh
xattr -lr * / 2>&1 /dev/null | grep -C 2 "00 00 00 00 00 00 00 00 40 00 FF FF FF FF 00 00"
```






<br/>
<br/>

## Atomic Test #3 - Create Windows System File with Attrib
Creates a file and marks it as a system file using the attrib.exe utility. Upon execution, open the file in file explorer then open Properties > Details
and observe that the Attributes are "SA" for System and Archive.

**Supported Platforms:** Windows




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| file_to_modify | File to modify using Attrib command | string | %temp%&#92;T1158.txt|


#### Attack Commands: Run with `command_prompt`!  Elevation Required (e.g. root or admin) 


```cmd
attrib.exe +s #{file_to_modify}
```

#### Cleanup Commands:
```cmd
del /A:S #{file_to_modify} >nul 2>&1
```



#### Dependencies:  Run with `command_prompt`!
##### Description: The file must exist on disk at specified location (#{file_to_modify})
##### Check Prereq Commands:
```cmd
IF EXIST #{file_to_modify} ( EXIT 0 ) ELSE ( EXIT 1 ) 
```
##### Get Prereq Commands:
```cmd
echo system_Attrib_T1158 >> #{file_to_modify}
```




<br/>
<br/>

## Atomic Test #4 - Create Windows Hidden File with Attrib
Creates a file and marks it as hidden using the attrib.exe utility.Upon execution, open File Epxplorer and enable View > Hidden Items. Then, open Properties > Details on the file
and observe that the Attributes are "SH" for System and Hidden.

**Supported Platforms:** Windows




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| file_to_modify | File to modify using Attrib command | string | %temp%&#92;T1158.txt|


#### Attack Commands: Run with `command_prompt`!  Elevation Required (e.g. root or admin) 


```cmd
attrib.exe +h #{file_to_modify}
```

#### Cleanup Commands:
```cmd
del /A:H #{file_to_modify} >nul 2>&1
```



#### Dependencies:  Run with `command_prompt`!
##### Description: The file must exist on disk at specified location (#{file_to_modify})
##### Check Prereq Commands:
```cmd
IF EXIST #{file_to_modify} ( EXIT 0 ) ELSE ( EXIT 1 ) 
```
##### Get Prereq Commands:
```cmd
echo system_Attrib_T1158 >> #{file_to_modify}
```




<br/>
<br/>

## Atomic Test #5 - Hidden files
Requires Apple Dev Tools

**Supported Platforms:** macOS




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| filename | path of file to hide | path | /tmp/evil|


#### Attack Commands: Run with `sh`! 


```sh
setfile -a V #{filename}
```






<br/>
<br/>

## Atomic Test #6 - Hide a Directory
Hide a directory on MacOS

**Supported Platforms:** macOS





#### Attack Commands: Run with `sh`! 


```sh
touch /var/tmp/T1158_mac.txt
chflags hidden /var/tmp/T1158_mac.txt
```

#### Cleanup Commands:
```sh
rm /var/tmp/T1158_mac.txt
```





<br/>
<br/>

## Atomic Test #7 - Show all hidden files
Show all hidden files on MacOS

**Supported Platforms:** macOS





#### Attack Commands: Run with `sh`! 


```sh
defaults write com.apple.finder AppleShowAllFiles YES
```

#### Cleanup Commands:
```sh
defaults write com.apple.finder AppleShowAllFiles NO
```





<br/>
<br/>

## Atomic Test #8 - Create ADS command prompt
Create an Alternate Data Stream with the command prompt. Write access is required. Upon execution, run "dir /a-d /s /r | find ":$DATA"" in the %temp%
folder to view that the alternate data stream exists. To view the data in the alternate data stream, run "notepad T1158_has_ads.txt:adstest.txt"

**Supported Platforms:** Windows




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| file_name | File name of file to create ADS on. | string | %temp%&#92;T1158_has_ads_cmd.txt|
| ads_filename | Name of ADS file. | string | adstest.txt|


#### Attack Commands: Run with `command_prompt`! 


```cmd
echo cmd /c echo "Shell code execution."> #{file_name}:#{ads_filename}
for /f "usebackq delims=φ" %i in (#{file_name}:#{ads_filename}) do %i
```

#### Cleanup Commands:
```cmd
del #{file_name} >nul 2>&1
```



#### Dependencies:  Run with `command_prompt`!
##### Description: The file must exist on disk at specified location (#{file_name})
##### Check Prereq Commands:
```cmd
IF EXIST #{file_name} ( EXIT 0 ) ELSE ( EXIT 1 ) 
```
##### Get Prereq Commands:
```cmd
echo normal_text >> #{file_name} >nul 2>&1
```




<br/>
<br/>

## Atomic Test #9 - Create ADS PowerShell
Create an Alternate Data Stream with PowerShell. Write access is required. To verify execution, the the command "ls -Recurse | %{ gi $_.Fullname -stream *} | where stream -ne ':$Data' | Select-Object pschildname"
in the %temp% direcotry to view all files with hidden data streams. To view the data in the alternate data stream, run "notepad.exe T1158_has_ads_powershell.txt:adstest.txt" in the %temp% folder.

**Supported Platforms:** Windows




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| file_name | File name of file to create ADS on. | string | $env:TEMP&#92;T1158_has_ads_powershell.txt|
| ads_filename | Name of ADS file. | string | adstest.txt|


#### Attack Commands: Run with `powershell`! 


```powershell
echo "test" > #{file_name} | set-content -path test.txt -stream #{ads_filename} -value "test"
set-content -path #{file_name} -stream #{ads_filename} -value "test2"
set-content -path . -stream #{ads_filename} -value "test3"
```

#### Cleanup Commands:
```powershell
Remove-Item -Path #{file_name} -ErrorAction Ignore
```



#### Dependencies:  Run with `powershell`!
##### Description: The file must exist on disk at specified location (#{file_name})
##### Check Prereq Commands:
```powershell
if (Test-Path #{file_name}) { exit 0 } else { exit 1 } 
```
##### Get Prereq Commands:
```powershell
New-Item -Path #{file_name} | Out-Null
```




<br/>
