# T1215 - Kernel Modules and Extensions
## [Description from ATT&CK](https://attack.mitre.org/wiki/Technique/T1215)
<blockquote>Loadable Kernel Modules (or LKMs) are pieces of code that can be loaded and unloaded into the kernel upon demand. They extend the functionality of the kernel without the need to reboot the system. For example, one type of module is the device driver, which allows the kernel to access hardware connected to the system. (Citation: Linux Kernel Programming) When used maliciously, Loadable Kernel Modules (LKMs) can be a type of kernel-mode [Rootkit](https://attack.mitre.org/techniques/T1014) that run with the highest operating system privilege (Ring 0). (Citation: Linux Kernel Module Programming Guide) Adversaries can use loadable kernel modules to covertly persist on a system and evade defenses. Examples have been found in the wild and there are some open source projects. (Citation: Volatility Phalanx2) (Citation: CrowdStrike Linux Rootkit) (Citation: GitHub Reptile) (Citation: GitHub Diamorphine)

Common features of LKM based rootkits include: hiding itself, selective hiding of files, processes and network activity, as well as log tampering, providing authenticated backdoors and enabling root access to non-privileged users. (Citation: iDefense Rootkit Overview)

Kernel extensions, also called kext, are used for macOS to load functionality onto a system similar to LKMs for Linux. They are loaded and unloaded through <code>kextload</code> and <code>kextunload</code> commands. Several examples have been found where this can be used. (Citation: RSAC 2015 San Francisco Patrick Wardle) (Citation: Synack Secure Kernel Extension Broken) Examples have been found in the wild. (Citation: Securelist Ventir)</blockquote>

## Atomic Tests

- [Atomic Test #1 - Linux - Load Kernel Module via insmod](#atomic-test-1---linux---load-kernel-module-via-insmod)


<br/>

## Atomic Test #1 - Linux - Load Kernel Module via insmod
This test uses the insmod command to load a kernel module for Linux.

**Supported Platforms:** Linux




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| kernel_module_file | KO object containing kernel module code. | path | diamorphine.ko|
| module_name | Kernel module name once loaded. | string | diamorphine|


#### Attack Commands: Run with `bash`!  Elevation Required (e.g. root or admin) 


```bash
insmod #{kernel_module_file}
```

#### Cleanup Commands:
```bash
rmmod #{module_name}
```





<br/>
