# T1482 - Domain Trust Discovery
## [Description from ATT&CK](https://attack.mitre.org/wiki/Technique/T1482)
<blockquote>Adversaries may attempt to gather information on domain trust relationships that may be used to identify [Lateral Movement](https://attack.mitre.org/tactics/TA0008) opportunities in Windows multi-domain/forest environments. Domain trusts provide a mechanism for a domain to allow access to resources based on the authentication procedures of another domain.(Citation: Microsoft Trusts) Domain trusts allow the users of the trusted domain to access resources in the trusting domain. The information discovered may help the adversary conduct [SID-History Injection](https://attack.mitre.org/techniques/T1178), [Pass the Ticket](https://attack.mitre.org/techniques/T1097), and [Kerberoasting](https://attack.mitre.org/techniques/T1208).(Citation: AdSecurity Forging Trust Tickets)(Citation: Harmj0y Domain Trusts) Domain trusts can be enumerated using the DSEnumerateDomainTrusts() Win32 API call, .NET methods, and LDAP.(Citation: Harmj0y Domain Trusts) The Windows utility [Nltest](https://attack.mitre.org/software/S0359) is known to be used by adversaries to enumerate domain trusts.(Citation: Microsoft Operation Wilysupply)</blockquote>

## Atomic Tests

- [Atomic Test #1 - Windows - Discover domain trusts with dsquery](#atomic-test-1---windows---discover-domain-trusts-with-dsquery)

- [Atomic Test #2 - Windows - Discover domain trusts with nltest](#atomic-test-2---windows---discover-domain-trusts-with-nltest)

- [Atomic Test #3 - Powershell enumerate domains and forests](#atomic-test-3---powershell-enumerate-domains-and-forests)


<br/>

## Atomic Test #1 - Windows - Discover domain trusts with dsquery
Uses the dsquery command to discover domain trusts.
Requires the installation of dsquery via Windows RSAT or the Windows Server AD DS role.

**Supported Platforms:** Windows





#### Attack Commands: Run with `command_prompt`! 


```cmd
dsquery * -filter "(objectClass=trustedDomain)" -attr *
```






<br/>
<br/>

## Atomic Test #2 - Windows - Discover domain trusts with nltest
Uses the nltest command to discover domain trusts.
Requires the installation of nltest via Windows RSAT or the Windows Server AD DS role.
This technique has been used by the Trickbot malware family.

**Supported Platforms:** Windows





#### Attack Commands: Run with `command_prompt`! 


```cmd
nltest /domain_trusts
```






<br/>
<br/>

## Atomic Test #3 - Powershell enumerate domains and forests
Use powershell to enumerate AD information

**Supported Platforms:** Windows





#### Attack Commands: Run with `powershell`! 


```powershell
Get-NetDomainTrust
Get-NetForestTrust
Get-ADDomain
Get-ADGroupMember Administrators -Recursive
```






<br/>
