# T1531 - Account Access Removal
## [Description from ATT&CK](https://attack.mitre.org/wiki/Technique/T1531)
<blockquote>Adversaries may interrupt availability of system and network resources by inhibiting access to accounts utilized by legitimate users. Accounts may be deleted, locked, or manipulated (ex: changed credentials) to remove access to accounts.

Adversaries may also subsequently log off and/or reboot boxes to set malicious changes into place.(Citation: CarbonBlack LockerGoga 2019)(Citation: Unit42 LockerGoga 2019)</blockquote>

## Atomic Tests

- [Atomic Test #1 - Change User Password - Windows](#atomic-test-1---change-user-password---windows)

- [Atomic Test #2 - Delete User - Windows](#atomic-test-2---delete-user---windows)


<br/>

## Atomic Test #1 - Change User Password - Windows
Changes the user password to hinder access attempts. Seen in use by LockerGoga. Upon execution, log into the user account "AtomicAdministrator" with
the password "HuHuHUHoHo283283".

**Supported Platforms:** Windows




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| user_account | User account whose password will be changed. | string | AtomicAdministrator|
| new_password | New password for the specified account. | string | HuHuHUHoHo283283@dJD|
| new_user_password | Password to use if user account must be created first | string | User2ChangePW!|


#### Attack Commands: Run with `command_prompt`!  Elevation Required (e.g. root or admin) 


```cmd
net.exe user #{user_account} #{new_password}
```

#### Cleanup Commands:
```cmd
net.exe user #{user_account} /delete >nul 2>&1
```



#### Dependencies:  Run with `command_prompt`!
##### Description: User account to change password of must exist (User: #{user_account})
##### Check Prereq Commands:
```cmd
net user #{user_account} 
```
##### Get Prereq Commands:
```cmd
net user #{user_account} #{new_user_password} /add
```




<br/>
<br/>

## Atomic Test #2 - Delete User - Windows
Deletes a user account to prevent access. Upon execution, run the command "net user" to verify that the new "AtomicUser" account was deleted.

**Supported Platforms:** Windows




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| user_account | User account to be deleted. | string | AtomicUser|
| new_user_password | Password to use if user account must be created first | string | User2DeletePW!|


#### Attack Commands: Run with `command_prompt`!  Elevation Required (e.g. root or admin) 


```cmd
net.exe user #{user_account} /delete
```




#### Dependencies:  Run with `command_prompt`!
##### Description: User account to delete must exist (User: #{user_account})
##### Check Prereq Commands:
```cmd
net user #{user_account} 
```
##### Get Prereq Commands:
```cmd
net user #{user_account} #{new_user_password} /add
```




<br/>
