| Title                    | Antivirus Exploitation Framework Detection       |
|:-------------------------|:------------------|
| **Description**          | Detects a highly relevant Antivirus alert that reports an exploitation framework |
| **ATT&amp;CK Tactic**    |  <ul><li>[TA0002: Execution](https://attack.mitre.org/tactics/TA0002)</li><li>[TA0011: Command and Control](https://attack.mitre.org/tactics/TA0011)</li></ul>  |
| **ATT&amp;CK Technique** | <ul><li>[T1203: Exploitation for Client Execution](https://attack.mitre.org/techniques/T1203)</li><li>[T1219: Remote Access Software](https://attack.mitre.org/techniques/T1219)</li></ul>  |
| **Data Needed**          | <ul><li>[DN_0084_av_alert](../Data_Needed/DN_0084_av_alert.md)</li></ul>  |
| **Trigger**              | <ul><li>[T1219: Remote Access Software](../Triggers/T1219.md)</li></ul>  |
| **Severity Level**       | critical |
| **False Positives**      | <ul><li>Unlikely</li></ul>  |
| **Development Status**   |  Development Status wasn't defined for this Detection Rule yet  |
| **References**           | <ul><li>[https://www.nextron-systems.com/2018/09/08/antivirus-event-analysis-cheat-sheet-v1-4/](https://www.nextron-systems.com/2018/09/08/antivirus-event-analysis-cheat-sheet-v1-4/)</li></ul>  |
| **Author**               | Florian Roth |


## Detection Rules

### Sigma rule

```
title: Antivirus Exploitation Framework Detection
id: 238527ad-3c2c-4e4f-a1f6-92fd63adb864
description: Detects a highly relevant Antivirus alert that reports an exploitation framework
date: 2018/09/09
modified: 2019/01/16
author: Florian Roth
references:
    - https://www.nextron-systems.com/2018/09/08/antivirus-event-analysis-cheat-sheet-v1-4/
tags:
    - attack.execution
    - attack.t1203
    - attack.command_and_control
    - attack.t1219
logsource:
    product: antivirus
detection:
    selection:
        Signature: 
            - "*MeteTool*"
            - "*MPreter*"
            - "*Meterpreter*"
            - "*Metasploit*"
            - "*PowerSploit*"
            - "*CobaltSrike*"
            - "*Swrort*"
            - "*Rozena*"
            - "*Backdoor.Cobalt*"
    condition: selection
fields:
    - FileName
    - User
falsepositives:
    - Unlikely
level: critical

```





### powershell
    
```
Get-WinEvent | where {($_.message -match "Signature.*.*MeteTool.*" -or $_.message -match "Signature.*.*MPreter.*" -or $_.message -match "Signature.*.*Meterpreter.*" -or $_.message -match "Signature.*.*Metasploit.*" -or $_.message -match "Signature.*.*PowerSploit.*" -or $_.message -match "Signature.*.*CobaltSrike.*" -or $_.message -match "Signature.*.*Swrort.*" -or $_.message -match "Signature.*.*Rozena.*" -or $_.message -match "Signature.*.*Backdoor.Cobalt.*") } | select TimeCreated,Id,RecordId,ProcessId,MachineName,Message
```


### es-qs
    
```
winlog.event_data.Signature.keyword:(*MeteTool* OR *MPreter* OR *Meterpreter* OR *Metasploit* OR *PowerSploit* OR *CobaltSrike* OR *Swrort* OR *Rozena* OR *Backdoor.Cobalt*)
```


### xpack-watcher
    
```
curl -s -XPUT -H 'Content-Type: application/json' --data-binary @- localhost:9200/_watcher/watch/238527ad-3c2c-4e4f-a1f6-92fd63adb864 <<EOF
{
  "metadata": {
    "title": "Antivirus Exploitation Framework Detection",
    "description": "Detects a highly relevant Antivirus alert that reports an exploitation framework",
    "tags": [
      "attack.execution",
      "attack.t1203",
      "attack.command_and_control",
      "attack.t1219"
    ],
    "query": "winlog.event_data.Signature.keyword:(*MeteTool* OR *MPreter* OR *Meterpreter* OR *Metasploit* OR *PowerSploit* OR *CobaltSrike* OR *Swrort* OR *Rozena* OR *Backdoor.Cobalt*)"
  },
  "trigger": {
    "schedule": {
      "interval": "30m"
    }
  },
  "input": {
    "search": {
      "request": {
        "body": {
          "size": 0,
          "query": {
            "bool": {
              "must": [
                {
                  "query_string": {
                    "query": "winlog.event_data.Signature.keyword:(*MeteTool* OR *MPreter* OR *Meterpreter* OR *Metasploit* OR *PowerSploit* OR *CobaltSrike* OR *Swrort* OR *Rozena* OR *Backdoor.Cobalt*)",
                    "analyze_wildcard": true
                  }
                }
              ],
              "filter": {
                "range": {
                  "timestamp": {
                    "gte": "now-30m/m"
                  }
                }
              }
            }
          }
        },
        "indices": [
          "winlogbeat-*"
        ]
      }
    }
  },
  "condition": {
    "compare": {
      "ctx.payload.hits.total": {
        "not_eq": 0
      }
    }
  },
  "actions": {
    "send_email": {
      "email": {
        "to": "root@localhost",
        "subject": "Sigma Rule 'Antivirus Exploitation Framework Detection'",
        "body": "Hits:\n{{#ctx.payload.hits.hits}}Hit on {{_source.@timestamp}}:\nFileName = {{_source.FileName}}\n    User = {{_source.User}}================================================================================\n{{/ctx.payload.hits.hits}}",
        "attachments": {
          "data.json": {
            "data": {
              "format": "json"
            }
          }
        }
      }
    }
  }
}
EOF

```


### graylog
    
```
Signature.keyword:(*MeteTool* *MPreter* *Meterpreter* *Metasploit* *PowerSploit* *CobaltSrike* *Swrort* *Rozena* *Backdoor.Cobalt*)
```


### splunk
    
```
(Signature="*MeteTool*" OR Signature="*MPreter*" OR Signature="*Meterpreter*" OR Signature="*Metasploit*" OR Signature="*PowerSploit*" OR Signature="*CobaltSrike*" OR Signature="*Swrort*" OR Signature="*Rozena*" OR Signature="*Backdoor.Cobalt*") | table FileName,User
```


### logpoint
    
```
Signature IN ["*MeteTool*", "*MPreter*", "*Meterpreter*", "*Metasploit*", "*PowerSploit*", "*CobaltSrike*", "*Swrort*", "*Rozena*", "*Backdoor.Cobalt*"]
```


### grep
    
```
grep -P '^(?:.*.*MeteTool.*|.*.*MPreter.*|.*.*Meterpreter.*|.*.*Metasploit.*|.*.*PowerSploit.*|.*.*CobaltSrike.*|.*.*Swrort.*|.*.*Rozena.*|.*.*Backdoor\.Cobalt.*)'
```



