| Title                    | Malware Shellcode in Verclsid Target Process       |
|:-------------------------|:------------------|
| **Description**          | Detects a process access to verclsid.exe that injects shellcode from a Microsoft Office application / VBA macro |
| **ATT&amp;CK Tactic**    |  <ul><li>[TA0005: Defense Evasion](https://attack.mitre.org/tactics/TA0005)</li><li>[TA0004: Privilege Escalation](https://attack.mitre.org/tactics/TA0004)</li></ul>  |
| **ATT&amp;CK Technique** | <ul><li>[T1055: Process Injection](https://attack.mitre.org/techniques/T1055)</li></ul>  |
| **Data Needed**          | <ul><li>[DN_0014_10_windows_sysmon_ProcessAccess](../Data_Needed/DN_0014_10_windows_sysmon_ProcessAccess.md)</li></ul>  |
| **Trigger**              | <ul><li>[T1055: Process Injection](../Triggers/T1055.md)</li></ul>  |
| **Severity Level**       | high |
| **False Positives**      | <ul><li>unknown</li></ul>  |
| **Development Status**   | experimental |
| **References**           | <ul><li>[https://twitter.com/JohnLaTwC/status/837743453039534080](https://twitter.com/JohnLaTwC/status/837743453039534080)</li></ul>  |
| **Author**               | John Lambert (tech), Florian Roth (rule) |


## Detection Rules

### Sigma rule

```
title: Malware Shellcode in Verclsid Target Process
id: b7967e22-3d7e-409b-9ed5-cdae3f9243a1
status: experimental
description: Detects a process access to verclsid.exe that injects shellcode from a Microsoft Office application / VBA macro
references:
    - https://twitter.com/JohnLaTwC/status/837743453039534080
tags:
    - attack.defense_evasion
    - attack.privilege_escalation
    - attack.t1055
author: John Lambert (tech), Florian Roth (rule)
date: 2017/03/04
logsource:
    product: windows
    service: sysmon
    definition: 'Use the following config to generate the necessary Event ID 10 Process Access events: <ProcessAccess onmatch="include"><CallTrace condition="contains">VBE7.DLL</CallTrace></ProcessAccess><ProcessAccess onmatch="exclude"><CallTrace condition="excludes">UNKNOWN</CallTrace></ProcessAccess>'
detection:
    selection:
        EventID: 10
        TargetImage: '*\verclsid.exe'
        GrantedAccess: '0x1FFFFF'
    combination1:
        CallTrace: '*|UNKNOWN(*VBE7.DLL*'
    combination2:
        SourceImage: '*\Microsoft Office\\*'
        CallTrace: '*|UNKNOWN*'
    condition: selection and 1 of combination*
falsepositives:
    - unknown
level: high



```





### powershell
    
```
Get-WinEvent -LogName Microsoft-Windows-Sysmon/Operational | where {(($_.ID -eq "10" -and $_.message -match "TargetImage.*.*\\verclsid.exe" -and $_.message -match "GrantedAccess.*0x1FFFFF") -and ($_.message -match "CallTrace.*.*|UNKNOWN(.*VBE7.DLL.*" -or ($_.message -match "SourceImage.*.*\\Microsoft Office\\.*" -and $_.message -match "CallTrace.*.*|UNKNOWN.*"))) } | select TimeCreated,Id,RecordId,ProcessId,MachineName,Message
```


### es-qs
    
```
(winlog.channel:"Microsoft\-Windows\-Sysmon\/Operational" AND (winlog.event_id:"10" AND winlog.event_data.TargetImage.keyword:*\\verclsid.exe AND winlog.event_data.GrantedAccess:"0x1FFFFF") AND (winlog.event_data.CallTrace.keyword:*|UNKNOWN\(*VBE7.DLL* OR (winlog.event_data.SourceImage.keyword:*\\Microsoft\ Office\\* AND winlog.event_data.CallTrace.keyword:*|UNKNOWN*)))
```


### xpack-watcher
    
```
curl -s -XPUT -H 'Content-Type: application/json' --data-binary @- localhost:9200/_watcher/watch/b7967e22-3d7e-409b-9ed5-cdae3f9243a1 <<EOF
{
  "metadata": {
    "title": "Malware Shellcode in Verclsid Target Process",
    "description": "Detects a process access to verclsid.exe that injects shellcode from a Microsoft Office application / VBA macro",
    "tags": [
      "attack.defense_evasion",
      "attack.privilege_escalation",
      "attack.t1055"
    ],
    "query": "(winlog.channel:\"Microsoft\\-Windows\\-Sysmon\\/Operational\" AND (winlog.event_id:\"10\" AND winlog.event_data.TargetImage.keyword:*\\\\verclsid.exe AND winlog.event_data.GrantedAccess:\"0x1FFFFF\") AND (winlog.event_data.CallTrace.keyword:*|UNKNOWN\\(*VBE7.DLL* OR (winlog.event_data.SourceImage.keyword:*\\\\Microsoft\\ Office\\\\* AND winlog.event_data.CallTrace.keyword:*|UNKNOWN*)))"
  },
  "trigger": {
    "schedule": {
      "interval": "30m"
    }
  },
  "input": {
    "search": {
      "request": {
        "body": {
          "size": 0,
          "query": {
            "bool": {
              "must": [
                {
                  "query_string": {
                    "query": "(winlog.channel:\"Microsoft\\-Windows\\-Sysmon\\/Operational\" AND (winlog.event_id:\"10\" AND winlog.event_data.TargetImage.keyword:*\\\\verclsid.exe AND winlog.event_data.GrantedAccess:\"0x1FFFFF\") AND (winlog.event_data.CallTrace.keyword:*|UNKNOWN\\(*VBE7.DLL* OR (winlog.event_data.SourceImage.keyword:*\\\\Microsoft\\ Office\\\\* AND winlog.event_data.CallTrace.keyword:*|UNKNOWN*)))",
                    "analyze_wildcard": true
                  }
                }
              ],
              "filter": {
                "range": {
                  "timestamp": {
                    "gte": "now-30m/m"
                  }
                }
              }
            }
          }
        },
        "indices": [
          "winlogbeat-*"
        ]
      }
    }
  },
  "condition": {
    "compare": {
      "ctx.payload.hits.total": {
        "not_eq": 0
      }
    }
  },
  "actions": {
    "send_email": {
      "email": {
        "to": "root@localhost",
        "subject": "Sigma Rule 'Malware Shellcode in Verclsid Target Process'",
        "body": "Hits:\n{{#ctx.payload.hits.hits}}{{_source}}\n================================================================================\n{{/ctx.payload.hits.hits}}",
        "attachments": {
          "data.json": {
            "data": {
              "format": "json"
            }
          }
        }
      }
    }
  }
}
EOF

```


### graylog
    
```
((EventID:"10" AND TargetImage.keyword:*\\verclsid.exe AND GrantedAccess:"0x1FFFFF") AND (CallTrace.keyword:*|UNKNOWN\(*VBE7.DLL* OR (SourceImage.keyword:*\\Microsoft Office\\* AND CallTrace.keyword:*|UNKNOWN*)))
```


### splunk
    
```
(source="WinEventLog:Microsoft-Windows-Sysmon/Operational" (EventCode="10" TargetImage="*\\verclsid.exe" GrantedAccess="0x1FFFFF") (CallTrace="*|UNKNOWN(*VBE7.DLL*" OR (SourceImage="*\\Microsoft Office\\*" CallTrace="*|UNKNOWN*")))
```


### logpoint
    
```
((event_id="10" TargetImage="*\\verclsid.exe" GrantedAccess="0x1FFFFF") (CallTrace="*|UNKNOWN(*VBE7.DLL*" OR (SourceImage="*\\Microsoft Office\\*" CallTrace="*|UNKNOWN*")))
```


### grep
    
```
grep -P '^(?:.*(?=.*(?:.*(?=.*10)(?=.*.*\verclsid\.exe)(?=.*0x1FFFFF)))(?=.*(?:.*(?:.*.*\|UNKNOWN\(.*VBE7\.DLL.*|.*(?:.*(?=.*.*\Microsoft Office\\.*)(?=.*.*\|UNKNOWN.*))))))'
```



