| Title                    | Malicious PowerShell Commandlet Names       |
|:-------------------------|:------------------|
| **Description**          | Detects the creation of known powershell scripts for exploitation |
| **ATT&amp;CK Tactic**    |  <ul><li>[TA0002: Execution](https://attack.mitre.org/tactics/TA0002)</li></ul>  |
| **ATT&amp;CK Technique** | <ul><li>[T1086: PowerShell](https://attack.mitre.org/techniques/T1086)</li></ul>  |
| **Data Needed**          | <ul><li>[DN_0015_11_windows_sysmon_FileCreate](../Data_Needed/DN_0015_11_windows_sysmon_FileCreate.md)</li></ul>  |
| **Trigger**              | <ul><li>[T1086: PowerShell](../Triggers/T1086.md)</li></ul>  |
| **Severity Level**       | high |
| **False Positives**      | <ul><li>Penetration Tests</li></ul>  |
| **Development Status**   | experimental |
| **References**           | <ul><li>[https://raw.githubusercontent.com/Neo23x0/sigma/f35c50049fa896dff91ff545cb199319172701e8/rules/windows/powershell/powershell_malicious_commandlets.yml](https://raw.githubusercontent.com/Neo23x0/sigma/f35c50049fa896dff91ff545cb199319172701e8/rules/windows/powershell/powershell_malicious_commandlets.yml)</li></ul>  |
| **Author**               | Markus Neis |


## Detection Rules

### Sigma rule

```
title: Malicious PowerShell Commandlet Names
id: f331aa1f-8c53-4fc3-b083-cc159bc971cb
status: experimental
description: Detects the creation of known powershell scripts for exploitation
references:
    - https://raw.githubusercontent.com/Neo23x0/sigma/f35c50049fa896dff91ff545cb199319172701e8/rules/windows/powershell/powershell_malicious_commandlets.yml
tags:
    - attack.execution
    - attack.t1086
author: Markus Neis
date: 2018/04/07
logsource:
    product: windows
    service: sysmon
detection:
    selection:
        EventID: 11
        TargetFilename:
            - '*\Invoke-DllInjection.ps1'   
            - '*\Invoke-WmiCommand.ps1'
            - '*\Get-GPPPassword.ps1'
            - '*\Get-Keystrokes.ps1'
            - '*\Get-VaultCredential.ps1'
            - '*\Invoke-CredentialInjection.ps1'
            - '*\Invoke-Mimikatz.ps1'
            - '*\Invoke-NinjaCopy.ps1'
            - '*\Invoke-TokenManipulation.ps1'
            - '*\Out-Minidump.ps1'
            - '*\VolumeShadowCopyTools.ps1'
            - '*\Invoke-ReflectivePEInjection.ps1'
            - '*\Get-TimedScreenshot.ps1'
            - '*\Invoke-UserHunter.ps1'
            - '*\Find-GPOLocation.ps1'
            - '*\Invoke-ACLScanner.ps1'
            - '*\Invoke-DowngradeAccount.ps1'
            - '*\Get-ServiceUnquoted.ps1'
            - '*\Get-ServiceFilePermission.ps1'
            - '*\Get-ServicePermission.ps1'
            - '*\Invoke-ServiceAbuse.ps1'
            - '*\Install-ServiceBinary.ps1'
            - '*\Get-RegAutoLogon.ps1'
            - '*\Get-VulnAutoRun.ps1'
            - '*\Get-VulnSchTask.ps1'
            - '*\Get-UnattendedInstallFile.ps1'
            - '*\Get-WebConfig.ps1'
            - '*\Get-ApplicationHost.ps1'
            - '*\Get-RegAlwaysInstallElevated.ps1'
            - '*\Get-Unconstrained.ps1'
            - '*\Add-RegBackdoor.ps1'
            - '*\Add-ScrnSaveBackdoor.ps1'
            - '*\Gupt-Backdoor.ps1'
            - '*\Invoke-ADSBackdoor.ps1'
            - '*\Enabled-DuplicateToken.ps1'
            - '*\Invoke-PsUaCme.ps1'
            - '*\Remove-Update.ps1'
            - '*\Check-VM.ps1'
            - '*\Get-LSASecret.ps1'
            - '*\Get-PassHashes.ps1'
            - '*\Show-TargetScreen.ps1'
            - '*\Port-Scan.ps1'
            - '*\Invoke-PoshRatHttp.ps1'
            - '*\Invoke-PowerShellTCP.ps1'
            - '*\Invoke-PowerShellWMI.ps1'
            - '*\Add-Exfiltration.ps1'
            - '*\Add-Persistence.ps1'
            - '*\Do-Exfiltration.ps1'
            - '*\Start-CaptureServer.ps1'
            - '*\Invoke-ShellCode.ps1'
            - '*\Get-ChromeDump.ps1'
            - '*\Get-ClipboardContents.ps1'
            - '*\Get-FoxDump.ps1'
            - '*\Get-IndexedItem.ps1'
            - '*\Get-Screenshot.ps1'
            - '*\Invoke-Inveigh.ps1'
            - '*\Invoke-NetRipper.ps1'
            - '*\Invoke-EgressCheck.ps1'
            - '*\Invoke-PostExfil.ps1'
            - '*\Invoke-PSInject.ps1'
            - '*\Invoke-RunAs.ps1'
            - '*\MailRaider.ps1'
            - '*\New-HoneyHash.ps1'
            - '*\Set-MacAttribute.ps1'
            - '*\Invoke-DCSync.ps1'
            - '*\Invoke-PowerDump.ps1'
            - '*\Exploit-Jboss.ps1'
            - '*\Invoke-ThunderStruck.ps1'
            - '*\Invoke-VoiceTroll.ps1'
            - '*\Set-Wallpaper.ps1'
            - '*\Invoke-InveighRelay.ps1'
            - '*\Invoke-PsExec.ps1'
            - '*\Invoke-SSHCommand.ps1'
            - '*\Get-SecurityPackages.ps1'
            - '*\Install-SSP.ps1'
            - '*\Invoke-BackdoorLNK.ps1'
            - '*\PowerBreach.ps1'
            - '*\Get-SiteListPassword.ps1'
            - '*\Get-System.ps1'
            - '*\Invoke-BypassUAC.ps1'
            - '*\Invoke-Tater.ps1'
            - '*\Invoke-WScriptBypassUAC.ps1'
            - '*\PowerUp.ps1'
            - '*\PowerView.ps1'
            - '*\Get-RickAstley.ps1'
            - '*\Find-Fruit.ps1'
            - '*\HTTP-Login.ps1'
            - '*\Find-TrustedDocuments.ps1'
            - '*\Invoke-Paranoia.ps1'
            - '*\Invoke-WinEnum.ps1'
            - '*\Invoke-ARPScan.ps1'
            - '*\Invoke-PortScan.ps1'
            - '*\Invoke-ReverseDNSLookup.ps1'
            - '*\Invoke-SMBScanner.ps1'
            - '*\Invoke-Mimikittenz.ps1'
    condition: selection
falsepositives:
    - Penetration Tests
level: high
        

```





### powershell
    
```
Get-WinEvent -LogName Microsoft-Windows-Sysmon/Operational | where {($_.ID -eq "11" -and ($_.message -match "TargetFilename.*.*\\Invoke-DllInjection.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-WmiCommand.ps1" -or $_.message -match "TargetFilename.*.*\\Get-GPPPassword.ps1" -or $_.message -match "TargetFilename.*.*\\Get-Keystrokes.ps1" -or $_.message -match "TargetFilename.*.*\\Get-VaultCredential.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-CredentialInjection.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-Mimikatz.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-NinjaCopy.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-TokenManipulation.ps1" -or $_.message -match "TargetFilename.*.*\\Out-Minidump.ps1" -or $_.message -match "TargetFilename.*.*\\VolumeShadowCopyTools.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-ReflectivePEInjection.ps1" -or $_.message -match "TargetFilename.*.*\\Get-TimedScreenshot.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-UserHunter.ps1" -or $_.message -match "TargetFilename.*.*\\Find-GPOLocation.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-ACLScanner.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-DowngradeAccount.ps1" -or $_.message -match "TargetFilename.*.*\\Get-ServiceUnquoted.ps1" -or $_.message -match "TargetFilename.*.*\\Get-ServiceFilePermission.ps1" -or $_.message -match "TargetFilename.*.*\\Get-ServicePermission.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-ServiceAbuse.ps1" -or $_.message -match "TargetFilename.*.*\\Install-ServiceBinary.ps1" -or $_.message -match "TargetFilename.*.*\\Get-RegAutoLogon.ps1" -or $_.message -match "TargetFilename.*.*\\Get-VulnAutoRun.ps1" -or $_.message -match "TargetFilename.*.*\\Get-VulnSchTask.ps1" -or $_.message -match "TargetFilename.*.*\\Get-UnattendedInstallFile.ps1" -or $_.message -match "TargetFilename.*.*\\Get-WebConfig.ps1" -or $_.message -match "TargetFilename.*.*\\Get-ApplicationHost.ps1" -or $_.message -match "TargetFilename.*.*\\Get-RegAlwaysInstallElevated.ps1" -or $_.message -match "TargetFilename.*.*\\Get-Unconstrained.ps1" -or $_.message -match "TargetFilename.*.*\\Add-RegBackdoor.ps1" -or $_.message -match "TargetFilename.*.*\\Add-ScrnSaveBackdoor.ps1" -or $_.message -match "TargetFilename.*.*\\Gupt-Backdoor.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-ADSBackdoor.ps1" -or $_.message -match "TargetFilename.*.*\\Enabled-DuplicateToken.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-PsUaCme.ps1" -or $_.message -match "TargetFilename.*.*\\Remove-Update.ps1" -or $_.message -match "TargetFilename.*.*\\Check-VM.ps1" -or $_.message -match "TargetFilename.*.*\\Get-LSASecret.ps1" -or $_.message -match "TargetFilename.*.*\\Get-PassHashes.ps1" -or $_.message -match "TargetFilename.*.*\\Show-TargetScreen.ps1" -or $_.message -match "TargetFilename.*.*\\Port-Scan.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-PoshRatHttp.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-PowerShellTCP.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-PowerShellWMI.ps1" -or $_.message -match "TargetFilename.*.*\\Add-Exfiltration.ps1" -or $_.message -match "TargetFilename.*.*\\Add-Persistence.ps1" -or $_.message -match "TargetFilename.*.*\\Do-Exfiltration.ps1" -or $_.message -match "TargetFilename.*.*\\Start-CaptureServer.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-ShellCode.ps1" -or $_.message -match "TargetFilename.*.*\\Get-ChromeDump.ps1" -or $_.message -match "TargetFilename.*.*\\Get-ClipboardContents.ps1" -or $_.message -match "TargetFilename.*.*\\Get-FoxDump.ps1" -or $_.message -match "TargetFilename.*.*\\Get-IndexedItem.ps1" -or $_.message -match "TargetFilename.*.*\\Get-Screenshot.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-Inveigh.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-NetRipper.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-EgressCheck.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-PostExfil.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-PSInject.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-RunAs.ps1" -or $_.message -match "TargetFilename.*.*\\MailRaider.ps1" -or $_.message -match "TargetFilename.*.*\\New-HoneyHash.ps1" -or $_.message -match "TargetFilename.*.*\\Set-MacAttribute.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-DCSync.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-PowerDump.ps1" -or $_.message -match "TargetFilename.*.*\\Exploit-Jboss.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-ThunderStruck.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-VoiceTroll.ps1" -or $_.message -match "TargetFilename.*.*\\Set-Wallpaper.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-InveighRelay.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-PsExec.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-SSHCommand.ps1" -or $_.message -match "TargetFilename.*.*\\Get-SecurityPackages.ps1" -or $_.message -match "TargetFilename.*.*\\Install-SSP.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-BackdoorLNK.ps1" -or $_.message -match "TargetFilename.*.*\\PowerBreach.ps1" -or $_.message -match "TargetFilename.*.*\\Get-SiteListPassword.ps1" -or $_.message -match "TargetFilename.*.*\\Get-System.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-BypassUAC.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-Tater.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-WScriptBypassUAC.ps1" -or $_.message -match "TargetFilename.*.*\\PowerUp.ps1" -or $_.message -match "TargetFilename.*.*\\PowerView.ps1" -or $_.message -match "TargetFilename.*.*\\Get-RickAstley.ps1" -or $_.message -match "TargetFilename.*.*\\Find-Fruit.ps1" -or $_.message -match "TargetFilename.*.*\\HTTP-Login.ps1" -or $_.message -match "TargetFilename.*.*\\Find-TrustedDocuments.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-Paranoia.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-WinEnum.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-ARPScan.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-PortScan.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-ReverseDNSLookup.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-SMBScanner.ps1" -or $_.message -match "TargetFilename.*.*\\Invoke-Mimikittenz.ps1")) } | select TimeCreated,Id,RecordId,ProcessId,MachineName,Message
```


### es-qs
    
```
(winlog.channel:"Microsoft\-Windows\-Sysmon\/Operational" AND winlog.event_id:"11" AND winlog.event_data.TargetFilename.keyword:(*\\Invoke\-DllInjection.ps1 OR *\\Invoke\-WmiCommand.ps1 OR *\\Get\-GPPPassword.ps1 OR *\\Get\-Keystrokes.ps1 OR *\\Get\-VaultCredential.ps1 OR *\\Invoke\-CredentialInjection.ps1 OR *\\Invoke\-Mimikatz.ps1 OR *\\Invoke\-NinjaCopy.ps1 OR *\\Invoke\-TokenManipulation.ps1 OR *\\Out\-Minidump.ps1 OR *\\VolumeShadowCopyTools.ps1 OR *\\Invoke\-ReflectivePEInjection.ps1 OR *\\Get\-TimedScreenshot.ps1 OR *\\Invoke\-UserHunter.ps1 OR *\\Find\-GPOLocation.ps1 OR *\\Invoke\-ACLScanner.ps1 OR *\\Invoke\-DowngradeAccount.ps1 OR *\\Get\-ServiceUnquoted.ps1 OR *\\Get\-ServiceFilePermission.ps1 OR *\\Get\-ServicePermission.ps1 OR *\\Invoke\-ServiceAbuse.ps1 OR *\\Install\-ServiceBinary.ps1 OR *\\Get\-RegAutoLogon.ps1 OR *\\Get\-VulnAutoRun.ps1 OR *\\Get\-VulnSchTask.ps1 OR *\\Get\-UnattendedInstallFile.ps1 OR *\\Get\-WebConfig.ps1 OR *\\Get\-ApplicationHost.ps1 OR *\\Get\-RegAlwaysInstallElevated.ps1 OR *\\Get\-Unconstrained.ps1 OR *\\Add\-RegBackdoor.ps1 OR *\\Add\-ScrnSaveBackdoor.ps1 OR *\\Gupt\-Backdoor.ps1 OR *\\Invoke\-ADSBackdoor.ps1 OR *\\Enabled\-DuplicateToken.ps1 OR *\\Invoke\-PsUaCme.ps1 OR *\\Remove\-Update.ps1 OR *\\Check\-VM.ps1 OR *\\Get\-LSASecret.ps1 OR *\\Get\-PassHashes.ps1 OR *\\Show\-TargetScreen.ps1 OR *\\Port\-Scan.ps1 OR *\\Invoke\-PoshRatHttp.ps1 OR *\\Invoke\-PowerShellTCP.ps1 OR *\\Invoke\-PowerShellWMI.ps1 OR *\\Add\-Exfiltration.ps1 OR *\\Add\-Persistence.ps1 OR *\\Do\-Exfiltration.ps1 OR *\\Start\-CaptureServer.ps1 OR *\\Invoke\-ShellCode.ps1 OR *\\Get\-ChromeDump.ps1 OR *\\Get\-ClipboardContents.ps1 OR *\\Get\-FoxDump.ps1 OR *\\Get\-IndexedItem.ps1 OR *\\Get\-Screenshot.ps1 OR *\\Invoke\-Inveigh.ps1 OR *\\Invoke\-NetRipper.ps1 OR *\\Invoke\-EgressCheck.ps1 OR *\\Invoke\-PostExfil.ps1 OR *\\Invoke\-PSInject.ps1 OR *\\Invoke\-RunAs.ps1 OR *\\MailRaider.ps1 OR *\\New\-HoneyHash.ps1 OR *\\Set\-MacAttribute.ps1 OR *\\Invoke\-DCSync.ps1 OR *\\Invoke\-PowerDump.ps1 OR *\\Exploit\-Jboss.ps1 OR *\\Invoke\-ThunderStruck.ps1 OR *\\Invoke\-VoiceTroll.ps1 OR *\\Set\-Wallpaper.ps1 OR *\\Invoke\-InveighRelay.ps1 OR *\\Invoke\-PsExec.ps1 OR *\\Invoke\-SSHCommand.ps1 OR *\\Get\-SecurityPackages.ps1 OR *\\Install\-SSP.ps1 OR *\\Invoke\-BackdoorLNK.ps1 OR *\\PowerBreach.ps1 OR *\\Get\-SiteListPassword.ps1 OR *\\Get\-System.ps1 OR *\\Invoke\-BypassUAC.ps1 OR *\\Invoke\-Tater.ps1 OR *\\Invoke\-WScriptBypassUAC.ps1 OR *\\PowerUp.ps1 OR *\\PowerView.ps1 OR *\\Get\-RickAstley.ps1 OR *\\Find\-Fruit.ps1 OR *\\HTTP\-Login.ps1 OR *\\Find\-TrustedDocuments.ps1 OR *\\Invoke\-Paranoia.ps1 OR *\\Invoke\-WinEnum.ps1 OR *\\Invoke\-ARPScan.ps1 OR *\\Invoke\-PortScan.ps1 OR *\\Invoke\-ReverseDNSLookup.ps1 OR *\\Invoke\-SMBScanner.ps1 OR *\\Invoke\-Mimikittenz.ps1))
```


### xpack-watcher
    
```
curl -s -XPUT -H 'Content-Type: application/json' --data-binary @- localhost:9200/_watcher/watch/f331aa1f-8c53-4fc3-b083-cc159bc971cb <<EOF
{
  "metadata": {
    "title": "Malicious PowerShell Commandlet Names",
    "description": "Detects the creation of known powershell scripts for exploitation",
    "tags": [
      "attack.execution",
      "attack.t1086"
    ],
    "query": "(winlog.channel:\"Microsoft\\-Windows\\-Sysmon\\/Operational\" AND winlog.event_id:\"11\" AND winlog.event_data.TargetFilename.keyword:(*\\\\Invoke\\-DllInjection.ps1 OR *\\\\Invoke\\-WmiCommand.ps1 OR *\\\\Get\\-GPPPassword.ps1 OR *\\\\Get\\-Keystrokes.ps1 OR *\\\\Get\\-VaultCredential.ps1 OR *\\\\Invoke\\-CredentialInjection.ps1 OR *\\\\Invoke\\-Mimikatz.ps1 OR *\\\\Invoke\\-NinjaCopy.ps1 OR *\\\\Invoke\\-TokenManipulation.ps1 OR *\\\\Out\\-Minidump.ps1 OR *\\\\VolumeShadowCopyTools.ps1 OR *\\\\Invoke\\-ReflectivePEInjection.ps1 OR *\\\\Get\\-TimedScreenshot.ps1 OR *\\\\Invoke\\-UserHunter.ps1 OR *\\\\Find\\-GPOLocation.ps1 OR *\\\\Invoke\\-ACLScanner.ps1 OR *\\\\Invoke\\-DowngradeAccount.ps1 OR *\\\\Get\\-ServiceUnquoted.ps1 OR *\\\\Get\\-ServiceFilePermission.ps1 OR *\\\\Get\\-ServicePermission.ps1 OR *\\\\Invoke\\-ServiceAbuse.ps1 OR *\\\\Install\\-ServiceBinary.ps1 OR *\\\\Get\\-RegAutoLogon.ps1 OR *\\\\Get\\-VulnAutoRun.ps1 OR *\\\\Get\\-VulnSchTask.ps1 OR *\\\\Get\\-UnattendedInstallFile.ps1 OR *\\\\Get\\-WebConfig.ps1 OR *\\\\Get\\-ApplicationHost.ps1 OR *\\\\Get\\-RegAlwaysInstallElevated.ps1 OR *\\\\Get\\-Unconstrained.ps1 OR *\\\\Add\\-RegBackdoor.ps1 OR *\\\\Add\\-ScrnSaveBackdoor.ps1 OR *\\\\Gupt\\-Backdoor.ps1 OR *\\\\Invoke\\-ADSBackdoor.ps1 OR *\\\\Enabled\\-DuplicateToken.ps1 OR *\\\\Invoke\\-PsUaCme.ps1 OR *\\\\Remove\\-Update.ps1 OR *\\\\Check\\-VM.ps1 OR *\\\\Get\\-LSASecret.ps1 OR *\\\\Get\\-PassHashes.ps1 OR *\\\\Show\\-TargetScreen.ps1 OR *\\\\Port\\-Scan.ps1 OR *\\\\Invoke\\-PoshRatHttp.ps1 OR *\\\\Invoke\\-PowerShellTCP.ps1 OR *\\\\Invoke\\-PowerShellWMI.ps1 OR *\\\\Add\\-Exfiltration.ps1 OR *\\\\Add\\-Persistence.ps1 OR *\\\\Do\\-Exfiltration.ps1 OR *\\\\Start\\-CaptureServer.ps1 OR *\\\\Invoke\\-ShellCode.ps1 OR *\\\\Get\\-ChromeDump.ps1 OR *\\\\Get\\-ClipboardContents.ps1 OR *\\\\Get\\-FoxDump.ps1 OR *\\\\Get\\-IndexedItem.ps1 OR *\\\\Get\\-Screenshot.ps1 OR *\\\\Invoke\\-Inveigh.ps1 OR *\\\\Invoke\\-NetRipper.ps1 OR *\\\\Invoke\\-EgressCheck.ps1 OR *\\\\Invoke\\-PostExfil.ps1 OR *\\\\Invoke\\-PSInject.ps1 OR *\\\\Invoke\\-RunAs.ps1 OR *\\\\MailRaider.ps1 OR *\\\\New\\-HoneyHash.ps1 OR *\\\\Set\\-MacAttribute.ps1 OR *\\\\Invoke\\-DCSync.ps1 OR *\\\\Invoke\\-PowerDump.ps1 OR *\\\\Exploit\\-Jboss.ps1 OR *\\\\Invoke\\-ThunderStruck.ps1 OR *\\\\Invoke\\-VoiceTroll.ps1 OR *\\\\Set\\-Wallpaper.ps1 OR *\\\\Invoke\\-InveighRelay.ps1 OR *\\\\Invoke\\-PsExec.ps1 OR *\\\\Invoke\\-SSHCommand.ps1 OR *\\\\Get\\-SecurityPackages.ps1 OR *\\\\Install\\-SSP.ps1 OR *\\\\Invoke\\-BackdoorLNK.ps1 OR *\\\\PowerBreach.ps1 OR *\\\\Get\\-SiteListPassword.ps1 OR *\\\\Get\\-System.ps1 OR *\\\\Invoke\\-BypassUAC.ps1 OR *\\\\Invoke\\-Tater.ps1 OR *\\\\Invoke\\-WScriptBypassUAC.ps1 OR *\\\\PowerUp.ps1 OR *\\\\PowerView.ps1 OR *\\\\Get\\-RickAstley.ps1 OR *\\\\Find\\-Fruit.ps1 OR *\\\\HTTP\\-Login.ps1 OR *\\\\Find\\-TrustedDocuments.ps1 OR *\\\\Invoke\\-Paranoia.ps1 OR *\\\\Invoke\\-WinEnum.ps1 OR *\\\\Invoke\\-ARPScan.ps1 OR *\\\\Invoke\\-PortScan.ps1 OR *\\\\Invoke\\-ReverseDNSLookup.ps1 OR *\\\\Invoke\\-SMBScanner.ps1 OR *\\\\Invoke\\-Mimikittenz.ps1))"
  },
  "trigger": {
    "schedule": {
      "interval": "30m"
    }
  },
  "input": {
    "search": {
      "request": {
        "body": {
          "size": 0,
          "query": {
            "bool": {
              "must": [
                {
                  "query_string": {
                    "query": "(winlog.channel:\"Microsoft\\-Windows\\-Sysmon\\/Operational\" AND winlog.event_id:\"11\" AND winlog.event_data.TargetFilename.keyword:(*\\\\Invoke\\-DllInjection.ps1 OR *\\\\Invoke\\-WmiCommand.ps1 OR *\\\\Get\\-GPPPassword.ps1 OR *\\\\Get\\-Keystrokes.ps1 OR *\\\\Get\\-VaultCredential.ps1 OR *\\\\Invoke\\-CredentialInjection.ps1 OR *\\\\Invoke\\-Mimikatz.ps1 OR *\\\\Invoke\\-NinjaCopy.ps1 OR *\\\\Invoke\\-TokenManipulation.ps1 OR *\\\\Out\\-Minidump.ps1 OR *\\\\VolumeShadowCopyTools.ps1 OR *\\\\Invoke\\-ReflectivePEInjection.ps1 OR *\\\\Get\\-TimedScreenshot.ps1 OR *\\\\Invoke\\-UserHunter.ps1 OR *\\\\Find\\-GPOLocation.ps1 OR *\\\\Invoke\\-ACLScanner.ps1 OR *\\\\Invoke\\-DowngradeAccount.ps1 OR *\\\\Get\\-ServiceUnquoted.ps1 OR *\\\\Get\\-ServiceFilePermission.ps1 OR *\\\\Get\\-ServicePermission.ps1 OR *\\\\Invoke\\-ServiceAbuse.ps1 OR *\\\\Install\\-ServiceBinary.ps1 OR *\\\\Get\\-RegAutoLogon.ps1 OR *\\\\Get\\-VulnAutoRun.ps1 OR *\\\\Get\\-VulnSchTask.ps1 OR *\\\\Get\\-UnattendedInstallFile.ps1 OR *\\\\Get\\-WebConfig.ps1 OR *\\\\Get\\-ApplicationHost.ps1 OR *\\\\Get\\-RegAlwaysInstallElevated.ps1 OR *\\\\Get\\-Unconstrained.ps1 OR *\\\\Add\\-RegBackdoor.ps1 OR *\\\\Add\\-ScrnSaveBackdoor.ps1 OR *\\\\Gupt\\-Backdoor.ps1 OR *\\\\Invoke\\-ADSBackdoor.ps1 OR *\\\\Enabled\\-DuplicateToken.ps1 OR *\\\\Invoke\\-PsUaCme.ps1 OR *\\\\Remove\\-Update.ps1 OR *\\\\Check\\-VM.ps1 OR *\\\\Get\\-LSASecret.ps1 OR *\\\\Get\\-PassHashes.ps1 OR *\\\\Show\\-TargetScreen.ps1 OR *\\\\Port\\-Scan.ps1 OR *\\\\Invoke\\-PoshRatHttp.ps1 OR *\\\\Invoke\\-PowerShellTCP.ps1 OR *\\\\Invoke\\-PowerShellWMI.ps1 OR *\\\\Add\\-Exfiltration.ps1 OR *\\\\Add\\-Persistence.ps1 OR *\\\\Do\\-Exfiltration.ps1 OR *\\\\Start\\-CaptureServer.ps1 OR *\\\\Invoke\\-ShellCode.ps1 OR *\\\\Get\\-ChromeDump.ps1 OR *\\\\Get\\-ClipboardContents.ps1 OR *\\\\Get\\-FoxDump.ps1 OR *\\\\Get\\-IndexedItem.ps1 OR *\\\\Get\\-Screenshot.ps1 OR *\\\\Invoke\\-Inveigh.ps1 OR *\\\\Invoke\\-NetRipper.ps1 OR *\\\\Invoke\\-EgressCheck.ps1 OR *\\\\Invoke\\-PostExfil.ps1 OR *\\\\Invoke\\-PSInject.ps1 OR *\\\\Invoke\\-RunAs.ps1 OR *\\\\MailRaider.ps1 OR *\\\\New\\-HoneyHash.ps1 OR *\\\\Set\\-MacAttribute.ps1 OR *\\\\Invoke\\-DCSync.ps1 OR *\\\\Invoke\\-PowerDump.ps1 OR *\\\\Exploit\\-Jboss.ps1 OR *\\\\Invoke\\-ThunderStruck.ps1 OR *\\\\Invoke\\-VoiceTroll.ps1 OR *\\\\Set\\-Wallpaper.ps1 OR *\\\\Invoke\\-InveighRelay.ps1 OR *\\\\Invoke\\-PsExec.ps1 OR *\\\\Invoke\\-SSHCommand.ps1 OR *\\\\Get\\-SecurityPackages.ps1 OR *\\\\Install\\-SSP.ps1 OR *\\\\Invoke\\-BackdoorLNK.ps1 OR *\\\\PowerBreach.ps1 OR *\\\\Get\\-SiteListPassword.ps1 OR *\\\\Get\\-System.ps1 OR *\\\\Invoke\\-BypassUAC.ps1 OR *\\\\Invoke\\-Tater.ps1 OR *\\\\Invoke\\-WScriptBypassUAC.ps1 OR *\\\\PowerUp.ps1 OR *\\\\PowerView.ps1 OR *\\\\Get\\-RickAstley.ps1 OR *\\\\Find\\-Fruit.ps1 OR *\\\\HTTP\\-Login.ps1 OR *\\\\Find\\-TrustedDocuments.ps1 OR *\\\\Invoke\\-Paranoia.ps1 OR *\\\\Invoke\\-WinEnum.ps1 OR *\\\\Invoke\\-ARPScan.ps1 OR *\\\\Invoke\\-PortScan.ps1 OR *\\\\Invoke\\-ReverseDNSLookup.ps1 OR *\\\\Invoke\\-SMBScanner.ps1 OR *\\\\Invoke\\-Mimikittenz.ps1))",
                    "analyze_wildcard": true
                  }
                }
              ],
              "filter": {
                "range": {
                  "timestamp": {
                    "gte": "now-30m/m"
                  }
                }
              }
            }
          }
        },
        "indices": [
          "winlogbeat-*"
        ]
      }
    }
  },
  "condition": {
    "compare": {
      "ctx.payload.hits.total": {
        "not_eq": 0
      }
    }
  },
  "actions": {
    "send_email": {
      "email": {
        "to": "root@localhost",
        "subject": "Sigma Rule 'Malicious PowerShell Commandlet Names'",
        "body": "Hits:\n{{#ctx.payload.hits.hits}}{{_source}}\n================================================================================\n{{/ctx.payload.hits.hits}}",
        "attachments": {
          "data.json": {
            "data": {
              "format": "json"
            }
          }
        }
      }
    }
  }
}
EOF

```


### graylog
    
```
(EventID:"11" AND TargetFilename.keyword:(*\\Invoke\-DllInjection.ps1 *\\Invoke\-WmiCommand.ps1 *\\Get\-GPPPassword.ps1 *\\Get\-Keystrokes.ps1 *\\Get\-VaultCredential.ps1 *\\Invoke\-CredentialInjection.ps1 *\\Invoke\-Mimikatz.ps1 *\\Invoke\-NinjaCopy.ps1 *\\Invoke\-TokenManipulation.ps1 *\\Out\-Minidump.ps1 *\\VolumeShadowCopyTools.ps1 *\\Invoke\-ReflectivePEInjection.ps1 *\\Get\-TimedScreenshot.ps1 *\\Invoke\-UserHunter.ps1 *\\Find\-GPOLocation.ps1 *\\Invoke\-ACLScanner.ps1 *\\Invoke\-DowngradeAccount.ps1 *\\Get\-ServiceUnquoted.ps1 *\\Get\-ServiceFilePermission.ps1 *\\Get\-ServicePermission.ps1 *\\Invoke\-ServiceAbuse.ps1 *\\Install\-ServiceBinary.ps1 *\\Get\-RegAutoLogon.ps1 *\\Get\-VulnAutoRun.ps1 *\\Get\-VulnSchTask.ps1 *\\Get\-UnattendedInstallFile.ps1 *\\Get\-WebConfig.ps1 *\\Get\-ApplicationHost.ps1 *\\Get\-RegAlwaysInstallElevated.ps1 *\\Get\-Unconstrained.ps1 *\\Add\-RegBackdoor.ps1 *\\Add\-ScrnSaveBackdoor.ps1 *\\Gupt\-Backdoor.ps1 *\\Invoke\-ADSBackdoor.ps1 *\\Enabled\-DuplicateToken.ps1 *\\Invoke\-PsUaCme.ps1 *\\Remove\-Update.ps1 *\\Check\-VM.ps1 *\\Get\-LSASecret.ps1 *\\Get\-PassHashes.ps1 *\\Show\-TargetScreen.ps1 *\\Port\-Scan.ps1 *\\Invoke\-PoshRatHttp.ps1 *\\Invoke\-PowerShellTCP.ps1 *\\Invoke\-PowerShellWMI.ps1 *\\Add\-Exfiltration.ps1 *\\Add\-Persistence.ps1 *\\Do\-Exfiltration.ps1 *\\Start\-CaptureServer.ps1 *\\Invoke\-ShellCode.ps1 *\\Get\-ChromeDump.ps1 *\\Get\-ClipboardContents.ps1 *\\Get\-FoxDump.ps1 *\\Get\-IndexedItem.ps1 *\\Get\-Screenshot.ps1 *\\Invoke\-Inveigh.ps1 *\\Invoke\-NetRipper.ps1 *\\Invoke\-EgressCheck.ps1 *\\Invoke\-PostExfil.ps1 *\\Invoke\-PSInject.ps1 *\\Invoke\-RunAs.ps1 *\\MailRaider.ps1 *\\New\-HoneyHash.ps1 *\\Set\-MacAttribute.ps1 *\\Invoke\-DCSync.ps1 *\\Invoke\-PowerDump.ps1 *\\Exploit\-Jboss.ps1 *\\Invoke\-ThunderStruck.ps1 *\\Invoke\-VoiceTroll.ps1 *\\Set\-Wallpaper.ps1 *\\Invoke\-InveighRelay.ps1 *\\Invoke\-PsExec.ps1 *\\Invoke\-SSHCommand.ps1 *\\Get\-SecurityPackages.ps1 *\\Install\-SSP.ps1 *\\Invoke\-BackdoorLNK.ps1 *\\PowerBreach.ps1 *\\Get\-SiteListPassword.ps1 *\\Get\-System.ps1 *\\Invoke\-BypassUAC.ps1 *\\Invoke\-Tater.ps1 *\\Invoke\-WScriptBypassUAC.ps1 *\\PowerUp.ps1 *\\PowerView.ps1 *\\Get\-RickAstley.ps1 *\\Find\-Fruit.ps1 *\\HTTP\-Login.ps1 *\\Find\-TrustedDocuments.ps1 *\\Invoke\-Paranoia.ps1 *\\Invoke\-WinEnum.ps1 *\\Invoke\-ARPScan.ps1 *\\Invoke\-PortScan.ps1 *\\Invoke\-ReverseDNSLookup.ps1 *\\Invoke\-SMBScanner.ps1 *\\Invoke\-Mimikittenz.ps1))
```


### splunk
    
```
(source="WinEventLog:Microsoft-Windows-Sysmon/Operational" EventCode="11" (TargetFilename="*\\Invoke-DllInjection.ps1" OR TargetFilename="*\\Invoke-WmiCommand.ps1" OR TargetFilename="*\\Get-GPPPassword.ps1" OR TargetFilename="*\\Get-Keystrokes.ps1" OR TargetFilename="*\\Get-VaultCredential.ps1" OR TargetFilename="*\\Invoke-CredentialInjection.ps1" OR TargetFilename="*\\Invoke-Mimikatz.ps1" OR TargetFilename="*\\Invoke-NinjaCopy.ps1" OR TargetFilename="*\\Invoke-TokenManipulation.ps1" OR TargetFilename="*\\Out-Minidump.ps1" OR TargetFilename="*\\VolumeShadowCopyTools.ps1" OR TargetFilename="*\\Invoke-ReflectivePEInjection.ps1" OR TargetFilename="*\\Get-TimedScreenshot.ps1" OR TargetFilename="*\\Invoke-UserHunter.ps1" OR TargetFilename="*\\Find-GPOLocation.ps1" OR TargetFilename="*\\Invoke-ACLScanner.ps1" OR TargetFilename="*\\Invoke-DowngradeAccount.ps1" OR TargetFilename="*\\Get-ServiceUnquoted.ps1" OR TargetFilename="*\\Get-ServiceFilePermission.ps1" OR TargetFilename="*\\Get-ServicePermission.ps1" OR TargetFilename="*\\Invoke-ServiceAbuse.ps1" OR TargetFilename="*\\Install-ServiceBinary.ps1" OR TargetFilename="*\\Get-RegAutoLogon.ps1" OR TargetFilename="*\\Get-VulnAutoRun.ps1" OR TargetFilename="*\\Get-VulnSchTask.ps1" OR TargetFilename="*\\Get-UnattendedInstallFile.ps1" OR TargetFilename="*\\Get-WebConfig.ps1" OR TargetFilename="*\\Get-ApplicationHost.ps1" OR TargetFilename="*\\Get-RegAlwaysInstallElevated.ps1" OR TargetFilename="*\\Get-Unconstrained.ps1" OR TargetFilename="*\\Add-RegBackdoor.ps1" OR TargetFilename="*\\Add-ScrnSaveBackdoor.ps1" OR TargetFilename="*\\Gupt-Backdoor.ps1" OR TargetFilename="*\\Invoke-ADSBackdoor.ps1" OR TargetFilename="*\\Enabled-DuplicateToken.ps1" OR TargetFilename="*\\Invoke-PsUaCme.ps1" OR TargetFilename="*\\Remove-Update.ps1" OR TargetFilename="*\\Check-VM.ps1" OR TargetFilename="*\\Get-LSASecret.ps1" OR TargetFilename="*\\Get-PassHashes.ps1" OR TargetFilename="*\\Show-TargetScreen.ps1" OR TargetFilename="*\\Port-Scan.ps1" OR TargetFilename="*\\Invoke-PoshRatHttp.ps1" OR TargetFilename="*\\Invoke-PowerShellTCP.ps1" OR TargetFilename="*\\Invoke-PowerShellWMI.ps1" OR TargetFilename="*\\Add-Exfiltration.ps1" OR TargetFilename="*\\Add-Persistence.ps1" OR TargetFilename="*\\Do-Exfiltration.ps1" OR TargetFilename="*\\Start-CaptureServer.ps1" OR TargetFilename="*\\Invoke-ShellCode.ps1" OR TargetFilename="*\\Get-ChromeDump.ps1" OR TargetFilename="*\\Get-ClipboardContents.ps1" OR TargetFilename="*\\Get-FoxDump.ps1" OR TargetFilename="*\\Get-IndexedItem.ps1" OR TargetFilename="*\\Get-Screenshot.ps1" OR TargetFilename="*\\Invoke-Inveigh.ps1" OR TargetFilename="*\\Invoke-NetRipper.ps1" OR TargetFilename="*\\Invoke-EgressCheck.ps1" OR TargetFilename="*\\Invoke-PostExfil.ps1" OR TargetFilename="*\\Invoke-PSInject.ps1" OR TargetFilename="*\\Invoke-RunAs.ps1" OR TargetFilename="*\\MailRaider.ps1" OR TargetFilename="*\\New-HoneyHash.ps1" OR TargetFilename="*\\Set-MacAttribute.ps1" OR TargetFilename="*\\Invoke-DCSync.ps1" OR TargetFilename="*\\Invoke-PowerDump.ps1" OR TargetFilename="*\\Exploit-Jboss.ps1" OR TargetFilename="*\\Invoke-ThunderStruck.ps1" OR TargetFilename="*\\Invoke-VoiceTroll.ps1" OR TargetFilename="*\\Set-Wallpaper.ps1" OR TargetFilename="*\\Invoke-InveighRelay.ps1" OR TargetFilename="*\\Invoke-PsExec.ps1" OR TargetFilename="*\\Invoke-SSHCommand.ps1" OR TargetFilename="*\\Get-SecurityPackages.ps1" OR TargetFilename="*\\Install-SSP.ps1" OR TargetFilename="*\\Invoke-BackdoorLNK.ps1" OR TargetFilename="*\\PowerBreach.ps1" OR TargetFilename="*\\Get-SiteListPassword.ps1" OR TargetFilename="*\\Get-System.ps1" OR TargetFilename="*\\Invoke-BypassUAC.ps1" OR TargetFilename="*\\Invoke-Tater.ps1" OR TargetFilename="*\\Invoke-WScriptBypassUAC.ps1" OR TargetFilename="*\\PowerUp.ps1" OR TargetFilename="*\\PowerView.ps1" OR TargetFilename="*\\Get-RickAstley.ps1" OR TargetFilename="*\\Find-Fruit.ps1" OR TargetFilename="*\\HTTP-Login.ps1" OR TargetFilename="*\\Find-TrustedDocuments.ps1" OR TargetFilename="*\\Invoke-Paranoia.ps1" OR TargetFilename="*\\Invoke-WinEnum.ps1" OR TargetFilename="*\\Invoke-ARPScan.ps1" OR TargetFilename="*\\Invoke-PortScan.ps1" OR TargetFilename="*\\Invoke-ReverseDNSLookup.ps1" OR TargetFilename="*\\Invoke-SMBScanner.ps1" OR TargetFilename="*\\Invoke-Mimikittenz.ps1"))
```


### logpoint
    
```
(event_id="11" TargetFilename IN ["*\\Invoke-DllInjection.ps1", "*\\Invoke-WmiCommand.ps1", "*\\Get-GPPPassword.ps1", "*\\Get-Keystrokes.ps1", "*\\Get-VaultCredential.ps1", "*\\Invoke-CredentialInjection.ps1", "*\\Invoke-Mimikatz.ps1", "*\\Invoke-NinjaCopy.ps1", "*\\Invoke-TokenManipulation.ps1", "*\\Out-Minidump.ps1", "*\\VolumeShadowCopyTools.ps1", "*\\Invoke-ReflectivePEInjection.ps1", "*\\Get-TimedScreenshot.ps1", "*\\Invoke-UserHunter.ps1", "*\\Find-GPOLocation.ps1", "*\\Invoke-ACLScanner.ps1", "*\\Invoke-DowngradeAccount.ps1", "*\\Get-ServiceUnquoted.ps1", "*\\Get-ServiceFilePermission.ps1", "*\\Get-ServicePermission.ps1", "*\\Invoke-ServiceAbuse.ps1", "*\\Install-ServiceBinary.ps1", "*\\Get-RegAutoLogon.ps1", "*\\Get-VulnAutoRun.ps1", "*\\Get-VulnSchTask.ps1", "*\\Get-UnattendedInstallFile.ps1", "*\\Get-WebConfig.ps1", "*\\Get-ApplicationHost.ps1", "*\\Get-RegAlwaysInstallElevated.ps1", "*\\Get-Unconstrained.ps1", "*\\Add-RegBackdoor.ps1", "*\\Add-ScrnSaveBackdoor.ps1", "*\\Gupt-Backdoor.ps1", "*\\Invoke-ADSBackdoor.ps1", "*\\Enabled-DuplicateToken.ps1", "*\\Invoke-PsUaCme.ps1", "*\\Remove-Update.ps1", "*\\Check-VM.ps1", "*\\Get-LSASecret.ps1", "*\\Get-PassHashes.ps1", "*\\Show-TargetScreen.ps1", "*\\Port-Scan.ps1", "*\\Invoke-PoshRatHttp.ps1", "*\\Invoke-PowerShellTCP.ps1", "*\\Invoke-PowerShellWMI.ps1", "*\\Add-Exfiltration.ps1", "*\\Add-Persistence.ps1", "*\\Do-Exfiltration.ps1", "*\\Start-CaptureServer.ps1", "*\\Invoke-ShellCode.ps1", "*\\Get-ChromeDump.ps1", "*\\Get-ClipboardContents.ps1", "*\\Get-FoxDump.ps1", "*\\Get-IndexedItem.ps1", "*\\Get-Screenshot.ps1", "*\\Invoke-Inveigh.ps1", "*\\Invoke-NetRipper.ps1", "*\\Invoke-EgressCheck.ps1", "*\\Invoke-PostExfil.ps1", "*\\Invoke-PSInject.ps1", "*\\Invoke-RunAs.ps1", "*\\MailRaider.ps1", "*\\New-HoneyHash.ps1", "*\\Set-MacAttribute.ps1", "*\\Invoke-DCSync.ps1", "*\\Invoke-PowerDump.ps1", "*\\Exploit-Jboss.ps1", "*\\Invoke-ThunderStruck.ps1", "*\\Invoke-VoiceTroll.ps1", "*\\Set-Wallpaper.ps1", "*\\Invoke-InveighRelay.ps1", "*\\Invoke-PsExec.ps1", "*\\Invoke-SSHCommand.ps1", "*\\Get-SecurityPackages.ps1", "*\\Install-SSP.ps1", "*\\Invoke-BackdoorLNK.ps1", "*\\PowerBreach.ps1", "*\\Get-SiteListPassword.ps1", "*\\Get-System.ps1", "*\\Invoke-BypassUAC.ps1", "*\\Invoke-Tater.ps1", "*\\Invoke-WScriptBypassUAC.ps1", "*\\PowerUp.ps1", "*\\PowerView.ps1", "*\\Get-RickAstley.ps1", "*\\Find-Fruit.ps1", "*\\HTTP-Login.ps1", "*\\Find-TrustedDocuments.ps1", "*\\Invoke-Paranoia.ps1", "*\\Invoke-WinEnum.ps1", "*\\Invoke-ARPScan.ps1", "*\\Invoke-PortScan.ps1", "*\\Invoke-ReverseDNSLookup.ps1", "*\\Invoke-SMBScanner.ps1", "*\\Invoke-Mimikittenz.ps1"])
```


### grep
    
```
grep -P '^(?:.*(?=.*11)(?=.*(?:.*.*\Invoke-DllInjection\.ps1|.*.*\Invoke-WmiCommand\.ps1|.*.*\Get-GPPPassword\.ps1|.*.*\Get-Keystrokes\.ps1|.*.*\Get-VaultCredential\.ps1|.*.*\Invoke-CredentialInjection\.ps1|.*.*\Invoke-Mimikatz\.ps1|.*.*\Invoke-NinjaCopy\.ps1|.*.*\Invoke-TokenManipulation\.ps1|.*.*\Out-Minidump\.ps1|.*.*\VolumeShadowCopyTools\.ps1|.*.*\Invoke-ReflectivePEInjection\.ps1|.*.*\Get-TimedScreenshot\.ps1|.*.*\Invoke-UserHunter\.ps1|.*.*\Find-GPOLocation\.ps1|.*.*\Invoke-ACLScanner\.ps1|.*.*\Invoke-DowngradeAccount\.ps1|.*.*\Get-ServiceUnquoted\.ps1|.*.*\Get-ServiceFilePermission\.ps1|.*.*\Get-ServicePermission\.ps1|.*.*\Invoke-ServiceAbuse\.ps1|.*.*\Install-ServiceBinary\.ps1|.*.*\Get-RegAutoLogon\.ps1|.*.*\Get-VulnAutoRun\.ps1|.*.*\Get-VulnSchTask\.ps1|.*.*\Get-UnattendedInstallFile\.ps1|.*.*\Get-WebConfig\.ps1|.*.*\Get-ApplicationHost\.ps1|.*.*\Get-RegAlwaysInstallElevated\.ps1|.*.*\Get-Unconstrained\.ps1|.*.*\Add-RegBackdoor\.ps1|.*.*\Add-ScrnSaveBackdoor\.ps1|.*.*\Gupt-Backdoor\.ps1|.*.*\Invoke-ADSBackdoor\.ps1|.*.*\Enabled-DuplicateToken\.ps1|.*.*\Invoke-PsUaCme\.ps1|.*.*\Remove-Update\.ps1|.*.*\Check-VM\.ps1|.*.*\Get-LSASecret\.ps1|.*.*\Get-PassHashes\.ps1|.*.*\Show-TargetScreen\.ps1|.*.*\Port-Scan\.ps1|.*.*\Invoke-PoshRatHttp\.ps1|.*.*\Invoke-PowerShellTCP\.ps1|.*.*\Invoke-PowerShellWMI\.ps1|.*.*\Add-Exfiltration\.ps1|.*.*\Add-Persistence\.ps1|.*.*\Do-Exfiltration\.ps1|.*.*\Start-CaptureServer\.ps1|.*.*\Invoke-ShellCode\.ps1|.*.*\Get-ChromeDump\.ps1|.*.*\Get-ClipboardContents\.ps1|.*.*\Get-FoxDump\.ps1|.*.*\Get-IndexedItem\.ps1|.*.*\Get-Screenshot\.ps1|.*.*\Invoke-Inveigh\.ps1|.*.*\Invoke-NetRipper\.ps1|.*.*\Invoke-EgressCheck\.ps1|.*.*\Invoke-PostExfil\.ps1|.*.*\Invoke-PSInject\.ps1|.*.*\Invoke-RunAs\.ps1|.*.*\MailRaider\.ps1|.*.*\New-HoneyHash\.ps1|.*.*\Set-MacAttribute\.ps1|.*.*\Invoke-DCSync\.ps1|.*.*\Invoke-PowerDump\.ps1|.*.*\Exploit-Jboss\.ps1|.*.*\Invoke-ThunderStruck\.ps1|.*.*\Invoke-VoiceTroll\.ps1|.*.*\Set-Wallpaper\.ps1|.*.*\Invoke-InveighRelay\.ps1|.*.*\Invoke-PsExec\.ps1|.*.*\Invoke-SSHCommand\.ps1|.*.*\Get-SecurityPackages\.ps1|.*.*\Install-SSP\.ps1|.*.*\Invoke-BackdoorLNK\.ps1|.*.*\PowerBreach\.ps1|.*.*\Get-SiteListPassword\.ps1|.*.*\Get-System\.ps1|.*.*\Invoke-BypassUAC\.ps1|.*.*\Invoke-Tater\.ps1|.*.*\Invoke-WScriptBypassUAC\.ps1|.*.*\PowerUp\.ps1|.*.*\PowerView\.ps1|.*.*\Get-RickAstley\.ps1|.*.*\Find-Fruit\.ps1|.*.*\HTTP-Login\.ps1|.*.*\Find-TrustedDocuments\.ps1|.*.*\Invoke-Paranoia\.ps1|.*.*\Invoke-WinEnum\.ps1|.*.*\Invoke-ARPScan\.ps1|.*.*\Invoke-PortScan\.ps1|.*.*\Invoke-ReverseDNSLookup\.ps1|.*.*\Invoke-SMBScanner\.ps1|.*.*\Invoke-Mimikittenz\.ps1)))'
```



