| Title                    | Exploit for CVE-2017-0261       |
|:-------------------------|:------------------|
| **Description**          | Detects Winword starting uncommon sub process FLTLDR.exe as used in exploits for CVE-2017-0261 and CVE-2017-0262 |
| **ATT&amp;CK Tactic**    |  <ul><li>[TA0005: Defense Evasion](https://attack.mitre.org/tactics/TA0005)</li><li>[TA0004: Privilege Escalation](https://attack.mitre.org/tactics/TA0004)</li></ul>  |
| **ATT&amp;CK Technique** | <ul><li>[T1055: Process Injection](https://attack.mitre.org/techniques/T1055)</li></ul>  |
| **Data Needed**          | <ul><li>[DN_0002_4688_windows_process_creation_with_commandline](../Data_Needed/DN_0002_4688_windows_process_creation_with_commandline.md)</li><li>[DN_0003_1_windows_sysmon_process_creation](../Data_Needed/DN_0003_1_windows_sysmon_process_creation.md)</li></ul>  |
| **Trigger**              | <ul><li>[T1055: Process Injection](../Triggers/T1055.md)</li></ul>  |
| **Severity Level**       | medium |
| **False Positives**      | <ul><li>Several false positives identified, check for suspicious file names or locations (e.g. Temp folders)</li></ul>  |
| **Development Status**   | experimental |
| **References**           | <ul><li>[https://www.fireeye.com/blog/threat-research/2017/05/eps-processing-zero-days.html](https://www.fireeye.com/blog/threat-research/2017/05/eps-processing-zero-days.html)</li></ul>  |
| **Author**               | Florian Roth |


## Detection Rules

### Sigma rule

```
title: Exploit for CVE-2017-0261
id: 864403a1-36c9-40a2-a982-4c9a45f7d833
status: experimental
description: Detects Winword starting uncommon sub process FLTLDR.exe as used in exploits for CVE-2017-0261 and CVE-2017-0262
references:
    - https://www.fireeye.com/blog/threat-research/2017/05/eps-processing-zero-days.html
author: Florian Roth
date: 2018/02/22
tags:
  - attack.defense_evasion
  - attack.privilege_escalation
  - attack.t1055
logsource:
    category: process_creation
    product: windows
detection:
    selection:
        ParentImage: '*\WINWORD.EXE'
        Image: '*\FLTLDR.exe*'
    condition: selection
falsepositives:
    - Several false positives identified, check for suspicious file names or locations (e.g. Temp folders)
level: medium

```





### powershell
    
```
Get-WinEvent | where {($_.message -match "ParentImage.*.*\\WINWORD.EXE" -and $_.message -match "Image.*.*\\FLTLDR.exe.*") } | select TimeCreated,Id,RecordId,ProcessId,MachineName,Message
```


### es-qs
    
```
(winlog.event_data.ParentImage.keyword:*\\WINWORD.EXE AND winlog.event_data.Image.keyword:*\\FLTLDR.exe*)
```


### xpack-watcher
    
```
curl -s -XPUT -H 'Content-Type: application/json' --data-binary @- localhost:9200/_watcher/watch/864403a1-36c9-40a2-a982-4c9a45f7d833 <<EOF
{
  "metadata": {
    "title": "Exploit for CVE-2017-0261",
    "description": "Detects Winword starting uncommon sub process FLTLDR.exe as used in exploits for CVE-2017-0261 and CVE-2017-0262",
    "tags": [
      "attack.defense_evasion",
      "attack.privilege_escalation",
      "attack.t1055"
    ],
    "query": "(winlog.event_data.ParentImage.keyword:*\\\\WINWORD.EXE AND winlog.event_data.Image.keyword:*\\\\FLTLDR.exe*)"
  },
  "trigger": {
    "schedule": {
      "interval": "30m"
    }
  },
  "input": {
    "search": {
      "request": {
        "body": {
          "size": 0,
          "query": {
            "bool": {
              "must": [
                {
                  "query_string": {
                    "query": "(winlog.event_data.ParentImage.keyword:*\\\\WINWORD.EXE AND winlog.event_data.Image.keyword:*\\\\FLTLDR.exe*)",
                    "analyze_wildcard": true
                  }
                }
              ],
              "filter": {
                "range": {
                  "timestamp": {
                    "gte": "now-30m/m"
                  }
                }
              }
            }
          }
        },
        "indices": [
          "winlogbeat-*"
        ]
      }
    }
  },
  "condition": {
    "compare": {
      "ctx.payload.hits.total": {
        "not_eq": 0
      }
    }
  },
  "actions": {
    "send_email": {
      "email": {
        "to": "root@localhost",
        "subject": "Sigma Rule 'Exploit for CVE-2017-0261'",
        "body": "Hits:\n{{#ctx.payload.hits.hits}}{{_source}}\n================================================================================\n{{/ctx.payload.hits.hits}}",
        "attachments": {
          "data.json": {
            "data": {
              "format": "json"
            }
          }
        }
      }
    }
  }
}
EOF

```


### graylog
    
```
(ParentImage.keyword:*\\WINWORD.EXE AND Image.keyword:*\\FLTLDR.exe*)
```


### splunk
    
```
(ParentImage="*\\WINWORD.EXE" Image="*\\FLTLDR.exe*")
```


### logpoint
    
```
(ParentImage="*\\WINWORD.EXE" Image="*\\FLTLDR.exe*")
```


### grep
    
```
grep -P '^(?:.*(?=.*.*\WINWORD\.EXE)(?=.*.*\FLTLDR\.exe.*))'
```



