| Title                    | Exploit for CVE-2017-8759       |
|:-------------------------|:------------------|
| **Description**          | Detects Winword starting uncommon sub process csc.exe as used in exploits for CVE-2017-8759 |
| **ATT&amp;CK Tactic**    |  <ul><li>[TA0002: Execution](https://attack.mitre.org/tactics/TA0002)</li></ul>  |
| **ATT&amp;CK Technique** | <ul><li>[T1203: Exploitation for Client Execution](https://attack.mitre.org/techniques/T1203)</li></ul>  |
| **Data Needed**          | <ul><li>[DN_0002_4688_windows_process_creation_with_commandline](../Data_Needed/DN_0002_4688_windows_process_creation_with_commandline.md)</li><li>[DN_0003_1_windows_sysmon_process_creation](../Data_Needed/DN_0003_1_windows_sysmon_process_creation.md)</li></ul>  |
| **Trigger**              |  There is no documented Trigger for this Detection Rule yet  |
| **Severity Level**       | critical |
| **False Positives**      | <ul><li>Unknown</li></ul>  |
| **Development Status**   |  Development Status wasn't defined for this Detection Rule yet  |
| **References**           | <ul><li>[https://www.hybrid-analysis.com/sample/0b4ef455e385b750d9f90749f1467eaf00e46e8d6c2885c260e1b78211a51684?environmentId=100](https://www.hybrid-analysis.com/sample/0b4ef455e385b750d9f90749f1467eaf00e46e8d6c2885c260e1b78211a51684?environmentId=100)</li><li>[https://www.reverse.it/sample/0b4ef455e385b750d9f90749f1467eaf00e46e8d6c2885c260e1b78211a51684?environmentId=100](https://www.reverse.it/sample/0b4ef455e385b750d9f90749f1467eaf00e46e8d6c2885c260e1b78211a51684?environmentId=100)</li></ul>  |
| **Author**               | Florian Roth |


## Detection Rules

### Sigma rule

```
title: Exploit for CVE-2017-8759
id: fdd84c68-a1f6-47c9-9477-920584f94905
description: Detects Winword starting uncommon sub process csc.exe as used in exploits for CVE-2017-8759
references:
    - https://www.hybrid-analysis.com/sample/0b4ef455e385b750d9f90749f1467eaf00e46e8d6c2885c260e1b78211a51684?environmentId=100
    - https://www.reverse.it/sample/0b4ef455e385b750d9f90749f1467eaf00e46e8d6c2885c260e1b78211a51684?environmentId=100
tags:
    - attack.execution
    - attack.t1203
author: Florian Roth
date: 2017/09/15
logsource:
    category: process_creation
    product: windows
detection:
    selection:
        ParentImage: '*\WINWORD.EXE'
        Image: '*\csc.exe'
    condition: selection
falsepositives:
    - Unknown
level: critical

```





### powershell
    
```
Get-WinEvent | where {($_.message -match "ParentImage.*.*\\WINWORD.EXE" -and $_.message -match "Image.*.*\\csc.exe") } | select TimeCreated,Id,RecordId,ProcessId,MachineName,Message
```


### es-qs
    
```
(winlog.event_data.ParentImage.keyword:*\\WINWORD.EXE AND winlog.event_data.Image.keyword:*\\csc.exe)
```


### xpack-watcher
    
```
curl -s -XPUT -H 'Content-Type: application/json' --data-binary @- localhost:9200/_watcher/watch/fdd84c68-a1f6-47c9-9477-920584f94905 <<EOF
{
  "metadata": {
    "title": "Exploit for CVE-2017-8759",
    "description": "Detects Winword starting uncommon sub process csc.exe as used in exploits for CVE-2017-8759",
    "tags": [
      "attack.execution",
      "attack.t1203"
    ],
    "query": "(winlog.event_data.ParentImage.keyword:*\\\\WINWORD.EXE AND winlog.event_data.Image.keyword:*\\\\csc.exe)"
  },
  "trigger": {
    "schedule": {
      "interval": "30m"
    }
  },
  "input": {
    "search": {
      "request": {
        "body": {
          "size": 0,
          "query": {
            "bool": {
              "must": [
                {
                  "query_string": {
                    "query": "(winlog.event_data.ParentImage.keyword:*\\\\WINWORD.EXE AND winlog.event_data.Image.keyword:*\\\\csc.exe)",
                    "analyze_wildcard": true
                  }
                }
              ],
              "filter": {
                "range": {
                  "timestamp": {
                    "gte": "now-30m/m"
                  }
                }
              }
            }
          }
        },
        "indices": [
          "winlogbeat-*"
        ]
      }
    }
  },
  "condition": {
    "compare": {
      "ctx.payload.hits.total": {
        "not_eq": 0
      }
    }
  },
  "actions": {
    "send_email": {
      "email": {
        "to": "root@localhost",
        "subject": "Sigma Rule 'Exploit for CVE-2017-8759'",
        "body": "Hits:\n{{#ctx.payload.hits.hits}}{{_source}}\n================================================================================\n{{/ctx.payload.hits.hits}}",
        "attachments": {
          "data.json": {
            "data": {
              "format": "json"
            }
          }
        }
      }
    }
  }
}
EOF

```


### graylog
    
```
(ParentImage.keyword:*\\WINWORD.EXE AND Image.keyword:*\\csc.exe)
```


### splunk
    
```
(ParentImage="*\\WINWORD.EXE" Image="*\\csc.exe")
```


### logpoint
    
```
(ParentImage="*\\WINWORD.EXE" Image="*\\csc.exe")
```


### grep
    
```
grep -P '^(?:.*(?=.*.*\WINWORD\.EXE)(?=.*.*\csc\.exe))'
```



