| Title                    | Exploiting CVE-2019-1388       |
|:-------------------------|:------------------|
| **Description**          | Detects an explotation attempt in which the UAC consent dialogue is used to invoke an Internet Explorer process running as LOCAL_SYSTEM |
| **ATT&amp;CK Tactic**    |  <ul><li>[TA0004: Privilege Escalation](https://attack.mitre.org/tactics/TA0004)</li></ul>  |
| **ATT&amp;CK Technique** | <ul><li>[T1068: Exploitation for Privilege Escalation](https://attack.mitre.org/techniques/T1068)</li></ul>  |
| **Data Needed**          | <ul><li>[DN_0003_1_windows_sysmon_process_creation](../Data_Needed/DN_0003_1_windows_sysmon_process_creation.md)</li></ul>  |
| **Trigger**              |  There is no documented Trigger for this Detection Rule yet  |
| **Severity Level**       | critical |
| **False Positives**      | <ul><li>Unknown</li></ul>  |
| **Development Status**   | experimental |
| **References**           | <ul><li>[https://portal.msrc.microsoft.com/en-US/security-guidance/advisory/CVE-2019-1388](https://portal.msrc.microsoft.com/en-US/security-guidance/advisory/CVE-2019-1388)</li><li>[https://www.zerodayinitiative.com/blog/2019/11/19/thanksgiving-treat-easy-as-pie-windows-7-secure-desktop-escalation-of-privilege](https://www.zerodayinitiative.com/blog/2019/11/19/thanksgiving-treat-easy-as-pie-windows-7-secure-desktop-escalation-of-privilege)</li></ul>  |
| **Author**               | Florian Roth |


## Detection Rules

### Sigma rule

```
title: Exploiting CVE-2019-1388
id: 02e0b2ea-a597-428e-b04a-af6a1a403e5c
status: experimental
description: Detects an explotation attempt in which the UAC consent dialogue is used to invoke an Internet Explorer process running as LOCAL_SYSTEM
references:
    - https://portal.msrc.microsoft.com/en-US/security-guidance/advisory/CVE-2019-1388
    - https://www.zerodayinitiative.com/blog/2019/11/19/thanksgiving-treat-easy-as-pie-windows-7-secure-desktop-escalation-of-privilege
author: Florian Roth
date: 2019/11/20
tags:
    - attack.privilege_escalation
    - attack.t1068
logsource:
    category: process_creation
    product: windows
detection:
    selection:
        ParentImage: '*\consent.exe'
        Image: '*\iexplore.exe'
        CommandLine: '* http*'
    rights1:
        IntegrityLevel: 'System'  # for Sysmon users
    rights2: 
        User: 'NT AUTHORITY\SYSTEM'  # for non-Sysmon users - English language settings
    condition: selection and ( rights1 or rights2 )
falsepositives:
    - Unknown
level: critical

```





### powershell
    
```
Get-WinEvent | where {(($_.message -match "ParentImage.*.*\\consent.exe" -and $_.message -match "Image.*.*\\iexplore.exe" -and $_.message -match "CommandLine.*.* http.*") -and ($_.message -match "IntegrityLevel.*System" -or $_.message -match "User.*NT AUTHORITY\\SYSTEM")) } | select TimeCreated,Id,RecordId,ProcessId,MachineName,Message
```


### es-qs
    
```
((winlog.event_data.ParentImage.keyword:*\\consent.exe AND winlog.event_data.Image.keyword:*\\iexplore.exe AND winlog.event_data.CommandLine.keyword:*\ http*) AND (IntegrityLevel:"System" OR winlog.event_data.User:"NT\ AUTHORITY\\SYSTEM"))
```


### xpack-watcher
    
```
curl -s -XPUT -H 'Content-Type: application/json' --data-binary @- localhost:9200/_watcher/watch/02e0b2ea-a597-428e-b04a-af6a1a403e5c <<EOF
{
  "metadata": {
    "title": "Exploiting CVE-2019-1388",
    "description": "Detects an explotation attempt in which the UAC consent dialogue is used to invoke an Internet Explorer process running as LOCAL_SYSTEM",
    "tags": [
      "attack.privilege_escalation",
      "attack.t1068"
    ],
    "query": "((winlog.event_data.ParentImage.keyword:*\\\\consent.exe AND winlog.event_data.Image.keyword:*\\\\iexplore.exe AND winlog.event_data.CommandLine.keyword:*\\ http*) AND (IntegrityLevel:\"System\" OR winlog.event_data.User:\"NT\\ AUTHORITY\\\\SYSTEM\"))"
  },
  "trigger": {
    "schedule": {
      "interval": "30m"
    }
  },
  "input": {
    "search": {
      "request": {
        "body": {
          "size": 0,
          "query": {
            "bool": {
              "must": [
                {
                  "query_string": {
                    "query": "((winlog.event_data.ParentImage.keyword:*\\\\consent.exe AND winlog.event_data.Image.keyword:*\\\\iexplore.exe AND winlog.event_data.CommandLine.keyword:*\\ http*) AND (IntegrityLevel:\"System\" OR winlog.event_data.User:\"NT\\ AUTHORITY\\\\SYSTEM\"))",
                    "analyze_wildcard": true
                  }
                }
              ],
              "filter": {
                "range": {
                  "timestamp": {
                    "gte": "now-30m/m"
                  }
                }
              }
            }
          }
        },
        "indices": [
          "winlogbeat-*"
        ]
      }
    }
  },
  "condition": {
    "compare": {
      "ctx.payload.hits.total": {
        "not_eq": 0
      }
    }
  },
  "actions": {
    "send_email": {
      "email": {
        "to": "root@localhost",
        "subject": "Sigma Rule 'Exploiting CVE-2019-1388'",
        "body": "Hits:\n{{#ctx.payload.hits.hits}}{{_source}}\n================================================================================\n{{/ctx.payload.hits.hits}}",
        "attachments": {
          "data.json": {
            "data": {
              "format": "json"
            }
          }
        }
      }
    }
  }
}
EOF

```


### graylog
    
```
((ParentImage.keyword:*\\consent.exe AND Image.keyword:*\\iexplore.exe AND CommandLine.keyword:* http*) AND (IntegrityLevel:"System" OR User:"NT AUTHORITY\\SYSTEM"))
```


### splunk
    
```
((ParentImage="*\\consent.exe" Image="*\\iexplore.exe" CommandLine="* http*") (IntegrityLevel="System" OR User="NT AUTHORITY\\SYSTEM"))
```


### logpoint
    
```
((ParentImage="*\\consent.exe" Image="*\\iexplore.exe" CommandLine="* http*") (IntegrityLevel="System" OR User="NT AUTHORITY\\SYSTEM"))
```


### grep
    
```
grep -P '^(?:.*(?=.*(?:.*(?=.*.*\consent\.exe)(?=.*.*\iexplore\.exe)(?=.*.* http.*)))(?=.*(?:.*(?:.*System|.*NT AUTHORITY\SYSTEM))))'
```



