| Title                    | Suspicious HWP Sub Processes       |
|:-------------------------|:------------------|
| **Description**          | Detects suspicious Hangul Word Processor (Hanword) sub processes that could indicate an exploitation |
| **ATT&amp;CK Tactic**    |  <ul><li>[TA0002: Execution](https://attack.mitre.org/tactics/TA0002)</li><li>[TA0005: Defense Evasion](https://attack.mitre.org/tactics/TA0005)</li><li>[TA0001: Initial Access](https://attack.mitre.org/tactics/TA0001)</li></ul>  |
| **ATT&amp;CK Technique** | <ul><li>[T1059: Command and Scripting Interpreter](https://attack.mitre.org/techniques/T1059)</li><li>[T1202: Indirect Command Execution](https://attack.mitre.org/techniques/T1202)</li><li>[T1193: Spearphishing Attachment](https://attack.mitre.org/techniques/T1193)</li></ul>  |
| **Data Needed**          | <ul><li>[DN_0002_4688_windows_process_creation_with_commandline](../Data_Needed/DN_0002_4688_windows_process_creation_with_commandline.md)</li><li>[DN_0003_1_windows_sysmon_process_creation](../Data_Needed/DN_0003_1_windows_sysmon_process_creation.md)</li></ul>  |
| **Trigger**              | <ul><li>[T1059: Command and Scripting Interpreter](../Triggers/T1059.md)</li><li>[T1202: Indirect Command Execution](../Triggers/T1202.md)</li><li>[T1193: Spearphishing Attachment](../Triggers/T1193.md)</li></ul>  |
| **Severity Level**       | high |
| **False Positives**      | <ul><li>Unknown</li></ul>  |
| **Development Status**   | experimental |
| **References**           | <ul><li>[https://www.securitynewspaper.com/2016/11/23/technical-teardown-exploit-malware-hwp-files/](https://www.securitynewspaper.com/2016/11/23/technical-teardown-exploit-malware-hwp-files/)</li><li>[https://www.hybrid-analysis.com/search?query=context:74940dcc5b38f9f9b1a0fea760d344735d7d91b610e6d5bd34533dd0153402c5&from_sample=5db135000388385a7644131f&block_redirect=1](https://www.hybrid-analysis.com/search?query=context:74940dcc5b38f9f9b1a0fea760d344735d7d91b610e6d5bd34533dd0153402c5&from_sample=5db135000388385a7644131f&block_redirect=1)</li><li>[https://twitter.com/cyberwar_15/status/1187287262054076416](https://twitter.com/cyberwar_15/status/1187287262054076416)</li><li>[https://blog.alyac.co.kr/1901](https://blog.alyac.co.kr/1901)</li><li>[https://en.wikipedia.org/wiki/Hangul_(word_processor)](https://en.wikipedia.org/wiki/Hangul_(word_processor))</li></ul>  |
| **Author**               | Florian Roth |
| Other Tags           | <ul><li>attack.g0032</li></ul> | 

## Detection Rules

### Sigma rule

```
title: Suspicious HWP Sub Processes
id: 023394c4-29d5-46ab-92b8-6a534c6f447b
description: Detects suspicious Hangul Word Processor (Hanword) sub processes that could indicate an exploitation
status: experimental
references:
    - https://www.securitynewspaper.com/2016/11/23/technical-teardown-exploit-malware-hwp-files/
    - https://www.hybrid-analysis.com/search?query=context:74940dcc5b38f9f9b1a0fea760d344735d7d91b610e6d5bd34533dd0153402c5&from_sample=5db135000388385a7644131f&block_redirect=1
    - https://twitter.com/cyberwar_15/status/1187287262054076416
    - https://blog.alyac.co.kr/1901
    - https://en.wikipedia.org/wiki/Hangul_(word_processor)
tags:
    - attack.execution
    - attack.defense_evasion
    - attack.initial_access
    - attack.t1059
    - attack.t1202
    - attack.t1193
    - attack.g0032
author: Florian Roth
date: 2019/10/24
logsource:
    category: process_creation
    product: windows
detection:
    selection:
        ParentImage: '*\Hwp.exe'
        Image: '*\gbb.exe'
    condition: selection
falsepositives:
    - Unknown
level: high

```





### powershell
    
```
Get-WinEvent | where {($_.message -match "ParentImage.*.*\\Hwp.exe" -and $_.message -match "Image.*.*\\gbb.exe") } | select TimeCreated,Id,RecordId,ProcessId,MachineName,Message
```


### es-qs
    
```
(winlog.event_data.ParentImage.keyword:*\\Hwp.exe AND winlog.event_data.Image.keyword:*\\gbb.exe)
```


### xpack-watcher
    
```
curl -s -XPUT -H 'Content-Type: application/json' --data-binary @- localhost:9200/_watcher/watch/023394c4-29d5-46ab-92b8-6a534c6f447b <<EOF
{
  "metadata": {
    "title": "Suspicious HWP Sub Processes",
    "description": "Detects suspicious Hangul Word Processor (Hanword) sub processes that could indicate an exploitation",
    "tags": [
      "attack.execution",
      "attack.defense_evasion",
      "attack.initial_access",
      "attack.t1059",
      "attack.t1202",
      "attack.t1193",
      "attack.g0032"
    ],
    "query": "(winlog.event_data.ParentImage.keyword:*\\\\Hwp.exe AND winlog.event_data.Image.keyword:*\\\\gbb.exe)"
  },
  "trigger": {
    "schedule": {
      "interval": "30m"
    }
  },
  "input": {
    "search": {
      "request": {
        "body": {
          "size": 0,
          "query": {
            "bool": {
              "must": [
                {
                  "query_string": {
                    "query": "(winlog.event_data.ParentImage.keyword:*\\\\Hwp.exe AND winlog.event_data.Image.keyword:*\\\\gbb.exe)",
                    "analyze_wildcard": true
                  }
                }
              ],
              "filter": {
                "range": {
                  "timestamp": {
                    "gte": "now-30m/m"
                  }
                }
              }
            }
          }
        },
        "indices": [
          "winlogbeat-*"
        ]
      }
    }
  },
  "condition": {
    "compare": {
      "ctx.payload.hits.total": {
        "not_eq": 0
      }
    }
  },
  "actions": {
    "send_email": {
      "email": {
        "to": "root@localhost",
        "subject": "Sigma Rule 'Suspicious HWP Sub Processes'",
        "body": "Hits:\n{{#ctx.payload.hits.hits}}{{_source}}\n================================================================================\n{{/ctx.payload.hits.hits}}",
        "attachments": {
          "data.json": {
            "data": {
              "format": "json"
            }
          }
        }
      }
    }
  }
}
EOF

```


### graylog
    
```
(ParentImage.keyword:*\\Hwp.exe AND Image.keyword:*\\gbb.exe)
```


### splunk
    
```
(ParentImage="*\\Hwp.exe" Image="*\\gbb.exe")
```


### logpoint
    
```
(ParentImage="*\\Hwp.exe" Image="*\\gbb.exe")
```


### grep
    
```
grep -P '^(?:.*(?=.*.*\Hwp\.exe)(?=.*.*\gbb\.exe))'
```



