| Title                    | Windows Kernel and 3rd-Party Drivers Exploits Token Stealing       |
|:-------------------------|:------------------|
| **Description**          | Detection of child processes spawned with SYSTEM privileges by parents with non-SYSTEM privileges and Medium integrity level |
| **ATT&amp;CK Tactic**    |  <ul><li>[TA0004: Privilege Escalation](https://attack.mitre.org/tactics/TA0004)</li></ul>  |
| **ATT&amp;CK Technique** | <ul><li>[T1068: Exploitation for Privilege Escalation](https://attack.mitre.org/techniques/T1068)</li></ul>  |
| **Data Needed**          | <ul><li>[DN_0003_1_windows_sysmon_process_creation](../Data_Needed/DN_0003_1_windows_sysmon_process_creation.md)</li></ul>  |
| **Enrichment** |<ul><li>[EN_0001_cache_sysmon_event_id_1_info](../Enrichments/EN_0001_cache_sysmon_event_id_1_info.md)</li><li>[EN_0002_enrich_sysmon_event_id_1_with_parent_info](../Enrichments/EN_0002_enrich_sysmon_event_id_1_with_parent_info.md)</li></ul> |
| **Trigger**              |  There is no documented Trigger for this Detection Rule yet  |
| **Severity Level**       | critical |
| **False Positives**      | <ul><li>Unknown</li></ul>  |
| **Development Status**   | experimental |
| **References**           | <ul><li>[https://www.slideshare.net/heirhabarov/hunting-for-privilege-escalation-in-windows-environment](https://www.slideshare.net/heirhabarov/hunting-for-privilege-escalation-in-windows-environment)</li></ul>  |
| **Author**               | Teymur Kheirkhabarov (source), Daniil Yugoslavskiy (rule) |


## Detection Rules

### Sigma rule

```
title: Windows Kernel and 3rd-Party Drivers Exploits Token Stealing
id: 8065b1b4-1778-4427-877f-6bf948b26d38
description: Detection of child processes spawned with SYSTEM privileges by parents with non-SYSTEM privileges and Medium integrity level
references:
    - https://www.slideshare.net/heirhabarov/hunting-for-privilege-escalation-in-windows-environment
tags:
    - attack.privilege_escalation
    - attack.t1068
status: experimental
author: Teymur Kheirkhabarov (source), Daniil Yugoslavskiy (rule)
date: 2019/06/03
logsource:
    category: process_creation
    product: windows
detection:
    selection:
        ParentIntegrityLevel: Medium
        IntegrityLevel: System
        User: "NT AUTHORITY\\SYSTEM"
    condition: selection
falsepositives:
    - Unknown
level: critical
enrichment:
    - EN_0001_cache_sysmon_event_id_1_info                # http://bit.ly/314zc6x
    - EN_0002_enrich_sysmon_event_id_1_with_parent_info   # http://bit.ly/2KmSC0l

```





### powershell
    
```
Get-WinEvent | where {($_.message -match "ParentIntegrityLevel.*Medium" -and $_.message -match "IntegrityLevel.*System" -and $_.message -match "User.*NT AUTHORITY\\SYSTEM") } | select TimeCreated,Id,RecordId,ProcessId,MachineName,Message
```


### es-qs
    
```
(ParentIntegrityLevel:"Medium" AND IntegrityLevel:"System" AND winlog.event_data.User:"NT\ AUTHORITY\\SYSTEM")
```


### xpack-watcher
    
```
curl -s -XPUT -H 'Content-Type: application/json' --data-binary @- localhost:9200/_watcher/watch/8065b1b4-1778-4427-877f-6bf948b26d38 <<EOF
{
  "metadata": {
    "title": "Windows Kernel and 3rd-Party Drivers Exploits Token Stealing",
    "description": "Detection of child processes spawned with SYSTEM privileges by parents with non-SYSTEM privileges and Medium integrity level",
    "tags": [
      "attack.privilege_escalation",
      "attack.t1068"
    ],
    "query": "(ParentIntegrityLevel:\"Medium\" AND IntegrityLevel:\"System\" AND winlog.event_data.User:\"NT\\ AUTHORITY\\\\SYSTEM\")"
  },
  "trigger": {
    "schedule": {
      "interval": "30m"
    }
  },
  "input": {
    "search": {
      "request": {
        "body": {
          "size": 0,
          "query": {
            "bool": {
              "must": [
                {
                  "query_string": {
                    "query": "(ParentIntegrityLevel:\"Medium\" AND IntegrityLevel:\"System\" AND winlog.event_data.User:\"NT\\ AUTHORITY\\\\SYSTEM\")",
                    "analyze_wildcard": true
                  }
                }
              ],
              "filter": {
                "range": {
                  "timestamp": {
                    "gte": "now-30m/m"
                  }
                }
              }
            }
          }
        },
        "indices": [
          "winlogbeat-*"
        ]
      }
    }
  },
  "condition": {
    "compare": {
      "ctx.payload.hits.total": {
        "not_eq": 0
      }
    }
  },
  "actions": {
    "send_email": {
      "email": {
        "to": "root@localhost",
        "subject": "Sigma Rule 'Windows Kernel and 3rd-Party Drivers Exploits Token Stealing'",
        "body": "Hits:\n{{#ctx.payload.hits.hits}}{{_source}}\n================================================================================\n{{/ctx.payload.hits.hits}}",
        "attachments": {
          "data.json": {
            "data": {
              "format": "json"
            }
          }
        }
      }
    }
  }
}
EOF

```


### graylog
    
```
(ParentIntegrityLevel:"Medium" AND IntegrityLevel:"System" AND User:"NT AUTHORITY\\SYSTEM")
```


### splunk
    
```
(ParentIntegrityLevel="Medium" IntegrityLevel="System" User="NT AUTHORITY\\SYSTEM")
```


### logpoint
    
```
(ParentIntegrityLevel="Medium" IntegrityLevel="System" User="NT AUTHORITY\\SYSTEM")
```


### grep
    
```
grep -P '^(?:.*(?=.*Medium)(?=.*System)(?=.*NT AUTHORITY\SYSTEM))'
```



