| Title                    | Dridex Process Pattern       |
|:-------------------------|:------------------|
| **Description**          | Detects typical Dridex process patterns |
| **ATT&amp;CK Tactic**    |  <ul><li>[TA0005: Defense Evasion](https://attack.mitre.org/tactics/TA0005)</li><li>[TA0004: Privilege Escalation](https://attack.mitre.org/tactics/TA0004)</li></ul>  |
| **ATT&amp;CK Technique** | <ul><li>[T1055: Process Injection](https://attack.mitre.org/techniques/T1055)</li></ul>  |
| **Data Needed**          | <ul><li>[DN_0002_4688_windows_process_creation_with_commandline](../Data_Needed/DN_0002_4688_windows_process_creation_with_commandline.md)</li><li>[DN_0003_1_windows_sysmon_process_creation](../Data_Needed/DN_0003_1_windows_sysmon_process_creation.md)</li></ul>  |
| **Trigger**              | <ul><li>[T1055: Process Injection](../Triggers/T1055.md)</li></ul>  |
| **Severity Level**       | critical |
| **False Positives**      | <ul><li>Unlikely</li></ul>  |
| **Development Status**   | experimental |
| **References**           | <ul><li>[https://app.any.run/tasks/993daa5e-112a-4ff6-8b5a-edbcec7c7ba3](https://app.any.run/tasks/993daa5e-112a-4ff6-8b5a-edbcec7c7ba3)</li></ul>  |
| **Author**               | Florian Roth |


## Detection Rules

### Sigma rule

```
title: Dridex Process Pattern
id: e6eb5a96-9e6f-4a18-9cdd-642cfda21c8e
status: experimental
description: Detects typical Dridex process patterns
references:
    - https://app.any.run/tasks/993daa5e-112a-4ff6-8b5a-edbcec7c7ba3
author: Florian Roth
date: 2019/01/10
tags:
    - attack.defense_evasion
    - attack.privilege_escalation
    - attack.t1055
logsource:
    category: process_creation
    product: windows
detection:
    selection1:
        CommandLine: '*\svchost.exe C:\Users\\*\Desktop\\*'
    selection2:
        ParentImage: '*\svchost.exe*'
        CommandLine:
            - '*whoami.exe /all'
            - '*net.exe view'
    condition: 1 of them
falsepositives:
    - Unlikely
level: critical

```





### powershell
    
```
Get-WinEvent | where {($_.message -match "CommandLine.*.*\\svchost.exe C:\\Users\\.*\\Desktop\\.*" -or ($_.message -match "ParentImage.*.*\\svchost.exe.*" -and ($_.message -match "CommandLine.*.*whoami.exe /all" -or $_.message -match "CommandLine.*.*net.exe view"))) } | select TimeCreated,Id,RecordId,ProcessId,MachineName,Message
```


### es-qs
    
```
(winlog.event_data.CommandLine.keyword:*\\svchost.exe\ C\:\\Users\\*\\Desktop\\* OR (winlog.event_data.ParentImage.keyword:*\\svchost.exe* AND winlog.event_data.CommandLine.keyword:(*whoami.exe\ \/all OR *net.exe\ view)))
```


### xpack-watcher
    
```
curl -s -XPUT -H 'Content-Type: application/json' --data-binary @- localhost:9200/_watcher/watch/e6eb5a96-9e6f-4a18-9cdd-642cfda21c8e <<EOF
{
  "metadata": {
    "title": "Dridex Process Pattern",
    "description": "Detects typical Dridex process patterns",
    "tags": [
      "attack.defense_evasion",
      "attack.privilege_escalation",
      "attack.t1055"
    ],
    "query": "(winlog.event_data.CommandLine.keyword:*\\\\svchost.exe\\ C\\:\\\\Users\\\\*\\\\Desktop\\\\* OR (winlog.event_data.ParentImage.keyword:*\\\\svchost.exe* AND winlog.event_data.CommandLine.keyword:(*whoami.exe\\ \\/all OR *net.exe\\ view)))"
  },
  "trigger": {
    "schedule": {
      "interval": "30m"
    }
  },
  "input": {
    "search": {
      "request": {
        "body": {
          "size": 0,
          "query": {
            "bool": {
              "must": [
                {
                  "query_string": {
                    "query": "(winlog.event_data.CommandLine.keyword:*\\\\svchost.exe\\ C\\:\\\\Users\\\\*\\\\Desktop\\\\* OR (winlog.event_data.ParentImage.keyword:*\\\\svchost.exe* AND winlog.event_data.CommandLine.keyword:(*whoami.exe\\ \\/all OR *net.exe\\ view)))",
                    "analyze_wildcard": true
                  }
                }
              ],
              "filter": {
                "range": {
                  "timestamp": {
                    "gte": "now-30m/m"
                  }
                }
              }
            }
          }
        },
        "indices": [
          "winlogbeat-*"
        ]
      }
    }
  },
  "condition": {
    "compare": {
      "ctx.payload.hits.total": {
        "not_eq": 0
      }
    }
  },
  "actions": {
    "send_email": {
      "email": {
        "to": "root@localhost",
        "subject": "Sigma Rule 'Dridex Process Pattern'",
        "body": "Hits:\n{{#ctx.payload.hits.hits}}{{_source}}\n================================================================================\n{{/ctx.payload.hits.hits}}",
        "attachments": {
          "data.json": {
            "data": {
              "format": "json"
            }
          }
        }
      }
    }
  }
}
EOF

```


### graylog
    
```
(CommandLine.keyword:*\\svchost.exe C\:\\Users\\*\\Desktop\\* OR (ParentImage.keyword:*\\svchost.exe* AND CommandLine.keyword:(*whoami.exe \/all *net.exe view)))
```


### splunk
    
```
(CommandLine="*\\svchost.exe C:\\Users\\*\\Desktop\\*" OR (ParentImage="*\\svchost.exe*" (CommandLine="*whoami.exe /all" OR CommandLine="*net.exe view")))
```


### logpoint
    
```
(CommandLine="*\\svchost.exe C:\\Users\\*\\Desktop\\*" OR (ParentImage="*\\svchost.exe*" CommandLine IN ["*whoami.exe /all", "*net.exe view"]))
```


### grep
    
```
grep -P '^(?:.*(?:.*.*\svchost\.exe C:\Users\\.*\Desktop\\.*|.*(?:.*(?=.*.*\svchost\.exe.*)(?=.*(?:.*.*whoami\.exe /all|.*.*net\.exe view)))))'
```



