| Title                    | DTRACK Process Creation       |
|:-------------------------|:------------------|
| **Description**          | Detects specific process parameters as seen in DTRACK infections |
| **ATT&amp;CK Tactic**    |   This Detection Rule wasn't mapped to ATT&amp;CK Tactic yet  |
| **ATT&amp;CK Technique** |  This Detection Rule wasn't mapped to ATT&amp;CK Technique yet  |
| **Data Needed**          | <ul><li>[DN_0002_4688_windows_process_creation_with_commandline](../Data_Needed/DN_0002_4688_windows_process_creation_with_commandline.md)</li><li>[DN_0003_1_windows_sysmon_process_creation](../Data_Needed/DN_0003_1_windows_sysmon_process_creation.md)</li></ul>  |
| **Trigger**              |  There is no documented Trigger for this Detection Rule yet  |
| **Severity Level**       | critical |
| **False Positives**      | <ul><li>Unlikely</li></ul>  |
| **Development Status**   | experimental |
| **References**           | <ul><li>[https://securelist.com/my-name-is-dtrack/93338/](https://securelist.com/my-name-is-dtrack/93338/)</li><li>[https://app.any.run/tasks/4bc9860d-ab51-4077-9e09-59ad346b92fd/](https://app.any.run/tasks/4bc9860d-ab51-4077-9e09-59ad346b92fd/)</li><li>[https://app.any.run/tasks/ce4deab5-3263-494f-93e3-afb2b9d79f14/](https://app.any.run/tasks/ce4deab5-3263-494f-93e3-afb2b9d79f14/)</li></ul>  |
| **Author**               | Florian Roth |


## Detection Rules

### Sigma rule

```
title: DTRACK Process Creation
id: f1531fa4-5b84-4342-8f68-9cf3fdbd83d4
status: experimental
description: Detects specific process parameters as seen in DTRACK infections
author: Florian Roth
date: 2019/10/30
references:
    - https://securelist.com/my-name-is-dtrack/93338/
    - https://app.any.run/tasks/4bc9860d-ab51-4077-9e09-59ad346b92fd/
    - https://app.any.run/tasks/ce4deab5-3263-494f-93e3-afb2b9d79f14/
logsource:
    category: process_creation
    product: windows
detection:
    selection:
        CommandLine: '* echo EEEE > *'
    condition: selection
fields:
    - CommandLine
    - ParentCommandLine
falsepositives:
    - Unlikely
level: critical

```





### powershell
    
```
Get-WinEvent | where {$_.message -match "CommandLine.*.* echo EEEE > .*" } | select TimeCreated,Id,RecordId,ProcessId,MachineName,Message
```


### es-qs
    
```
winlog.event_data.CommandLine.keyword:*\ echo\ EEEE\ >\ *
```


### xpack-watcher
    
```
curl -s -XPUT -H 'Content-Type: application/json' --data-binary @- localhost:9200/_watcher/watch/f1531fa4-5b84-4342-8f68-9cf3fdbd83d4 <<EOF
{
  "metadata": {
    "title": "DTRACK Process Creation",
    "description": "Detects specific process parameters as seen in DTRACK infections",
    "tags": "",
    "query": "winlog.event_data.CommandLine.keyword:*\\ echo\\ EEEE\\ >\\ *"
  },
  "trigger": {
    "schedule": {
      "interval": "30m"
    }
  },
  "input": {
    "search": {
      "request": {
        "body": {
          "size": 0,
          "query": {
            "bool": {
              "must": [
                {
                  "query_string": {
                    "query": "winlog.event_data.CommandLine.keyword:*\\ echo\\ EEEE\\ >\\ *",
                    "analyze_wildcard": true
                  }
                }
              ],
              "filter": {
                "range": {
                  "timestamp": {
                    "gte": "now-30m/m"
                  }
                }
              }
            }
          }
        },
        "indices": [
          "winlogbeat-*"
        ]
      }
    }
  },
  "condition": {
    "compare": {
      "ctx.payload.hits.total": {
        "not_eq": 0
      }
    }
  },
  "actions": {
    "send_email": {
      "email": {
        "to": "root@localhost",
        "subject": "Sigma Rule 'DTRACK Process Creation'",
        "body": "Hits:\n{{#ctx.payload.hits.hits}}Hit on {{_source.@timestamp}}:\n      CommandLine = {{_source.CommandLine}}\nParentCommandLine = {{_source.ParentCommandLine}}================================================================================\n{{/ctx.payload.hits.hits}}",
        "attachments": {
          "data.json": {
            "data": {
              "format": "json"
            }
          }
        }
      }
    }
  }
}
EOF

```


### graylog
    
```
CommandLine.keyword:* echo EEEE > *
```


### splunk
    
```
CommandLine="* echo EEEE > *" | table CommandLine,ParentCommandLine
```


### logpoint
    
```
CommandLine="* echo EEEE > *"
```


### grep
    
```
grep -P '^.* echo EEEE > .*'
```



