| Title                    | NotPetya Ransomware Activity       |
|:-------------------------|:------------------|
| **Description**          | Detects NotPetya ransomware activity in which the extracted passwords are passed back to the main module via named pipe, the file system journal of drive C is deleted and windows eventlogs are cleared using wevtutil |
| **ATT&amp;CK Tactic**    |  <ul><li>[TA0002: Execution](https://attack.mitre.org/tactics/TA0002)</li><li>[TA0006: Credential Access](https://attack.mitre.org/tactics/TA0006)</li><li>[TA0005: Defense Evasion](https://attack.mitre.org/tactics/TA0005)</li></ul>  |
| **ATT&amp;CK Technique** | <ul><li>[T1085: Rundll32](https://attack.mitre.org/techniques/T1085)</li><li>[T1070: Indicator Removal on Host](https://attack.mitre.org/techniques/T1070)</li><li>[T1003: OS Credential Dumping](https://attack.mitre.org/techniques/T1003)</li></ul>  |
| **Data Needed**          | <ul><li>[DN_0002_4688_windows_process_creation_with_commandline](../Data_Needed/DN_0002_4688_windows_process_creation_with_commandline.md)</li><li>[DN_0003_1_windows_sysmon_process_creation](../Data_Needed/DN_0003_1_windows_sysmon_process_creation.md)</li></ul>  |
| **Trigger**              | <ul><li>[T1085: Rundll32](../Triggers/T1085.md)</li><li>[T1070: Indicator Removal on Host](../Triggers/T1070.md)</li><li>[T1003: OS Credential Dumping](../Triggers/T1003.md)</li></ul>  |
| **Severity Level**       | critical |
| **False Positives**      | <ul><li>Admin activity</li></ul>  |
| **Development Status**   | experimental |
| **References**           | <ul><li>[https://securelist.com/schroedingers-petya/78870/](https://securelist.com/schroedingers-petya/78870/)</li><li>[https://www.hybrid-analysis.com/sample/64b0b58a2c030c77fdb2b537b2fcc4af432bc55ffb36599a31d418c7c69e94b1?environmentId=100](https://www.hybrid-analysis.com/sample/64b0b58a2c030c77fdb2b537b2fcc4af432bc55ffb36599a31d418c7c69e94b1?environmentId=100)</li></ul>  |
| **Author**               | Florian Roth, Tom Ueltschi |
| Other Tags           | <ul><li>car.2016-04-002</li></ul> | 

## Detection Rules

### Sigma rule

```
title: NotPetya Ransomware Activity
id: 79aeeb41-8156-4fac-a0cd-076495ab82a1
status: experimental
description: Detects NotPetya ransomware activity in which the extracted passwords are passed back to the main module via named pipe, the file system journal of drive
    C is deleted and windows eventlogs are cleared using wevtutil
author: Florian Roth, Tom Ueltschi
date: 2019/01/16
references:
    - https://securelist.com/schroedingers-petya/78870/
    - https://www.hybrid-analysis.com/sample/64b0b58a2c030c77fdb2b537b2fcc4af432bc55ffb36599a31d418c7c69e94b1?environmentId=100
tags:
    - attack.execution
    - attack.credential_access
    - attack.defense_evasion
    - attack.t1085
    - attack.t1070
    - attack.t1003
    - car.2016-04-002
logsource:
    category: process_creation
    product: windows
detection:
    pipe_com:
        CommandLine: '*\AppData\Local\Temp\\* \\.\pipe\\*'
    rundll32_dash1:
        Image: '*\rundll32.exe'
        CommandLine: '*.dat,#1'
    perfc_keyword:
        - '*\perfc.dat*'
    condition: 1 of them
fields:
    - CommandLine
    - ParentCommandLine
falsepositives:
    - Admin activity
level: critical

```





### powershell
    
```
Get-WinEvent | where {($_.message -match "CommandLine.*.*\\AppData\\Local\\Temp\\.* \\.\\pipe\\.*" -or ($_.message -match "Image.*.*\\rundll32.exe" -and $_.message -match "CommandLine.*.*.dat,#1") -or $_.message -match "*\perfc.dat*") } | select TimeCreated,Id,RecordId,ProcessId,MachineName,Message
```


### es-qs
    
```
(winlog.event_data.CommandLine.keyword:*\\AppData\\Local\\Temp\\*\ \\.\\pipe\\* OR (winlog.event_data.Image.keyword:*\\rundll32.exe AND winlog.event_data.CommandLine.keyword:*.dat,#1) OR *\\perfc.dat*)
```


### xpack-watcher
    
```
curl -s -XPUT -H 'Content-Type: application/json' --data-binary @- localhost:9200/_watcher/watch/79aeeb41-8156-4fac-a0cd-076495ab82a1 <<EOF
{
  "metadata": {
    "title": "NotPetya Ransomware Activity",
    "description": "Detects NotPetya ransomware activity in which the extracted passwords are passed back to the main module via named pipe, the file system journal of drive C is deleted and windows eventlogs are cleared using wevtutil",
    "tags": [
      "attack.execution",
      "attack.credential_access",
      "attack.defense_evasion",
      "attack.t1085",
      "attack.t1070",
      "attack.t1003",
      "car.2016-04-002"
    ],
    "query": "(winlog.event_data.CommandLine.keyword:*\\\\AppData\\\\Local\\\\Temp\\\\*\\ \\\\.\\\\pipe\\\\* OR (winlog.event_data.Image.keyword:*\\\\rundll32.exe AND winlog.event_data.CommandLine.keyword:*.dat,#1) OR *\\\\perfc.dat*)"
  },
  "trigger": {
    "schedule": {
      "interval": "30m"
    }
  },
  "input": {
    "search": {
      "request": {
        "body": {
          "size": 0,
          "query": {
            "bool": {
              "must": [
                {
                  "query_string": {
                    "query": "(winlog.event_data.CommandLine.keyword:*\\\\AppData\\\\Local\\\\Temp\\\\*\\ \\\\.\\\\pipe\\\\* OR (winlog.event_data.Image.keyword:*\\\\rundll32.exe AND winlog.event_data.CommandLine.keyword:*.dat,#1) OR *\\\\perfc.dat*)",
                    "analyze_wildcard": true
                  }
                }
              ],
              "filter": {
                "range": {
                  "timestamp": {
                    "gte": "now-30m/m"
                  }
                }
              }
            }
          }
        },
        "indices": [
          "winlogbeat-*"
        ]
      }
    }
  },
  "condition": {
    "compare": {
      "ctx.payload.hits.total": {
        "not_eq": 0
      }
    }
  },
  "actions": {
    "send_email": {
      "email": {
        "to": "root@localhost",
        "subject": "Sigma Rule 'NotPetya Ransomware Activity'",
        "body": "Hits:\n{{#ctx.payload.hits.hits}}Hit on {{_source.@timestamp}}:\n      CommandLine = {{_source.CommandLine}}\nParentCommandLine = {{_source.ParentCommandLine}}================================================================================\n{{/ctx.payload.hits.hits}}",
        "attachments": {
          "data.json": {
            "data": {
              "format": "json"
            }
          }
        }
      }
    }
  }
}
EOF

```


### graylog
    
```
(CommandLine.keyword:*\\AppData\\Local\\Temp\\* \\.\\pipe\\* OR (Image.keyword:*\\rundll32.exe AND CommandLine.keyword:*.dat,#1) OR *\\perfc.dat*)
```


### splunk
    
```
(CommandLine="*\\AppData\\Local\\Temp\\* \\.\\pipe\\*" OR (Image="*\\rundll32.exe" CommandLine="*.dat,#1") OR "*\\perfc.dat*") | table CommandLine,ParentCommandLine
```


### logpoint
    
```
(CommandLine="*\\AppData\\Local\\Temp\\* \\.\\pipe\\*" OR (Image="*\\rundll32.exe" CommandLine="*.dat,#1") OR "*\\perfc.dat*")
```


### grep
    
```
grep -P '^(?:.*(?:.*.*\AppData\Local\Temp\\.* \\\.\pipe\\.*|.*(?:.*(?=.*.*\rundll32\.exe)(?=.*.*\.dat,#1))|.*.*\perfc\.dat.*))'
```



