| Title                    | QBot Process Creation       |
|:-------------------------|:------------------|
| **Description**          | Detects QBot like process executions |
| **ATT&amp;CK Tactic**    |   This Detection Rule wasn't mapped to ATT&amp;CK Tactic yet  |
| **ATT&amp;CK Technique** |  This Detection Rule wasn't mapped to ATT&amp;CK Technique yet  |
| **Data Needed**          | <ul><li>[DN_0002_4688_windows_process_creation_with_commandline](../Data_Needed/DN_0002_4688_windows_process_creation_with_commandline.md)</li><li>[DN_0003_1_windows_sysmon_process_creation](../Data_Needed/DN_0003_1_windows_sysmon_process_creation.md)</li></ul>  |
| **Trigger**              |  There is no documented Trigger for this Detection Rule yet  |
| **Severity Level**       | critical |
| **False Positives**      | <ul><li>Unlikely</li></ul>  |
| **Development Status**   | experimental |
| **References**           | <ul><li>[https://twitter.com/killamjr/status/1179034907932315648](https://twitter.com/killamjr/status/1179034907932315648)</li><li>[https://app.any.run/tasks/2e0647b7-eb86-4f72-904b-d2d0ecac07d1/](https://app.any.run/tasks/2e0647b7-eb86-4f72-904b-d2d0ecac07d1/)</li></ul>  |
| **Author**               | Florian Roth |


## Detection Rules

### Sigma rule

```
title: QBot Process Creation
id: 4fcac6eb-0287-4090-8eea-2602e4c20040
status: experimental
description: Detects QBot like process executions
author: Florian Roth
date: 2019/10/01
references:
    - https://twitter.com/killamjr/status/1179034907932315648
    - https://app.any.run/tasks/2e0647b7-eb86-4f72-904b-d2d0ecac07d1/
logsource:
    category: process_creation
    product: windows
detection:
    selection1:
        ParentImage: '*\WinRAR.exe'
        Image: '*\wscript.exe'
    selection2:
        CommandLine: '* /c ping.exe -n 6 127.0.0.1 & type *'
    condition: selection1 or selection2
fields:
    - CommandLine
    - ParentCommandLine
falsepositives:
    - Unlikely
level: critical

```





### powershell
    
```
Get-WinEvent | where {(($_.message -match "ParentImage.*.*\\WinRAR.exe" -and $_.message -match "Image.*.*\\wscript.exe") -or $_.message -match "CommandLine.*.* /c ping.exe -n 6 127.0.0.1 & type .*") } | select TimeCreated,Id,RecordId,ProcessId,MachineName,Message
```


### es-qs
    
```
((winlog.event_data.ParentImage.keyword:*\\WinRAR.exe AND winlog.event_data.Image.keyword:*\\wscript.exe) OR winlog.event_data.CommandLine.keyword:*\ \/c\ ping.exe\ \-n\ 6\ 127.0.0.1\ &\ type\ *)
```


### xpack-watcher
    
```
curl -s -XPUT -H 'Content-Type: application/json' --data-binary @- localhost:9200/_watcher/watch/4fcac6eb-0287-4090-8eea-2602e4c20040 <<EOF
{
  "metadata": {
    "title": "QBot Process Creation",
    "description": "Detects QBot like process executions",
    "tags": "",
    "query": "((winlog.event_data.ParentImage.keyword:*\\\\WinRAR.exe AND winlog.event_data.Image.keyword:*\\\\wscript.exe) OR winlog.event_data.CommandLine.keyword:*\\ \\/c\\ ping.exe\\ \\-n\\ 6\\ 127.0.0.1\\ &\\ type\\ *)"
  },
  "trigger": {
    "schedule": {
      "interval": "30m"
    }
  },
  "input": {
    "search": {
      "request": {
        "body": {
          "size": 0,
          "query": {
            "bool": {
              "must": [
                {
                  "query_string": {
                    "query": "((winlog.event_data.ParentImage.keyword:*\\\\WinRAR.exe AND winlog.event_data.Image.keyword:*\\\\wscript.exe) OR winlog.event_data.CommandLine.keyword:*\\ \\/c\\ ping.exe\\ \\-n\\ 6\\ 127.0.0.1\\ &\\ type\\ *)",
                    "analyze_wildcard": true
                  }
                }
              ],
              "filter": {
                "range": {
                  "timestamp": {
                    "gte": "now-30m/m"
                  }
                }
              }
            }
          }
        },
        "indices": [
          "winlogbeat-*"
        ]
      }
    }
  },
  "condition": {
    "compare": {
      "ctx.payload.hits.total": {
        "not_eq": 0
      }
    }
  },
  "actions": {
    "send_email": {
      "email": {
        "to": "root@localhost",
        "subject": "Sigma Rule 'QBot Process Creation'",
        "body": "Hits:\n{{#ctx.payload.hits.hits}}Hit on {{_source.@timestamp}}:\n      CommandLine = {{_source.CommandLine}}\nParentCommandLine = {{_source.ParentCommandLine}}================================================================================\n{{/ctx.payload.hits.hits}}",
        "attachments": {
          "data.json": {
            "data": {
              "format": "json"
            }
          }
        }
      }
    }
  }
}
EOF

```


### graylog
    
```
((ParentImage.keyword:*\\WinRAR.exe AND Image.keyword:*\\wscript.exe) OR CommandLine.keyword:* \/c ping.exe \-n 6 127.0.0.1 & type *)
```


### splunk
    
```
((ParentImage="*\\WinRAR.exe" Image="*\\wscript.exe") OR CommandLine="* /c ping.exe -n 6 127.0.0.1 & type *") | table CommandLine,ParentCommandLine
```


### logpoint
    
```
((ParentImage="*\\WinRAR.exe" Image="*\\wscript.exe") OR CommandLine="* /c ping.exe -n 6 127.0.0.1 & type *")
```


### grep
    
```
grep -P '^(?:.*(?:.*(?:.*(?=.*.*\WinRAR\.exe)(?=.*.*\wscript\.exe))|.*.* /c ping\.exe -n 6 127\.0\.0\.1 & type .*))'
```



