| Title                    | WScript or CScript Dropper       |
|:-------------------------|:------------------|
| **Description**          | Detects wscript/cscript executions of scripts located in user directories |
| **ATT&amp;CK Tactic**    |  <ul><li>[TA0005: Defense Evasion](https://attack.mitre.org/tactics/TA0005)</li><li>[TA0002: Execution](https://attack.mitre.org/tactics/TA0002)</li></ul>  |
| **ATT&amp;CK Technique** | <ul><li>[T1064: Scripting](https://attack.mitre.org/techniques/T1064)</li></ul>  |
| **Data Needed**          | <ul><li>[DN_0002_4688_windows_process_creation_with_commandline](../Data_Needed/DN_0002_4688_windows_process_creation_with_commandline.md)</li><li>[DN_0003_1_windows_sysmon_process_creation](../Data_Needed/DN_0003_1_windows_sysmon_process_creation.md)</li></ul>  |
| **Trigger**              | <ul><li>[T1064: Scripting](../Triggers/T1064.md)</li></ul>  |
| **Severity Level**       | high |
| **False Positives**      | <ul><li>Winzip</li><li>Other self-extractors</li></ul>  |
| **Development Status**   | experimental |
| **References**           |  There are no documented References for this Detection Rule yet  |
| **Author**               | Margaritis Dimitrios (idea), Florian Roth (rule) |


## Detection Rules

### Sigma rule

```
title: WScript or CScript Dropper
id: cea72823-df4d-4567-950c-0b579eaf0846
status: experimental
description: Detects wscript/cscript executions of scripts located in user directories
author: Margaritis Dimitrios (idea), Florian Roth (rule)
date: 2019/01/16
tags:
    - attack.defense_evasion
    - attack.execution
    - attack.t1064
logsource:
    category: process_creation
    product: windows
detection:
    selection:
        Image:
            - '*\wscript.exe'
            - '*\cscript.exe'
        CommandLine:
            - '* C:\Users\\*.jse *'
            - '* C:\Users\\*.vbe *'
            - '* C:\Users\\*.js *'
            - '* C:\Users\\*.vba *'
            - '* C:\Users\\*.vbs *'
            - '* C:\ProgramData\\*.jse *'
            - '* C:\ProgramData\\*.vbe *'
            - '* C:\ProgramData\\*.js *'
            - '* C:\ProgramData\\*.vba *'
            - '* C:\ProgramData\\*.vbs *'
    falsepositive:
        ParentImage: '*\winzip*'
    condition: selection and not falsepositive
fields:
    - CommandLine
    - ParentCommandLine
falsepositives:
    - Winzip
    - Other self-extractors
level: high

```





### powershell
    
```
Get-WinEvent | where {((($_.message -match "Image.*.*\\wscript.exe" -or $_.message -match "Image.*.*\\cscript.exe") -and ($_.message -match "CommandLine.*.* C:\\Users\\.*.jse .*" -or $_.message -match "CommandLine.*.* C:\\Users\\.*.vbe .*" -or $_.message -match "CommandLine.*.* C:\\Users\\.*.js .*" -or $_.message -match "CommandLine.*.* C:\\Users\\.*.vba .*" -or $_.message -match "CommandLine.*.* C:\\Users\\.*.vbs .*" -or $_.message -match "CommandLine.*.* C:\\ProgramData\\.*.jse .*" -or $_.message -match "CommandLine.*.* C:\\ProgramData\\.*.vbe .*" -or $_.message -match "CommandLine.*.* C:\\ProgramData\\.*.js .*" -or $_.message -match "CommandLine.*.* C:\\ProgramData\\.*.vba .*" -or $_.message -match "CommandLine.*.* C:\\ProgramData\\.*.vbs .*")) -and  -not ($_.message -match "ParentImage.*.*\\winzip.*")) } | select TimeCreated,Id,RecordId,ProcessId,MachineName,Message
```


### es-qs
    
```
((winlog.event_data.Image.keyword:(*\\wscript.exe OR *\\cscript.exe) AND winlog.event_data.CommandLine.keyword:(*\ C\:\\Users\\*.jse\ * OR *\ C\:\\Users\\*.vbe\ * OR *\ C\:\\Users\\*.js\ * OR *\ C\:\\Users\\*.vba\ * OR *\ C\:\\Users\\*.vbs\ * OR *\ C\:\\ProgramData\\*.jse\ * OR *\ C\:\\ProgramData\\*.vbe\ * OR *\ C\:\\ProgramData\\*.js\ * OR *\ C\:\\ProgramData\\*.vba\ * OR *\ C\:\\ProgramData\\*.vbs\ *)) AND (NOT (winlog.event_data.ParentImage.keyword:*\\winzip*)))
```


### xpack-watcher
    
```
curl -s -XPUT -H 'Content-Type: application/json' --data-binary @- localhost:9200/_watcher/watch/cea72823-df4d-4567-950c-0b579eaf0846 <<EOF
{
  "metadata": {
    "title": "WScript or CScript Dropper",
    "description": "Detects wscript/cscript executions of scripts located in user directories",
    "tags": [
      "attack.defense_evasion",
      "attack.execution",
      "attack.t1064"
    ],
    "query": "((winlog.event_data.Image.keyword:(*\\\\wscript.exe OR *\\\\cscript.exe) AND winlog.event_data.CommandLine.keyword:(*\\ C\\:\\\\Users\\\\*.jse\\ * OR *\\ C\\:\\\\Users\\\\*.vbe\\ * OR *\\ C\\:\\\\Users\\\\*.js\\ * OR *\\ C\\:\\\\Users\\\\*.vba\\ * OR *\\ C\\:\\\\Users\\\\*.vbs\\ * OR *\\ C\\:\\\\ProgramData\\\\*.jse\\ * OR *\\ C\\:\\\\ProgramData\\\\*.vbe\\ * OR *\\ C\\:\\\\ProgramData\\\\*.js\\ * OR *\\ C\\:\\\\ProgramData\\\\*.vba\\ * OR *\\ C\\:\\\\ProgramData\\\\*.vbs\\ *)) AND (NOT (winlog.event_data.ParentImage.keyword:*\\\\winzip*)))"
  },
  "trigger": {
    "schedule": {
      "interval": "30m"
    }
  },
  "input": {
    "search": {
      "request": {
        "body": {
          "size": 0,
          "query": {
            "bool": {
              "must": [
                {
                  "query_string": {
                    "query": "((winlog.event_data.Image.keyword:(*\\\\wscript.exe OR *\\\\cscript.exe) AND winlog.event_data.CommandLine.keyword:(*\\ C\\:\\\\Users\\\\*.jse\\ * OR *\\ C\\:\\\\Users\\\\*.vbe\\ * OR *\\ C\\:\\\\Users\\\\*.js\\ * OR *\\ C\\:\\\\Users\\\\*.vba\\ * OR *\\ C\\:\\\\Users\\\\*.vbs\\ * OR *\\ C\\:\\\\ProgramData\\\\*.jse\\ * OR *\\ C\\:\\\\ProgramData\\\\*.vbe\\ * OR *\\ C\\:\\\\ProgramData\\\\*.js\\ * OR *\\ C\\:\\\\ProgramData\\\\*.vba\\ * OR *\\ C\\:\\\\ProgramData\\\\*.vbs\\ *)) AND (NOT (winlog.event_data.ParentImage.keyword:*\\\\winzip*)))",
                    "analyze_wildcard": true
                  }
                }
              ],
              "filter": {
                "range": {
                  "timestamp": {
                    "gte": "now-30m/m"
                  }
                }
              }
            }
          }
        },
        "indices": [
          "winlogbeat-*"
        ]
      }
    }
  },
  "condition": {
    "compare": {
      "ctx.payload.hits.total": {
        "not_eq": 0
      }
    }
  },
  "actions": {
    "send_email": {
      "email": {
        "to": "root@localhost",
        "subject": "Sigma Rule 'WScript or CScript Dropper'",
        "body": "Hits:\n{{#ctx.payload.hits.hits}}Hit on {{_source.@timestamp}}:\n      CommandLine = {{_source.CommandLine}}\nParentCommandLine = {{_source.ParentCommandLine}}================================================================================\n{{/ctx.payload.hits.hits}}",
        "attachments": {
          "data.json": {
            "data": {
              "format": "json"
            }
          }
        }
      }
    }
  }
}
EOF

```


### graylog
    
```
((Image.keyword:(*\\wscript.exe *\\cscript.exe) AND CommandLine.keyword:(* C\:\\Users\\*.jse * * C\:\\Users\\*.vbe * * C\:\\Users\\*.js * * C\:\\Users\\*.vba * * C\:\\Users\\*.vbs * * C\:\\ProgramData\\*.jse * * C\:\\ProgramData\\*.vbe * * C\:\\ProgramData\\*.js * * C\:\\ProgramData\\*.vba * * C\:\\ProgramData\\*.vbs *)) AND (NOT (ParentImage.keyword:*\\winzip*)))
```


### splunk
    
```
(((Image="*\\wscript.exe" OR Image="*\\cscript.exe") (CommandLine="* C:\\Users\\*.jse *" OR CommandLine="* C:\\Users\\*.vbe *" OR CommandLine="* C:\\Users\\*.js *" OR CommandLine="* C:\\Users\\*.vba *" OR CommandLine="* C:\\Users\\*.vbs *" OR CommandLine="* C:\\ProgramData\\*.jse *" OR CommandLine="* C:\\ProgramData\\*.vbe *" OR CommandLine="* C:\\ProgramData\\*.js *" OR CommandLine="* C:\\ProgramData\\*.vba *" OR CommandLine="* C:\\ProgramData\\*.vbs *")) NOT (ParentImage="*\\winzip*")) | table CommandLine,ParentCommandLine
```


### logpoint
    
```
((Image IN ["*\\wscript.exe", "*\\cscript.exe"] CommandLine IN ["* C:\\Users\\*.jse *", "* C:\\Users\\*.vbe *", "* C:\\Users\\*.js *", "* C:\\Users\\*.vba *", "* C:\\Users\\*.vbs *", "* C:\\ProgramData\\*.jse *", "* C:\\ProgramData\\*.vbe *", "* C:\\ProgramData\\*.js *", "* C:\\ProgramData\\*.vba *", "* C:\\ProgramData\\*.vbs *"])  -(ParentImage="*\\winzip*"))
```


### grep
    
```
grep -P '^(?:.*(?=.*(?:.*(?=.*(?:.*.*\wscript\.exe|.*.*\cscript\.exe))(?=.*(?:.*.* C:\Users\\.*\.jse .*|.*.* C:\Users\\.*\.vbe .*|.*.* C:\Users\\.*\.js .*|.*.* C:\Users\\.*\.vba .*|.*.* C:\Users\\.*\.vbs .*|.*.* C:\ProgramData\\.*\.jse .*|.*.* C:\ProgramData\\.*\.vbe .*|.*.* C:\ProgramData\\.*\.js .*|.*.* C:\ProgramData\\.*\.vba .*|.*.* C:\ProgramData\\.*\.vbs .*))))(?=.*(?!.*(?:.*(?=.*.*\winzip.*)))))'
```



