| Title                    | Trickbot Malware Recon Activity       |
|:-------------------------|:------------------|
| **Description**          | Trickbot enumerates domain/network topology and executes certain commands automatically every few minutes. This detectors attempts to identify that activity based off a command rarely observed in an enterprise network. |
| **ATT&amp;CK Tactic**    |   This Detection Rule wasn't mapped to ATT&amp;CK Tactic yet  |
| **ATT&amp;CK Technique** | <ul><li>[T1482: Domain Trust Discovery](https://attack.mitre.org/techniques/T1482)</li></ul>  |
| **Data Needed**          | <ul><li>[DN_0002_4688_windows_process_creation_with_commandline](../Data_Needed/DN_0002_4688_windows_process_creation_with_commandline.md)</li><li>[DN_0003_1_windows_sysmon_process_creation](../Data_Needed/DN_0003_1_windows_sysmon_process_creation.md)</li></ul>  |
| **Trigger**              | <ul><li>[T1482: Domain Trust Discovery](../Triggers/T1482.md)</li></ul>  |
| **Severity Level**       | critical |
| **False Positives**      | <ul><li>Rare System Admin Activity</li></ul>  |
| **Development Status**   | experimental |
| **References**           | <ul><li>[https://www.sneakymonkey.net/2019/05/22/trickbot-analysis/](https://www.sneakymonkey.net/2019/05/22/trickbot-analysis/)</li></ul>  |
| **Author**               | David Burkett |


## Detection Rules

### Sigma rule

```
title: Trickbot Malware Recon Activity
id: 410ad193-a728-4107-bc79-4419789fcbf8
status: experimental
description: Trickbot enumerates domain/network topology and executes certain commands automatically every few minutes. This detectors attempts to identify that activity based off a command rarely observed in an enterprise network.
references:
    - https://www.sneakymonkey.net/2019/05/22/trickbot-analysis/
author: David Burkett
date: 2019/12/28
tags:
    - attack.t1482
logsource:
    category: process_creation
    product: windows
detection:
    selection:
        Image:
            - '*\nltest.exe'
        CommandLine:
            - '/domain_trusts /all_trusts'
            - '/domain_trusts'
    condition: selection
fields:
    - CommandLine
    - ParentCommandLine
falsepositives:
    - Rare System Admin Activity
level: critical
```





### powershell
    
```
Get-WinEvent | where {(($_.message -match "Image.*.*\\nltest.exe") -and ($_.message -match "/domain_trusts /all_trusts" -or $_.message -match "/domain_trusts")) } | select TimeCreated,Id,RecordId,ProcessId,MachineName,Message
```


### es-qs
    
```
(winlog.event_data.Image.keyword:(*\\nltest.exe) AND winlog.event_data.CommandLine:("\/domain_trusts\ \/all_trusts" OR "\/domain_trusts"))
```


### xpack-watcher
    
```
curl -s -XPUT -H 'Content-Type: application/json' --data-binary @- localhost:9200/_watcher/watch/410ad193-a728-4107-bc79-4419789fcbf8 <<EOF
{
  "metadata": {
    "title": "Trickbot Malware Recon Activity",
    "description": "Trickbot enumerates domain/network topology and executes certain commands automatically every few minutes. This detectors attempts to identify that activity based off a command rarely observed in an enterprise network.",
    "tags": [
      "attack.t1482"
    ],
    "query": "(winlog.event_data.Image.keyword:(*\\\\nltest.exe) AND winlog.event_data.CommandLine:(\"\\/domain_trusts\\ \\/all_trusts\" OR \"\\/domain_trusts\"))"
  },
  "trigger": {
    "schedule": {
      "interval": "30m"
    }
  },
  "input": {
    "search": {
      "request": {
        "body": {
          "size": 0,
          "query": {
            "bool": {
              "must": [
                {
                  "query_string": {
                    "query": "(winlog.event_data.Image.keyword:(*\\\\nltest.exe) AND winlog.event_data.CommandLine:(\"\\/domain_trusts\\ \\/all_trusts\" OR \"\\/domain_trusts\"))",
                    "analyze_wildcard": true
                  }
                }
              ],
              "filter": {
                "range": {
                  "timestamp": {
                    "gte": "now-30m/m"
                  }
                }
              }
            }
          }
        },
        "indices": [
          "winlogbeat-*"
        ]
      }
    }
  },
  "condition": {
    "compare": {
      "ctx.payload.hits.total": {
        "not_eq": 0
      }
    }
  },
  "actions": {
    "send_email": {
      "email": {
        "to": "root@localhost",
        "subject": "Sigma Rule 'Trickbot Malware Recon Activity'",
        "body": "Hits:\n{{#ctx.payload.hits.hits}}Hit on {{_source.@timestamp}}:\n      CommandLine = {{_source.CommandLine}}\nParentCommandLine = {{_source.ParentCommandLine}}================================================================================\n{{/ctx.payload.hits.hits}}",
        "attachments": {
          "data.json": {
            "data": {
              "format": "json"
            }
          }
        }
      }
    }
  }
}
EOF

```


### graylog
    
```
(Image.keyword:(*\\nltest.exe) AND CommandLine:("\/domain_trusts \/all_trusts" "\/domain_trusts"))
```


### splunk
    
```
((Image="*\\nltest.exe") (CommandLine="/domain_trusts /all_trusts" OR CommandLine="/domain_trusts")) | table CommandLine,ParentCommandLine
```


### logpoint
    
```
(Image IN ["*\\nltest.exe"] CommandLine IN ["/domain_trusts /all_trusts", "/domain_trusts"])
```


### grep
    
```
grep -P '^(?:.*(?=.*(?:.*.*\nltest\.exe))(?=.*(?:.*/domain_trusts /all_trusts|.*/domain_trusts)))'
```



