| Title                    | Potential RDP Exploit CVE-2019-0708       |
|:-------------------------|:------------------|
| **Description**          | Detect suspicious error on protocol RDP, potential CVE-2019-0708 |
| **ATT&amp;CK Tactic**    |  <ul><li>[TA0001: Initial Access](https://attack.mitre.org/tactics/TA0001)</li><li>[TA0008: Lateral Movement](https://attack.mitre.org/tactics/TA0008)</li></ul>  |
| **ATT&amp;CK Technique** | <ul><li>[T1210: Exploitation of Remote Services](https://attack.mitre.org/techniques/T1210)</li><li>[T1190: Exploit Public-Facing Application](https://attack.mitre.org/techniques/T1190)</li></ul>  |
| **Data Needed**          | <ul><li>[DN_0089_56_terminal_server_security_layer_detected_an_error](../Data_Needed/DN_0089_56_terminal_server_security_layer_detected_an_error.md)</li><li>[DN_0090_50_terminal_server_security_layer_detected_an_error](../Data_Needed/DN_0090_50_terminal_server_security_layer_detected_an_error.md)</li></ul>  |
| **Trigger**              |  There is no documented Trigger for this Detection Rule yet  |
| **Severity Level**       | high |
| **False Positives**      | <ul><li>Bad connections or network interruptions</li></ul>  |
| **Development Status**   | experimental |
| **References**           | <ul><li>[https://github.com/zerosum0x0/CVE-2019-0708](https://github.com/zerosum0x0/CVE-2019-0708)</li><li>[https://github.com/Ekultek/BlueKeep](https://github.com/Ekultek/BlueKeep)</li></ul>  |
| **Author**               | Lionel PRAT, Christophe BROCAS, @atc_project (improvements) |
| Other Tags           | <ul><li>car.2013-07-002</li></ul> | 

## Detection Rules

### Sigma rule

```
title: Potential RDP Exploit CVE-2019-0708
id: aaa5b30d-f418-420b-83a0-299cb6024885
description: Detect suspicious error on protocol RDP, potential CVE-2019-0708
references:
    - https://github.com/zerosum0x0/CVE-2019-0708
    - https://github.com/Ekultek/BlueKeep
tags:
    - attack.initial_access
    - attack.lateral_movement
    - attack.t1210
    - attack.t1190
    - car.2013-07-002
status: experimental
author: "Lionel PRAT, Christophe BROCAS, @atc_project (improvements)"
date: 2019/05/24
logsource:
    product: windows
    service: system
detection:
    selection:
        EventID:
            - 56
            - 50
        Source: TermDD
    condition: selection
falsepositives:
    - Bad connections or network interruptions
level: high

```





### powershell
    
```
Get-WinEvent -LogName System | where {(($_.ID -eq "56" -or $_.ID -eq "50") -and $_.message -match "Source.*TermDD") } | select TimeCreated,Id,RecordId,ProcessId,MachineName,Message
```


### es-qs
    
```
(winlog.event_id:("56" OR "50") AND winlog.event_data.Source:"TermDD")
```


### xpack-watcher
    
```
curl -s -XPUT -H 'Content-Type: application/json' --data-binary @- localhost:9200/_watcher/watch/aaa5b30d-f418-420b-83a0-299cb6024885 <<EOF
{
  "metadata": {
    "title": "Potential RDP Exploit CVE-2019-0708",
    "description": "Detect suspicious error on protocol RDP, potential CVE-2019-0708",
    "tags": [
      "attack.initial_access",
      "attack.lateral_movement",
      "attack.t1210",
      "attack.t1190",
      "car.2013-07-002"
    ],
    "query": "(winlog.event_id:(\"56\" OR \"50\") AND winlog.event_data.Source:\"TermDD\")"
  },
  "trigger": {
    "schedule": {
      "interval": "30m"
    }
  },
  "input": {
    "search": {
      "request": {
        "body": {
          "size": 0,
          "query": {
            "bool": {
              "must": [
                {
                  "query_string": {
                    "query": "(winlog.event_id:(\"56\" OR \"50\") AND winlog.event_data.Source:\"TermDD\")",
                    "analyze_wildcard": true
                  }
                }
              ],
              "filter": {
                "range": {
                  "timestamp": {
                    "gte": "now-30m/m"
                  }
                }
              }
            }
          }
        },
        "indices": [
          "winlogbeat-*"
        ]
      }
    }
  },
  "condition": {
    "compare": {
      "ctx.payload.hits.total": {
        "not_eq": 0
      }
    }
  },
  "actions": {
    "send_email": {
      "email": {
        "to": "root@localhost",
        "subject": "Sigma Rule 'Potential RDP Exploit CVE-2019-0708'",
        "body": "Hits:\n{{#ctx.payload.hits.hits}}{{_source}}\n================================================================================\n{{/ctx.payload.hits.hits}}",
        "attachments": {
          "data.json": {
            "data": {
              "format": "json"
            }
          }
        }
      }
    }
  }
}
EOF

```


### graylog
    
```
(EventID:("56" "50") AND Source:"TermDD")
```


### splunk
    
```
(source="WinEventLog:System" (EventCode="56" OR EventCode="50") Source="TermDD")
```


### logpoint
    
```
(event_source="Microsoft-Windows-Security-Auditing" event_id IN ["56", "50"] Source="TermDD")
```


### grep
    
```
grep -P '^(?:.*(?=.*(?:.*56|.*50))(?=.*TermDD))'
```



