# T1064 - Scripting
## [Description from ATT&CK](https://attack.mitre.org/wiki/Technique/T1064)
<blockquote>Adversaries may use scripts to aid in operations and perform multiple actions that would otherwise be manual. Scripting is useful for speeding up operational tasks and reducing the time required to gain access to critical resources. Some scripting languages may be used to bypass process monitoring mechanisms by directly interacting with the operating system at an API level instead of calling other programs. Common scripting languages for Windows include VBScript and [PowerShell](https://attack.mitre.org/techniques/T1086) but could also be in the form of command-line batch scripts.

Scripts can be embedded inside Office documents as macros that can be set to execute when files used in [Spearphishing Attachment](https://attack.mitre.org/techniques/T1193) and other types of spearphishing are opened. Malicious embedded macros are an alternative means of execution than software exploitation through [Exploitation for Client Execution](https://attack.mitre.org/techniques/T1203), where adversaries will rely on macros being allowed or that the user will accept to activate them.

Many popular offensive frameworks exist which use forms of scripting for security testers and adversaries alike. Metasploit (Citation: Metasploit_Ref), Veil (Citation: Veil_Ref), and PowerSploit (Citation: Powersploit) are three examples that are popular among penetration testers for exploit and post-compromise operations and include many features for evading defenses. Some adversaries are known to use PowerShell. (Citation: Alperovitch 2014)</blockquote>

## Atomic Tests

- [Atomic Test #1 - Create and Execute Bash Shell Script](#atomic-test-1---create-and-execute-bash-shell-script)

- [Atomic Test #2 - Create and Execute Batch Script](#atomic-test-2---create-and-execute-batch-script)


<br/>

## Atomic Test #1 - Create and Execute Bash Shell Script
Creates and executes a simple bash script.

**Supported Platforms:** macOS, Linux





#### Attack Commands: Run with `sh`! 


```sh
sh -c "echo 'echo Hello from the Atomic Red Team' > /tmp/art.sh"
sh -c "echo 'ping -c 4 8.8.8.8' >> /tmp/art.sh"
chmod +x /tmp/art.sh
sh /tmp/art.sh
```






<br/>
<br/>

## Atomic Test #2 - Create and Execute Batch Script
Creates and executes a simple batch script. Upon execution, CMD will briefly launh to run the batch script then close again.

**Supported Platforms:** Windows




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| command_to_execute | Command to execute within script. | string | dir|
| script_path | Path of script to create. | path | $env:TEMP&#92;T1064_script.bat|


#### Attack Commands: Run with `powershell`! 


```powershell
Start-Process #{script_path}
```

#### Cleanup Commands:
```powershell
Remove-Item #{script_path} -Force -ErrorAction Ignore
```



#### Dependencies:  Run with `powershell`!
##### Description: Batch file must exist on disk at specified location (#{script_path})
##### Check Prereq Commands:
```powershell
if (Test-Path #{script_path}) {exit 0} else {exit 1} 
```
##### Get Prereq Commands:
```powershell
New-Item #{script_path} -Force | Out-Null
Set-Content -Path #{script_path} -Value "#{command_to_execute}"
```




<br/>
