# T1166 - Setuid and Setgid
## [Description from ATT&CK](https://attack.mitre.org/wiki/Technique/T1166)
<blockquote>When the setuid or setgid bits are set on Linux or macOS for an application, this means that the application will run with the privileges of the owning user or group respectively  (Citation: setuid man page). Normally an application is run in the current user’s context, regardless of which user or group owns the application. There are instances where programs need to be executed in an elevated context to function properly, but the user running them doesn’t need the elevated privileges. Instead of creating an entry in the sudoers file, which must be done by root, any user can specify the setuid or setgid flag to be set for their own applications. These bits are indicated with an "s" instead of an "x" when viewing a file's attributes via <code>ls -l</code>. The <code>chmod</code> program can set these bits with via bitmasking, <code>chmod 4777 [file]</code> or via shorthand naming, <code>chmod u+s [file]</code>.

An adversary can take advantage of this to either do a shell escape or exploit a vulnerability in an application with the setsuid or setgid bits to get code running in a different user’s context. Additionally, adversaries can use this mechanism on their own malware to make sure they're able to execute in elevated contexts in the future  (Citation: OSX Keydnap malware).</blockquote>

## Atomic Tests

- [Atomic Test #1 - Make and modify binary from C source](#atomic-test-1---make-and-modify-binary-from-c-source)

- [Atomic Test #2 - Set a SetUID flag on file](#atomic-test-2---set-a-setuid-flag-on-file)

- [Atomic Test #3 - Set a SetGID flag on file](#atomic-test-3---set-a-setgid-flag-on-file)


<br/>

## Atomic Test #1 - Make and modify binary from C source
Make, change owner, and change file attributes on a C source code file

**Supported Platforms:** macOS, Linux




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| payload | hello.c payload | path | PathToAtomicsFolder/T1166/src/hello.c|


#### Attack Commands: Run with `sh`!  Elevation Required (e.g. root or admin) 


```sh
cp #{payload} /tmp/hello.c
cd /tmp
sudo chown root hello.c
sudo make hello
sudo chown root hello
sudo chmod u+s hello
./hello
```

#### Cleanup Commands:
```sh
sudo rm ./hello
sudo rm /tmp/hello.c
```





<br/>
<br/>

## Atomic Test #2 - Set a SetUID flag on file
This test sets the SetUID flag on a file in Linux and macOS.

**Supported Platforms:** macOS, Linux




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| file_to_setuid | Path of file to set SetUID flag | path | /tmp/evilBinary|


#### Attack Commands: Run with `sh`!  Elevation Required (e.g. root or admin) 


```sh
sudo touch #{file_to_setuid}
sudo chown root #{file_to_setuid}
sudo chmod u+s #{file_to_setuid}
```

#### Cleanup Commands:
```sh
sudo rm #{file_to_setuid}
```





<br/>
<br/>

## Atomic Test #3 - Set a SetGID flag on file
This test sets the SetGID flag on a file in Linux and macOS.

**Supported Platforms:** macOS, Linux




#### Inputs:
| Name | Description | Type | Default Value | 
|------|-------------|------|---------------|
| file_to_setuid | Path of file to set SetGID flag | path | /tmp/evilBinary|


#### Attack Commands: Run with `sh`!  Elevation Required (e.g. root or admin) 


```sh
sudo touch #{file_to_setuid}
sudo chown root #{file_to_setuid}
sudo chmod g+s #{file_to_setuid}
```

#### Cleanup Commands:
```sh
sudo rm #{file_to_setuid}
```





<br/>
